@@ -61,6 +61,8 @@ ${IN_SCRIPT:-false} && {
 echo_help() {
     cat << EOF
 Usage: $0 [OPTION] ... -- [OPTIONS FOR CMAKE]
+--enable-*/--disable-* options shown are not the default
+For each enable-*, there is a disable-* option, and vice versa.
 
 -a, --all, all          Builds release and debug
     --asm, asm=*        Set assembly compiler [$ASM]
@@ -76,14 +78,28 @@ Usage: $0 [OPTION] ... -- [OPTIONS FOR CMAKE]
     enable-avx512
     --enable-lto,       Enable link time optimization
     enable-lto
+    --disable-native,   Disable the use of -march=native
+    disable-native
+    --enable-pgo,       Enable profile guided optimization
+    enable-pgo
     --shared, shared    Build shared libs
 -x, --static, static    Build static libs
+    --native, native    Build for native performance (march=native)
 -g, --gen, gen=*        Set CMake generator
 -i, --install, install  Install build [Default release]
 -j, --jobs, jobs=*      Set number of jobs for make/CMake [$jobs]
     --no-enc, no-enc    Don't build the encoder app and libs
     --no-dec, no-dec    Don't build the decoder app and libs
+    --no-apps, no-apps  Don't build the apps, only build the libs
 -p, --prefix, prefix=*  Set installation prefix
+    --pgo-dir,          Directory to store the pgo profiles
+    pgo-dir=*
+    --pgo-compile-gen,  Compile PGO up to the generate stage
+    pgo-compile-gen
+    --pgo-compile-use,  Compile PGO up to the use stage
+    pgo-compile-use
+    --pgo-videos,       Directory of y4m videos to use for PGO instead
+    pgo-videos=         of objective-1-fast
     --release, release  Build release
     --sanitizer,        Build and enable using sanitizer
     sanitizer=*
@@ -102,35 +118,41 @@ Example usage:
 EOF
 }
 
-# Usage: build <release|debug> [test]
-build() (
-    build_type=Release
+configure() (
+    build_type=Release clean=true
     while [ -n "$*" ]; do
         case $(printf %s "$1" | tr '[:upper:]' '[:lower:]') in
         release) build_type=Release && shift ;;
         debug) build_type=Debug && shift ;;
+        no_clean) clean=false && shift ;;
         *) break ;;
         esac
     done
-
-    rm -rf $build_type
+    $clean && rm -rf $build_type
     mkdir -p $build_type > /dev/null 2>&1
     cd_safe $build_type
-
     cmake ../../.. -DCMAKE_BUILD_TYPE=$build_type $CMAKE_EXTRA_FLAGS "$@"
+)
 
-    if [ -f Makefile ]; then
-        make -j "$jobs"
-        return
-    fi
-
-    set --
+# Usage: build <release|debug> [test]
+build() (
+    build_type=Release clean=''
+    while [ -n "$*" ]; do
+        case $(printf %s "$1" | tr '[:upper:]' '[:lower:]') in
+        release) build_type=Release && shift ;;
+        debug) build_type=Debug && shift ;;
+        clean) clean=true && shift ;;
+        *) break ;;
+        esac
+    done
     if cmake --build 2>&1 | grep -q parallel; then
-        set -- --parallel "$jobs"
+        cmake --build $build_type --config $build_type ${clean:+--clean-first} --parallel "$jobs" "$@"
+    elif [ -f "$build_type/Makefile" ]; then
+        ${clean:+make -C "$build_type" clean}
+        make -C "$build_type" -j "$jobs" "$@"
+    else
+        cmake --build $build_type --config $build_type ${clean:+--clean-first} "$@"
     fi
-
-    # Compile the Library
-    cmake --build . --config $build_type "$@"
 )
 
 check_executable() (
@@ -147,7 +169,8 @@ check_executable() (
         $print_exec && printf '%s\n' "$command_to_check"
         return 0
     fi
-    for d in "$@" $(printf '%s ' "$PATH" | tr ':' ' '); do
+    IFS="${IFS}:"
+    for d in "$@" $PATH; do
         if [ -x "$d/$command_to_check" ]; then
             $print_exec && printf '%s\n' "$d/$command_to_check"
             return 0
@@ -158,7 +181,7 @@ check_executable() (
 
 install_build() (
     build_type=Release
-    sudo=$(check_executable -p sudo)
+    sudo=$(check_executable -p sudo) || :
     while [ -n "$*" ]; do
         case $(printf %s "$1" | tr '[:upper:]' '[:lower:]') in
         release) build_type="Release" && shift ;;
@@ -176,22 +199,24 @@ install_build() (
 )
 
 if [ -z "$CC" ] && [ "$(uname -a | cut -c1-5)" != "MINGW" ]; then
-    ! CC=$(check_executable -p icc /opt/intel/bin) &&
+    if ! CC=$(check_executable -p icc /opt/intel/bin) && ! CC=$(check_executable -p clang); then
         ! CC=$(check_executable -p gcc) &&
-        ! CC=$(check_executable -p clang) &&
-        ! CC=$(check_executable -p cc) &&
-        die "No suitable c compiler found in path" \
-            "Please either install one or set it via cc=*"
+            ! CC=$(check_executable -p cc) &&
+            die "No suitable c compiler found in path" \
+                "Please either install one or set it via cc=*"
+        print_message "Unable to find clang or icc, it is recommended to use clang" "Currently using $CC"
+    fi
     export CC
 fi
 
 if [ -z "$CXX" ] && [ "$(uname -a | cut -c1-5)" != "MINGW" ]; then
-    ! CXX=$(check_executable -p icpc "/opt/intel/bin") &&
+    if ! CXX=$(check_executable -p icpc /opt/intel/bin) && ! CXX=$(check_executable -p clang++); then
         ! CXX=$(check_executable -p g++) &&
-        ! CXX=$(check_executable -p clang++) &&
-        ! CXX=$(check_executable -p c++) &&
-        die "No suitable cpp compiler found in path" \
-            "Please either install one or set it via cxx=*"
+            ! CXX=$(check_executable -p c++) &&
+            die "No suitable c++ compiler found in path" \
+                "Please either install one or set it via cxx=*"
+        print_message "Unable to find clang++ or icpc, it is recommended to use clang++" "Currently using $CXX"
+    fi
     export CXX
 fi
 
@@ -199,6 +224,8 @@ build_release=false
 build_debug=false
 build_install=false
 
+PGO_COMPILE_STAGE=none
+
 parse_options() {
     while true; do
         [ -z "$1" ] && break
@@ -245,6 +272,9 @@ parse_options() {
         disable*)
             case ${1#disable-} in
             avx512) CMAKE_EXTRA_FLAGS="$CMAKE_EXTRA_FLAGS -DENABLE_AVX512=OFF" ;;
+            lto) CMAKE_EXTRA_FLAGS="$CMAKE_EXTRA_FLAGS -DSVT_AV1_LTO=OFF" ;;
+            native) CMAKE_EXTRA_FLAGS="$CMAKE_EXTRA_FLAGS -DNATIVE=OFF" ;;
+            pgo) CMAKE_EXTRA_FLAGS="$CMAKE_EXTRA_FLAGS -DSVT_AV1_PGO=OFF" PGO_COMPILE_STAGE=none ;;
             *) print_message "Unknown option: $1" ;;
             esac
             shift
@@ -253,18 +283,31 @@ parse_options() {
             case ${1#enable-} in
             avx512) CMAKE_EXTRA_FLAGS="$CMAKE_EXTRA_FLAGS -DENABLE_AVX512=ON" ;;
             lto) CMAKE_EXTRA_FLAGS="$CMAKE_EXTRA_FLAGS -DSVT_AV1_LTO=ON" ;;
+            native) CMAKE_EXTRA_FLAGS="$CMAKE_EXTRA_FLAGS -DNATIVE=ON" ;;
+            pgo)
+                CMAKE_EXTRA_FLAGS="$CMAKE_EXTRA_FLAGS -DSVT_AV1_PGO=ON"
+                case $PGO_COMPILE_STAGE in
+                none) PGO_COMPILE_STAGE=all ;;
+                esac
+                ;;
             *) print_message "Unknown option: $1" ;;
             esac
             shift
             ;;
         shared) CMAKE_EXTRA_FLAGS="$CMAKE_EXTRA_FLAGS -DBUILD_SHARED_LIBS=ON" && shift ;;
         static) CMAKE_EXTRA_FLAGS="$CMAKE_EXTRA_FLAGS -DBUILD_SHARED_LIBS=OFF" && shift ;;
+        native) CMAKE_EXTRA_FLAGS="$CMAKE_EXTRA_FLAGS -DNATIVE=ON" && shift ;;
         gen=*) CMAKE_EXTRA_FLAGS="$CMAKE_EXTRA_FLAGS -G${1#*=}" && shift ;;
         install) build_install=true && shift ;;
         jobs=*) jobs="${1#*=}" && shift ;;
         no-enc) CMAKE_EXTRA_FLAGS="$CMAKE_EXTRA_FLAGS -DBUILD_ENC=OFF" && shift ;;
         no-dec) CMAKE_EXTRA_FLAGS="$CMAKE_EXTRA_FLAGS -DBUILD_DEC=OFF" && shift ;;
+        no-apps) CMAKE_EXTRA_FLAGS="$CMAKE_EXTRA_FLAGS -DBUILD_APPS=OFF" && shift ;;
         prefix=*) CMAKE_EXTRA_FLAGS="$CMAKE_EXTRA_FLAGS -DCMAKE_INSTALL_PREFIX=${1#*=}" && shift ;;
+        pgo-dir=*) CMAKE_EXTRA_FLAGS="$CMAKE_EXTRA_FLAGS -DSVT_AV1_PGO_DIR=${1#*=}" && shift ;;
+        pgo-compile-gen) PGO_COMPILE_STAGE=gen && shift ;;
+        pgo-compile-use) PGO_COMPILE_STAGE=use && shift ;;
+        pgo-videos=*) CMAKE_EXTRA_FLAGS="$CMAKE_EXTRA_FLAGS -DSVT_AV1_PGO_CUSTOM_VIDEOS=${1#*=}" && shift ;;
         release) build_release=true && shift ;;
         sanitizer=*) CMAKE_EXTRA_FLAGS="$CMAKE_EXTRA_FLAGS -DSANITIZER=${1#*=}" && shift ;;
         target_system=*)
@@ -282,7 +325,7 @@ parse_options() {
                 toolchain=$PWD/$toolchain
                 curl --connect-timeout 15 --retry 3 --retry-delay 5 -sfLk -o "$toolchain" "$url"
                 ;;
-            *) toolchain=$(
+            *) toolchain="$(
                 case ${url%/*} in
                 */*)
                     [ -n "$prev_pwd" ] && cd "$prev_pwd"
@@ -290,7 +333,7 @@ parse_options() {
                     ;;
                 esac
                 pwd -P 2> /dev/null || pwd
-            )/${url##*/} ;;
+            )/${url##*/}" ;;
             esac
             CMAKE_EXTRA_FLAGS="$CMAKE_EXTRA_FLAGS -DCMAKE_TOOLCHAIN_FILE=$toolchain" && shift
             ;;
@@ -307,6 +350,8 @@ parse_equal_option() {
     esac
 }
 
+parse_options enable-native
+
 if [ -z "$*" ]; then
     build_release=true
 else
@@ -322,17 +367,21 @@ else
             c-only) parse_options c-only && shift ;;
             clean) parse_options clean && shift ;;
             debug) parse_options debug && shift ;;
-            disable* | enable* ) parse_options "$match" && shift ;;
+            disable* | enable*) parse_options "$match" && shift ;;
             install) parse_options install && shift ;;
             no-enc) parse_options no-enc && shift ;;
             no-dec) parse_options no-dec && shift ;;
+            no-apps) parse_options no-apps && shift ;;
+            pgo-compile-gen) parse_options pgo-compile-gen && shift ;;
+            pgo-compile-use) parse_options pgo-compile-use && shift ;;
             release) parse_options release && shift ;;
             shared) parse_options shared && shift ;;
             static) parse_options static && shift ;;
+            native) parse_options native && shift ;;
             toolchain) parse_options toolchain="$2" && shift ;;
             test) parse_options tests && shift ;;
             verbose) parse_options verbose && shift ;;
-            asm | bindir | cc | cxx | gen | jobs | prefix | sanitizer | target_system)
+            asm | bindir | cc | cxx | gen | jobs | pgo-dir | pgo-videos | prefix | sanitizer | target_system)
                 parse_equal_option "$1" "$2"
                 case $1 in
                 *=*) shift ;;
@@ -432,19 +481,25 @@ else
             c-only) parse_options c-only && shift ;;
             clean) parse_options clean && shift ;;
             debug) parse_options debug && shift ;;
-            disable* | enable* ) parse_options "$match" && shift ;;
+            disable* | enable*) parse_options "$match" && shift ;;
             gen=*) parse_options gen="${1#*=}" && shift ;;
             help) parse_options help && shift ;;
             install) parse_options install && shift ;;
             jobs=*) parse_options jobs="${1#*=}" && shift ;;
             prefix=*) parse_options prefix="${1#*=}" && shift ;;
+            pgo-dir=*) parse_options pgo-dir="${1#*=}" && shift ;;
+            pgo-compile-gen) parse_options pgo-compile-gen && shift ;;
+            pgo-compile-use) parse_options pgo-compile-use && shift ;;
+            pgo-videos=*) parse_options pgo-videos="${1#*=}" && shift ;;
             no-enc) parse_options no-enc && shift ;;
             no-dec) parse_options no-dec && shift ;;
+            no-apps) parse_options no-apps && shift ;;
             target_system=*) parse_options target_system="${1#*=}" && shift ;;
             shared) parse_options shared && shift ;;
             static) parse_options static && shift ;;
+            native) parse_options native && shift ;;
             release) parse_options release && shift ;;
-            sanitizer=*) parse_options sanitizer="${1#*=}" && shift;;
+            sanitizer=*) parse_options sanitizer="${1#*=}" && shift ;;
             test) parse_options tests && shift ;;
             toolchain=*) parse_options toolchain="${1#*=}" && shift ;;
             verbose) parse_options verbose && shift ;;
@@ -462,14 +517,22 @@ esac
 
 [ "${PATH#*\/usr\/local\/bin}" = "$PATH" ] && PATH=$PATH:/usr/local/bin
 
-if $build_debug && $build_release; then
-    build release "$@"
-    build debug "$@"
-elif $build_debug; then
-    build debug "$@"
-else
+build_args='' compile_args=''
+
+case $PGO_COMPILE_STAGE in
+all) build_args='--target RunPGO' ;;
+gen) build_args='--target PGOCompileGen' ;;
+use) compile_args=no_clean build_args='--target PGOCompileUse' ;;
+esac
+
+$build_debug && {
+    configure debug $compile_args "$@"
+    build debug $build_args
+}
+if $build_release || ! $build_debug; then
     build_release=true
-    build release "$@"
+    configure release $compile_args "$@"
+    build release $build_args
 fi
 
 if $build_install; then
