@@ -29,10 +29,10 @@
 #include "EbAppConfig.h"
 #include "EbAppContext.h"
 #include "EbTime.h"
+#include <fcntl.h>
 #ifdef _WIN32
 #include <windows.h>
 #include <io.h> /* _setmode() */
-#include <fcntl.h> /* _O_BINARY */
 #else
 #include <pthread.h>
 #include <semaphore.h>
@@ -63,6 +63,8 @@ void process_output_recon_buffer(EncChannel* c);
 
 void process_output_stream_buffer(EncChannel* c, EncApp* enc_app, int32_t* frame_count);
 
+void init_reader(EbConfig* app_cfg);
+
 volatile int32_t keep_running = 1;
 
 void event_handler(int32_t dummy) {
@@ -76,10 +78,10 @@ void event_handler(int32_t dummy) {
 void assign_app_thread_group(uint8_t target_socket) {
 #ifdef _WIN32
     if (GetActiveProcessorGroupCount() == 2) {
-        GROUP_AFFINITY group_affinity;
-        GetThreadGroupAffinity(GetCurrentThread(), &group_affinity);
-        group_affinity.Group = target_socket;
-        SetThreadGroupAffinity(GetCurrentThread(), &group_affinity, NULL);
+        GROUP_AFFINITY svt_aom_group_affinity;
+        GetThreadGroupAffinity(GetCurrentThread(), &svt_aom_group_affinity);
+        svt_aom_group_affinity.Group = target_socket;
+        SetThreadGroupAffinity(GetCurrentThread(), &svt_aom_group_affinity, NULL);
     }
 #else
     (void)target_socket;
@@ -97,31 +99,46 @@ typedef struct EncContext {
 } EncContext;
 
 //initilize memory mapped file handler
-void init_memory_file_map(EbConfig* config) {
+static void init_memory_file_map(EbConfig* app_cfg) {
+    app_cfg->mmap.enable = app_cfg->buffered_input == -1 && !app_cfg->input_file_is_fifo;
+
+    if (!app_cfg->mmap.enable)
+        return;
+    // app_cfg->mmap.y4m_seq_hdr   = 0; // already initialized to 0 or some value in read_y4m_header()
+    app_cfg->mmap.y4m_frm_hdr   = 0;
+    app_cfg->mmap.file_frame_it = 0;
+    const int64_t curr_loc      = ftello(app_cfg->input_file); // get current fp location
+    fseeko(app_cfg->input_file, 0L, SEEK_END); // seek to end of file
+    app_cfg->mmap.file_size = ftello(app_cfg->input_file); // get file size
+    fseeko(app_cfg->input_file, curr_loc, SEEK_SET); // seek back to that location
 #ifdef _WIN32
-    config->mmap.enable = 0;
-#else
-    config->mmap.enable = (config->buffered_input == -1) ? 1 : 0;
-#endif
-
-    if (config->input_file == stdin || config->input_file_is_fifo)
-        config->mmap.enable = 0;
-
-    if (config->mmap.enable) {
-        if (config->input_file) {
-            uint64_t curr_loc = ftello(config->input_file); // get current fp location
-            fseeko(config->input_file, 0L, SEEK_END);
-            config->mmap.file_size = ftello(config->input_file);
-            fseeko(config->input_file, curr_loc, SEEK_SET); // seek back to that location
-#ifndef _WIN32
-            config->mmap.fd = fileno(config->input_file);
-#endif
-        }
-        config->mmap.file_frame_it = 0;
-#ifndef _WIN32
-        config->mmap.align_mask = sysconf(_SC_PAGESIZE) - 1;
-#endif
+    SYSTEM_INFO sys_info;
+    GetSystemInfo(&sys_info);
+    app_cfg->mmap.fd         = _fileno(app_cfg->input_file);
+    app_cfg->mmap.align_mask = sys_info.dwAllocationGranularity > sys_info.dwPageSize
+        ? sys_info.dwAllocationGranularity - 1
+        : sys_info.dwPageSize - 1;
+    HANDLE fhandle           = (HANDLE)_get_osfhandle(app_cfg->mmap.fd);
+    app_cfg->mmap.map_handle = CreateFileMapping(fhandle, NULL, PAGE_READONLY, 0, 0, NULL);
+    if (!app_cfg->mmap.map_handle) {
+        app_cfg->mmap.enable = false;
+        return;
     }
+#else
+    app_cfg->mmap.fd = fileno(app_cfg->input_file);
+#if defined(__linux__)
+    posix_fadvise(app_cfg->mmap.fd, 0, 0, POSIX_FADV_NOREUSE);
+#endif
+    app_cfg->mmap.align_mask = sysconf(_SC_PAGESIZE) - 1;
+#endif
+}
+
+static void deinit_memory_file_map(EbConfig* app_cfg) {
+    if (!app_cfg->mmap.enable)
+        return;
+#ifdef _WIN32
+    CloseHandle(app_cfg->mmap.map_handle);
+#endif
 }
 
 static int compar_uint64(const void* a, const void* b) {
@@ -130,8 +147,8 @@ static int compar_uint64(const void* a, const void* b) {
     return (x < y) ? -1 : (x > y) ? 1 : 0;
 }
 
-static EbErrorType enc_context_ctor(EncApp* enc_app, EncContext* enc_context, int32_t argc,
-                                    char* argv[], EncPass enc_pass, int32_t passes) {
+static EbErrorType enc_context_ctor(EncApp* enc_app, EncContext* enc_context, int32_t argc, char* argv[],
+                                    EncPass enc_pass, int32_t passes) {
 #if LOG_ENC_DONE
     tot_frames_done = 0;
 #endif
@@ -169,23 +186,23 @@ static EbErrorType enc_context_ctor(EncApp* enc_app, EncContext* enc_context, in
         return return_error;
     }
     // Set main thread affinity
-    if (enc_context->channels[0].config->config.target_socket != -1)
-        assign_app_thread_group(enc_context->channels[0].config->config.target_socket);
+    if (enc_context->channels[0].app_cfg->config.target_socket != -1)
+        assign_app_thread_group(enc_context->channels[0].app_cfg->config.target_socket);
 
     // Init the Encoder
     for (uint32_t inst_cnt = 0; inst_cnt < num_channels; ++inst_cnt) {
         EncChannel* c = enc_context->channels + inst_cnt;
         if (c->return_error == EB_ErrorNone) {
-            EbConfig* config                    = c->config;
-            config->config.active_channel_count = num_channels;
-            config->config.channel_id           = inst_cnt;
-            config->config.recon_enabled        = config->recon_file ? TRUE : FALSE;
+            EbConfig* app_cfg                    = c->app_cfg;
+            app_cfg->config.active_channel_count = num_channels;
+            app_cfg->config.channel_id           = inst_cnt;
+            app_cfg->config.recon_enabled        = app_cfg->recon_file ? TRUE : FALSE;
 
             // set force_key_frames frames
-            if (config->config.force_key_frames) {
-                const double fps = (double)config->config.frame_rate_numerator /
-                    config->config.frame_rate_denominator;
-                struct forced_key_frames* forced_keyframes = &config->forced_keyframes;
+            if (app_cfg->config.force_key_frames) {
+                const double fps = (double)app_cfg->config.frame_rate_numerator /
+                    app_cfg->config.frame_rate_denominator;
+                struct forced_key_frames* forced_keyframes = &app_cfg->forced_keyframes;
 
                 for (size_t i = 0; i < forced_keyframes->count; ++i) {
                     char*  p;
@@ -204,18 +221,18 @@ static EbErrorType enc_context_ctor(EncApp* enc_app, EncContext* enc_context, in
                       sizeof(forced_keyframes->frames[0]),
                       compar_uint64);
             }
-            init_memory_file_map(config);
+            init_memory_file_map(app_cfg);
+            init_reader(app_cfg);
 
-            app_svt_av1_get_time(&config->performance_context.lib_start_time[0],
-                                 &config->performance_context.lib_start_time[1]);
+            app_svt_av1_get_time(&app_cfg->performance_context.lib_start_time[0],
+                                 &app_cfg->performance_context.lib_start_time[1]);
             // Update pass
-            config->config.pass = passes == 1 ? config->config.pass // Single-Pass
-                                              : (int)enc_pass; // Multi-Pass
+            app_cfg->config.pass = passes == 1 ? app_cfg->config.pass // Single-Pass
+                                               : (int)enc_pass; // Multi-Pass
 
-            c->return_error = handle_stats_file(
-                config, enc_pass, &enc_app->rc_twopasses_stats, num_channels);
+            c->return_error = handle_stats_file(app_cfg, enc_pass, &enc_app->rc_twopasses_stats, num_channels);
             if (c->return_error == EB_ErrorNone) {
-                c->return_error = init_encoder(config, c->app_callback, inst_cnt);
+                c->return_error = init_encoder(app_cfg, inst_cnt);
             }
             return_error = (EbErrorType)(return_error | c->return_error);
         } else
@@ -228,70 +245,67 @@ static void enc_context_dctor(EncContext* enc_context) {
     // DeInit Encoder
     for (int32_t inst_cnt = enc_context->num_channels - 1; inst_cnt >= 0; --inst_cnt) {
         EncChannel* c = enc_context->channels + inst_cnt;
+        deinit_memory_file_map(c->app_cfg);
         enc_channel_dctor(c, inst_cnt);
     }
 
-    for (uint32_t warning_id = 0; warning_id < MAX_NUM_TOKENS; warning_id++)
-        free(enc_context->warning[warning_id]);
+    for (uint32_t warning_id = 0; warning_id < MAX_NUM_TOKENS; warning_id++) free(enc_context->warning[warning_id]);
 }
 
 double      get_psnr(double sse, double max);
 static void print_summary(const EncContext* const enc_context) {
     for (uint32_t inst_cnt = 0; inst_cnt < enc_context->num_channels; ++inst_cnt) {
-        const EncChannel* const c      = &enc_context->channels[inst_cnt];
-        const EbConfig*         config = c->config;
+        const EncChannel* const c       = &enc_context->channels[inst_cnt];
+        const EbConfig*         app_cfg = c->app_cfg;
         if (c->exit_cond == APP_ExitConditionFinished && c->return_error == EB_ErrorNone &&
-            (config->config.pass == 0 ||
-             (config->config.pass == 2 &&
-              config->config.rate_control_mode == SVT_AV1_RC_MODE_CQP_OR_CRF) ||
-             config->config.pass == 3)) {
+            (app_cfg->config.pass == 0 ||
+             (app_cfg->config.pass == 2 && app_cfg->config.rate_control_mode == SVT_AV1_RC_MODE_CQP_OR_CRF) ||
+             app_cfg->config.pass == 3)) {
 #if LOG_ENC_DONE
-            tot_frames_done = (int)config->performance_context.frame_count;
+            tot_frames_done = (int)app_cfg->performance_context.frame_count;
 #endif
-            uint64_t frame_count    = (uint32_t)config->performance_context.frame_count;
-            uint32_t max_luma_value = (config->config.encoder_bit_depth == 8) ? 255 : 1023;
+
+            uint64_t frame_count    = (uint32_t)app_cfg->performance_context.frame_count;
+            uint32_t max_luma_value = (app_cfg->config.encoder_bit_depth == 8) ? 255 : 1023;
             double   max_luma_sse   = (double)max_luma_value * max_luma_value *
-                (config->config.source_width * config->config.source_height);
+                (app_cfg->config.source_width * app_cfg->config.source_height);
             double max_chroma_sse = (double)max_luma_value * max_luma_value *
-                (config->config.source_width / 2 * config->config.source_height / 2);
+                (app_cfg->config.source_width / 2 * app_cfg->config.source_height / 2);
 
-            const double frame_rate = (double)config->config.frame_rate_numerator /
-                (double)config->config.frame_rate_denominator;
+            const double frame_rate = (double)app_cfg->config.frame_rate_numerator /
+                (double)app_cfg->config.frame_rate_denominator;
 
-            if (config->config.stat_report && config->stat_file) {
-                fprintf(config->stat_file,
+            if (app_cfg->config.stat_report && app_cfg->stat_file) {
+                fprintf(app_cfg->stat_file,
                         "\nSUMMARY "
                         "------------------------------------------------------"
                         "---------------\n");
-                fprintf(config->stat_file,
+                fprintf(app_cfg->stat_file,
                         "\n\t\t\t\tAverage PSNR (using per-frame "
                         "PSNR)\t\t|\tOverall PSNR (using per-frame MSE)\t\t|"
                         "\tAverage SSIM\n");
-                fprintf(config->stat_file,
+                fprintf(app_cfg->stat_file,
                         "Total Frames\tAverage QP  \tY-PSNR   \tU-PSNR   "
                         "\tV-PSNR\t\t| \tY-PSNR   \tU-PSNR   \tV-PSNR   \t|"
                         "\tY-SSIM   \tU-SSIM   \tV-SSIM   "
                         "\t|\tBitrate\n");
-                fprintf(config->stat_file,
+                fprintf(app_cfg->stat_file,
                         "%10ld  \t   %2.2f    \t%3.2f dB\t%3.2f dB\t%3.2f dB  "
                         "\t|\t%3.2f dB\t%3.2f dB\t%3.2f dB \t|\t%1.5f \t%1.5f "
                         "\t%1.5f\t\t|\t%.2f kbps\n",
                         (long int)frame_count,
-                        (float)config->performance_context.sum_qp / frame_count,
-                        (float)config->performance_context.sum_luma_psnr / frame_count,
-                        (float)config->performance_context.sum_cb_psnr / frame_count,
-                        (float)config->performance_context.sum_cr_psnr / frame_count,
-                        (float)(get_psnr((config->performance_context.sum_luma_sse / frame_count),
-                                         max_luma_sse)),
-                        (float)(get_psnr((config->performance_context.sum_cb_sse / frame_count),
-                                         max_chroma_sse)),
-                        (float)(get_psnr((config->performance_context.sum_cr_sse / frame_count),
-                                         max_chroma_sse)),
-                        (float)config->performance_context.sum_luma_ssim / frame_count,
-                        (float)config->performance_context.sum_cb_ssim / frame_count,
-                        (float)config->performance_context.sum_cr_ssim / frame_count,
-                        ((double)(config->performance_context.byte_count << 3) * frame_rate /
-                         (config->frames_encoded * 1000)));
+                        (float)app_cfg->performance_context.sum_qp / frame_count,
+                        (float)app_cfg->performance_context.sum_luma_psnr / frame_count,
+                        (float)app_cfg->performance_context.sum_cb_psnr / frame_count,
+                        (float)app_cfg->performance_context.sum_cr_psnr / frame_count,
+                        (float)(get_psnr((app_cfg->performance_context.sum_luma_sse / frame_count), max_luma_sse)),
+                        (float)(get_psnr((app_cfg->performance_context.sum_cb_sse / frame_count), max_chroma_sse)),
+                        (float)(get_psnr((app_cfg->performance_context.sum_cr_sse / frame_count), max_chroma_sse)),
+                        (float)app_cfg->performance_context.sum_luma_ssim / frame_count,
+                        (float)app_cfg->performance_context.sum_cb_ssim / frame_count,
+                        (float)app_cfg->performance_context.sum_cr_ssim / frame_count,
+                        ((double)(app_cfg->performance_context.byte_count << 3) * frame_rate /
+                         (app_cfg->frames_encoded * 1000)));
             }
 
             fprintf(stderr,
@@ -303,11 +317,11 @@ static void print_summary(const EncContext* const enc_context) {
                     "%12d\t\t%4.2f fps\t\t%10.0f\t\t%5.2f kbps\n",
                     (int32_t)frame_count,
                     frame_rate,
-                    (double)config->performance_context.byte_count,
-                    ((double)(config->performance_context.byte_count << 3) * frame_rate /
-                     (config->frames_encoded * 1000)));
+                    (double)app_cfg->performance_context.byte_count,
+                    ((double)(app_cfg->performance_context.byte_count << 3) * frame_rate /
+                     (app_cfg->frames_encoded * 1000)));
 
-            if (config->config.stat_report) {
+            if (app_cfg->config.stat_report) {
                 fprintf(stderr,
                         "\n\t\tAverage PSNR (using per-frame "
                         "PSNR)\t\t|\tOverall PSNR (using per-frame MSE)\t\t|\t"
@@ -319,19 +333,16 @@ static void print_summary(const EncContext* const enc_context) {
                 fprintf(stderr,
                         "%11.2f\t%4.2f dB\t%4.2f dB\t%4.2f dB\t|\t%4.2f "
                         "dB\t%4.2f dB\t%4.2f dB\t|\t%1.5f\t%1.5f\t%1.5f\n",
-                        (float)config->performance_context.sum_qp / frame_count,
-                        (float)config->performance_context.sum_luma_psnr / frame_count,
-                        (float)config->performance_context.sum_cb_psnr / frame_count,
-                        (float)config->performance_context.sum_cr_psnr / frame_count,
-                        (float)(get_psnr((config->performance_context.sum_luma_sse / frame_count),
-                                         max_luma_sse)),
-                        (float)(get_psnr((config->performance_context.sum_cb_sse / frame_count),
-                                         max_chroma_sse)),
-                        (float)(get_psnr((config->performance_context.sum_cr_sse / frame_count),
-                                         max_chroma_sse)),
-                        (float)config->performance_context.sum_luma_ssim / frame_count,
-                        (float)config->performance_context.sum_cb_ssim / frame_count,
-                        (float)config->performance_context.sum_cr_ssim / frame_count);
+                        (float)app_cfg->performance_context.sum_qp / frame_count,
+                        (float)app_cfg->performance_context.sum_luma_psnr / frame_count,
+                        (float)app_cfg->performance_context.sum_cb_psnr / frame_count,
+                        (float)app_cfg->performance_context.sum_cr_psnr / frame_count,
+                        (float)(get_psnr((app_cfg->performance_context.sum_luma_sse / frame_count), max_luma_sse)),
+                        (float)(get_psnr((app_cfg->performance_context.sum_cb_sse / frame_count), max_chroma_sse)),
+                        (float)(get_psnr((app_cfg->performance_context.sum_cr_sse / frame_count), max_chroma_sse)),
+                        (float)app_cfg->performance_context.sum_luma_ssim / frame_count,
+                        (float)app_cfg->performance_context.sum_cb_ssim / frame_count,
+                        (float)app_cfg->performance_context.sum_cr_ssim / frame_count);
             }
 
             fflush(stdout);
@@ -345,22 +356,21 @@ static void print_performance(const EncContext* const enc_context) {
     for (uint32_t inst_cnt = 0; inst_cnt < enc_context->num_channels; ++inst_cnt) {
         const EncChannel* c = enc_context->channels + inst_cnt;
         if (c->exit_cond == APP_ExitConditionFinished && c->return_error == EB_ErrorNone) {
-            EbConfig* config = c->config;
-            if (config->stop_encoder == FALSE) {
-                if ((config->config.pass == 0 ||
-                     (config->config.pass == 2 &&
-                      config->config.rate_control_mode == SVT_AV1_RC_MODE_CQP_OR_CRF) ||
-                     config->config.pass == 3))
+            EbConfig* app_cfg = c->app_cfg;
+            if (app_cfg->stop_encoder == FALSE) {
+                if ((app_cfg->config.pass == 0 ||
+                     (app_cfg->config.pass == 2 && app_cfg->config.rate_control_mode == SVT_AV1_RC_MODE_CQP_OR_CRF) ||
+                     app_cfg->config.pass == 3))
                     fprintf(stderr,
                             "\nChannel %u\nAverage Speed:\t\t%.3f fps\nTotal Encoding Time:\t%.0f "
                             "ms\nTotal Execution Time:\t%.0f ms\nAverage Latency:\t%.0f ms\nMax "
                             "Latency:\t\t%u ms\n",
                             (uint32_t)(inst_cnt + 1),
-                            config->performance_context.average_speed,
-                            config->performance_context.total_encode_time * 1000,
-                            config->performance_context.total_execution_time * 1000,
-                            config->performance_context.average_latency,
-                            (uint32_t)(config->performance_context.max_latency));
+                            app_cfg->performance_context.average_speed,
+                            app_cfg->performance_context.total_encode_time * 1000,
+                            app_cfg->performance_context.total_execution_time * 1000,
+                            app_cfg->performance_context.average_latency,
+                            (uint32_t)(app_cfg->performance_context.max_latency));
             } else
                 fprintf(stderr, "\nChannel %u Encoding Interrupted\n", (uint32_t)(inst_cnt + 1));
         } else if (c->return_error == EB_ErrorInsufficientResources)
@@ -393,23 +403,34 @@ static Bool has_active_channel(const EncContext* const enc_context) {
     }
     return FALSE;
 }
+bool process_skip(EbConfig* app_cfg, EbBufferHeaderType* header_ptr);
 
 static void enc_channel_step(EncChannel* c, EncApp* enc_app, EncContext* enc_context) {
-    EbConfig* config = c->config;
+    EbConfig* app_cfg = c->app_cfg;
+
+    if (app_cfg->need_to_skip) {
+        bool skip   = !process_skip(app_cfg, app_cfg->input_buffer_pool);
+        int  next_c = fgetc(app_cfg->input_file);
+        if (!skip && next_c == EOF) {
+            fputs("\n[SVT-Error]: Skipped all available frames!\n", stderr);
+            c->exit_cond_input = APP_ExitConditionFinished;
+            c->active          = FALSE;
+            return;
+        }
+        ungetc(next_c, app_cfg->input_file);
+    }
+
     process_input_buffer(c);
     process_output_recon_buffer(c);
     process_output_stream_buffer(c, enc_app, &enc_context->total_frames);
 
-    if (((c->exit_cond_recon == APP_ExitConditionFinished || !config->recon_file) &&
-         c->exit_cond_output == APP_ExitConditionFinished &&
-         c->exit_cond_input == APP_ExitConditionFinished) ||
-        ((c->exit_cond_recon == APP_ExitConditionError && config->recon_file) ||
-         c->exit_cond_output == APP_ExitConditionError ||
-         c->exit_cond_input == APP_ExitConditionError)) {
+    if (((c->exit_cond_recon == APP_ExitConditionFinished || !app_cfg->recon_file) &&
+         c->exit_cond_output == APP_ExitConditionFinished && c->exit_cond_input == APP_ExitConditionFinished) ||
+        ((c->exit_cond_recon == APP_ExitConditionError && app_cfg->recon_file) ||
+         c->exit_cond_output == APP_ExitConditionError || c->exit_cond_input == APP_ExitConditionError)) {
         c->active = FALSE;
-        if (config->recon_file)
-            c->exit_cond = (AppExitConditionType)(c->exit_cond_recon | c->exit_cond_output |
-                                                  c->exit_cond_input);
+        if (app_cfg->recon_file)
+            c->exit_cond = (AppExitConditionType)(c->exit_cond_recon | c->exit_cond_output | c->exit_cond_input);
         else
             c->exit_cond = (AppExitConditionType)(c->exit_cond_output | c->exit_cond_input);
     }
@@ -432,14 +453,14 @@ static const char* get_pass_name(EncPass enc_pass, int32_t passes) {
 }
 static void enc_channel_start(EncChannel* c) {
     if (c->return_error == EB_ErrorNone) {
-        EbConfig* config    = c->config;
+        EbConfig* app_cfg   = c->app_cfg;
         c->exit_cond        = APP_ExitConditionNone;
         c->exit_cond_output = APP_ExitConditionNone;
-        c->exit_cond_recon  = config->recon_file ? APP_ExitConditionNone : APP_ExitConditionError;
+        c->exit_cond_recon  = app_cfg->recon_file ? APP_ExitConditionNone : APP_ExitConditionError;
         c->exit_cond_input  = APP_ExitConditionNone;
         c->active           = TRUE;
-        app_svt_av1_get_time(&config->performance_context.encode_start_time[0],
-                             &config->performance_context.encode_start_time[1]);
+        app_svt_av1_get_time(&app_cfg->performance_context.encode_start_time[0],
+                             &app_cfg->performance_context.encode_start_time[1]);
     }
 }
 
@@ -500,8 +521,7 @@ int32_t main(int32_t argc, char* argv[]) {
     enc_app_ctor(&enc_app);
     passes = get_passes(argc, argv, enc_pass);
     for (uint8_t pass_idx = 0; pass_idx < passes; pass_idx++) {
-        return_error = enc_context_ctor(
-            &enc_app, &enc_context, argc, argv, enc_pass[pass_idx], passes);
+        return_error = enc_context_ctor(&enc_app, &enc_context, argc, argv, enc_pass[pass_idx], passes);
 
         if (return_error == EB_ErrorNone)
             return_error = encode(&enc_app, &enc_context);
