@@ -14,9 +14,8 @@
 
 #include "EbDefinitions.h"
 
-static INLINE __m256i calc_mask_d16_avx2(const __m256i *data_src0, const __m256i *data_src1,
-                                         const __m256i *round_const, const __m256i *mask_base_16,
-                                         const __m256i *clip_diff, int round) {
+static INLINE __m256i calc_mask_d16_avx2(const __m256i *data_src0, const __m256i *data_src1, const __m256i *round_const,
+                                         const __m256i *mask_base_16, const __m256i *clip_diff, int round) {
     const __m256i diffa       = _mm256_subs_epu16(*data_src0, *data_src1);
     const __m256i diffb       = _mm256_subs_epu16(*data_src1, *data_src0);
     const __m256i diff        = _mm256_max_epu16(diffa, diffb);
@@ -28,9 +27,8 @@ static INLINE __m256i calc_mask_d16_avx2(const __m256i *data_src0, const __m256i
 }
 
 static INLINE __m256i calc_mask_d16_inv_avx2(const __m256i *data_src0, const __m256i *data_src1,
-                                             const __m256i *round_const,
-                                             const __m256i *mask_base_16, const __m256i *clip_diff,
-                                             int round) {
+                                             const __m256i *round_const, const __m256i *mask_base_16,
+                                             const __m256i *clip_diff, int round) {
     const __m256i diffa         = _mm256_subs_epu16(*data_src0, *data_src1);
     const __m256i diffb         = _mm256_subs_epu16(*data_src1, *data_src0);
     const __m256i diff          = _mm256_max_epu16(diffa, diffb);
@@ -42,9 +40,9 @@ static INLINE __m256i calc_mask_d16_inv_avx2(const __m256i *data_src0, const __m
     return diff_const_16;
 }
 
-static INLINE void build_compound_diffwtd_mask_d16_avx2(uint8_t *mask, const CONV_BUF_TYPE *src0,
-                                                        int src0_stride, const CONV_BUF_TYPE *src1,
-                                                        int src1_stride, int h, int w, int shift) {
+static INLINE void build_compound_diffwtd_mask_d16_avx2(uint8_t *mask, const CONV_BUF_TYPE *src0, int src0_stride,
+                                                        const CONV_BUF_TYPE *src1, int src1_stride, int h, int w,
+                                                        int shift) {
     const int     mask_base = 38;
     const __m256i _r        = _mm256_set1_epi16((1 << shift) >> 1);
     const __m256i y38       = _mm256_set1_epi16(mask_base);
@@ -60,10 +58,8 @@ static INLINE void build_compound_diffwtd_mask_d16_avx2(uint8_t *mask, const CON
             const __m128i s1_b = xx_loadl_64(src1 + src1_stride);
             const __m128i s1_c = xx_loadl_64(src1 + src1_stride * 2);
             const __m128i s1_d = xx_loadl_64(src1 + src1_stride * 3);
-            const __m256i s0   = yy_set_m128i(_mm_unpacklo_epi64(s0_c, s0_d),
-                                            _mm_unpacklo_epi64(s0_a, s0_b));
-            const __m256i s1   = yy_set_m128i(_mm_unpacklo_epi64(s1_c, s1_d),
-                                            _mm_unpacklo_epi64(s1_a, s1_b));
+            const __m256i s0   = yy_set_m128i(_mm_unpacklo_epi64(s0_c, s0_d), _mm_unpacklo_epi64(s0_a, s0_b));
+            const __m256i s1   = yy_set_m128i(_mm_unpacklo_epi64(s1_c, s1_d), _mm_unpacklo_epi64(s1_a, s1_b));
             const __m256i m16  = calc_mask_d16_avx2(&s0, &s1, &_r, &y38, &y64, shift);
             const __m256i m8   = _mm256_packus_epi16(m16, _mm256_setzero_si256());
             xx_storeu_128(mask, _mm256_castsi256_si128(_mm256_permute4x64_epi64(m8, 0xd8)));
@@ -182,9 +178,9 @@ static INLINE void build_compound_diffwtd_mask_d16_avx2(uint8_t *mask, const CON
     }
 }
 
-static INLINE void build_compound_diffwtd_mask_d16_inv_avx2(
-    uint8_t *mask, const CONV_BUF_TYPE *src0, int src0_stride, const CONV_BUF_TYPE *src1,
-    int src1_stride, int h, int w, int shift) {
+static INLINE void build_compound_diffwtd_mask_d16_inv_avx2(uint8_t *mask, const CONV_BUF_TYPE *src0, int src0_stride,
+                                                            const CONV_BUF_TYPE *src1, int src1_stride, int h, int w,
+                                                            int shift) {
     const int     mask_base = 38;
     const __m256i _r        = _mm256_set1_epi16((1 << shift) >> 1);
     const __m256i y38       = _mm256_set1_epi16(mask_base);
@@ -200,10 +196,8 @@ static INLINE void build_compound_diffwtd_mask_d16_inv_avx2(
             const __m128i s1_b = xx_loadl_64(src1 + src1_stride);
             const __m128i s1_c = xx_loadl_64(src1 + src1_stride * 2);
             const __m128i s1_d = xx_loadl_64(src1 + src1_stride * 3);
-            const __m256i s0   = yy_set_m128i(_mm_unpacklo_epi64(s0_c, s0_d),
-                                            _mm_unpacklo_epi64(s0_a, s0_b));
-            const __m256i s1   = yy_set_m128i(_mm_unpacklo_epi64(s1_c, s1_d),
-                                            _mm_unpacklo_epi64(s1_a, s1_b));
+            const __m256i s0   = yy_set_m128i(_mm_unpacklo_epi64(s0_c, s0_d), _mm_unpacklo_epi64(s0_a, s0_b));
+            const __m256i s1   = yy_set_m128i(_mm_unpacklo_epi64(s1_c, s1_d), _mm_unpacklo_epi64(s1_a, s1_b));
             const __m256i m16  = calc_mask_d16_inv_avx2(&s0, &s1, &_r, &y38, &y64, shift);
             const __m256i m8   = _mm256_packus_epi16(m16, _mm256_setzero_si256());
             xx_storeu_128(mask, _mm256_castsi256_si128(_mm256_permute4x64_epi64(m8, 0xd8)));
@@ -218,11 +212,9 @@ static INLINE void build_compound_diffwtd_mask_d16_inv_avx2(
             const __m256i s0_c_d  = yy_loadu2_128(src0 + src0_stride * 3, src0 + src0_stride * 2);
             const __m256i s1_a_b  = yy_loadu2_128(src1 + src1_stride, src1);
             const __m256i s1_c_d  = yy_loadu2_128(src1 + src1_stride * 3, src1 + src1_stride * 2);
-            const __m256i m16_a_b = calc_mask_d16_inv_avx2(
-                &s0_a_b, &s1_a_b, &_r, &y38, &y64, shift);
-            const __m256i m16_c_d = calc_mask_d16_inv_avx2(
-                &s0_c_d, &s1_c_d, &_r, &y38, &y64, shift);
-            const __m256i m8 = _mm256_packus_epi16(m16_a_b, m16_c_d);
+            const __m256i m16_a_b = calc_mask_d16_inv_avx2(&s0_a_b, &s1_a_b, &_r, &y38, &y64, shift);
+            const __m256i m16_c_d = calc_mask_d16_inv_avx2(&s0_c_d, &s1_c_d, &_r, &y38, &y64, shift);
+            const __m256i m8      = _mm256_packus_epi16(m16_a_b, m16_c_d);
             yy_storeu_256(mask, _mm256_permute4x64_epi64(m8, 0xd8));
             src0 += src0_stride << 2;
             src1 += src1_stride << 2;
@@ -324,9 +316,8 @@ static INLINE void build_compound_diffwtd_mask_d16_inv_avx2(
     }
 }
 
-void svt_av1_build_compound_diffwtd_mask_d16_avx2(uint8_t *mask, DIFFWTD_MASK_TYPE mask_type,
-                                                  const CONV_BUF_TYPE *src0, int src0_stride,
-                                                  const CONV_BUF_TYPE *src1, int src1_stride, int h,
+void svt_av1_build_compound_diffwtd_mask_d16_avx2(uint8_t *mask, DIFFWTD_MASK_TYPE mask_type, const CONV_BUF_TYPE *src0,
+                                                  int src0_stride, const CONV_BUF_TYPE *src1, int src1_stride, int h,
                                                   int w, ConvolveParams *conv_params, int bd) {
     const int shift = 2 * FILTER_BITS - conv_params->round_0 - conv_params->round_1 + (bd - 8);
     // When rounding constant is added, there is a possibility of overflow.
@@ -337,10 +328,8 @@ void svt_av1_build_compound_diffwtd_mask_d16_avx2(uint8_t *mask, DIFFWTD_MASK_TY
     assert(AOM_BLEND_A64_MAX_ALPHA == 64);
 
     if (mask_type == DIFFWTD_38) {
-        build_compound_diffwtd_mask_d16_avx2(
-            mask, src0, src0_stride, src1, src1_stride, h, w, shift);
+        build_compound_diffwtd_mask_d16_avx2(mask, src0, src0_stride, src1, src1_stride, h, w, shift);
     } else {
-        build_compound_diffwtd_mask_d16_inv_avx2(
-            mask, src0, src0_stride, src1, src1_stride, h, w, shift);
+        build_compound_diffwtd_mask_d16_inv_avx2(mask, src0, src0_stride, src1, src1_stride, h, w, shift);
     }
 }
