@@ -13,9 +13,9 @@
 #include <emmintrin.h>
 #include "common_dsp_rtcd.h"
 
-void svt_picture_average_kernel_sse2_intrin(EbByte src0, uint32_t src0_stride, EbByte src1,
-                                            uint32_t src1_stride, EbByte dst, uint32_t dst_stride,
-                                            uint32_t area_width, uint32_t area_height) {
+void svt_picture_average_kernel_sse2_intrin(EbByte src0, uint32_t src0_stride, EbByte src1, uint32_t src1_stride,
+                                            EbByte dst, uint32_t dst_stride, uint32_t area_width,
+                                            uint32_t area_height) {
     __m128i  xmm_avg1, xmm_avg2;
     uint32_t y;
     assert((area_width & 3) == 0);
@@ -24,13 +24,11 @@ void svt_picture_average_kernel_sse2_intrin(EbByte src0, uint32_t src0_stride, E
     if (area_width >= 16) {
         for (uint32_t x = 0; x < area_height; ++x) {
             for (y = 0; y + 15 < area_width; y += 16) {
-                xmm_avg1 = _mm_avg_epu8(_mm_loadu_si128((__m128i *)(src0 + y)),
-                                        _mm_loadu_si128((__m128i *)(src1 + y)));
+                xmm_avg1 = _mm_avg_epu8(_mm_loadu_si128((__m128i *)(src0 + y)), _mm_loadu_si128((__m128i *)(src1 + y)));
                 _mm_storeu_si128((__m128i *)(dst + y), xmm_avg1);
             }
             if (area_width & 8) {
-                xmm_avg1 = _mm_avg_epu8(_mm_loadl_epi64((__m128i *)(src0 + y)),
-                                        _mm_loadl_epi64((__m128i *)(src1 + y)));
+                xmm_avg1 = _mm_avg_epu8(_mm_loadl_epi64((__m128i *)(src0 + y)), _mm_loadl_epi64((__m128i *)(src1 + y)));
                 _mm_storel_epi64((__m128i *)(dst + y), xmm_avg1);
                 y += 8;
             }
@@ -46,8 +44,7 @@ void svt_picture_average_kernel_sse2_intrin(EbByte src0, uint32_t src0_stride, E
         }
     } else if (area_width == 4) {
         for (y = 0; y < area_height; y += 2) {
-            xmm_avg1 = _mm_avg_epu8(_mm_cvtsi32_si128(*(uint32_t *)src0),
-                                    _mm_cvtsi32_si128(*(uint32_t *)src1));
+            xmm_avg1 = _mm_avg_epu8(_mm_cvtsi32_si128(*(uint32_t *)src0), _mm_cvtsi32_si128(*(uint32_t *)src1));
             xmm_avg2 = _mm_avg_epu8(_mm_cvtsi32_si128(*(uint32_t *)(src0 + src0_stride)),
                                     _mm_cvtsi32_si128(*(uint32_t *)(src1 + src1_stride)));
 
@@ -60,8 +57,7 @@ void svt_picture_average_kernel_sse2_intrin(EbByte src0, uint32_t src0_stride, E
         }
     } else if (area_width == 8) {
         for (y = 0; y < area_height; y += 2) {
-            xmm_avg1 = _mm_avg_epu8(_mm_loadl_epi64((__m128i *)src0),
-                                    _mm_loadl_epi64((__m128i *)src1));
+            xmm_avg1 = _mm_avg_epu8(_mm_loadl_epi64((__m128i *)src0), _mm_loadl_epi64((__m128i *)src1));
             xmm_avg2 = _mm_avg_epu8(_mm_loadl_epi64((__m128i *)(src0 + src0_stride)),
                                     _mm_loadl_epi64((__m128i *)(src1 + src1_stride)));
 
@@ -75,16 +71,14 @@ void svt_picture_average_kernel_sse2_intrin(EbByte src0, uint32_t src0_stride, E
     }
 }
 
-void svt_picture_average_kernel1_line_sse2_intrin(EbByte src0, EbByte src1, EbByte dst,
-                                                  uint32_t area_width) {
+void svt_picture_average_kernel1_line_sse2_intrin(EbByte src0, EbByte src1, EbByte dst, uint32_t area_width) {
     __m128i xmm_avg1, xmm_avg2, xmm_avg3, xmm_avg4;
 
     if (area_width > 16) {
         if (area_width == 32) {
             //for (y = 0; y < area_height; y += 2)
             {
-                xmm_avg1 = _mm_avg_epu8(_mm_loadu_si128((__m128i *)src0),
-                                        _mm_loadu_si128((__m128i *)src1));
+                xmm_avg1 = _mm_avg_epu8(_mm_loadu_si128((__m128i *)src0), _mm_loadu_si128((__m128i *)src1));
                 xmm_avg2 = _mm_avg_epu8(_mm_loadu_si128((__m128i *)(src0 + 16)),
                                         _mm_loadu_si128((__m128i *)(src1 + 16)));
                 //xmm_avg3 = _mm_avg_epu8(_mm_loadu_si128((__m128i*)(src0 + src0_stride)), _mm_loadu_si128((__m128i*)(src1 + src1_stride)));
@@ -102,8 +96,7 @@ void svt_picture_average_kernel1_line_sse2_intrin(EbByte src0, EbByte src1, EbBy
         } else {
             //for (y = 0; y < area_height; y += 2)
             {
-                xmm_avg1 = _mm_avg_epu8(_mm_loadu_si128((__m128i *)src0),
-                                        _mm_loadu_si128((__m128i *)src1));
+                xmm_avg1 = _mm_avg_epu8(_mm_loadu_si128((__m128i *)src0), _mm_loadu_si128((__m128i *)src1));
                 xmm_avg2 = _mm_avg_epu8(_mm_loadu_si128((__m128i *)(src0 + 16)),
                                         _mm_loadu_si128((__m128i *)(src1 + 16)));
                 xmm_avg3 = _mm_avg_epu8(_mm_loadu_si128((__m128i *)(src0 + 32)),
@@ -135,8 +128,7 @@ void svt_picture_average_kernel1_line_sse2_intrin(EbByte src0, EbByte src1, EbBy
         if (area_width == 16) {
             //for (y = 0; y < area_height; y += 2)
             {
-                xmm_avg1 = _mm_avg_epu8(_mm_loadu_si128((__m128i *)src0),
-                                        _mm_loadu_si128((__m128i *)src1));
+                xmm_avg1 = _mm_avg_epu8(_mm_loadu_si128((__m128i *)src0), _mm_loadu_si128((__m128i *)src1));
                 //xmm_avg2 = _mm_avg_epu8(_mm_loadu_si128((__m128i*)(src0 + src0_stride)), _mm_loadu_si128((__m128i*)(src1 + src1_stride)));
 
                 _mm_storeu_si128((__m128i *)dst, xmm_avg1);
@@ -149,8 +141,7 @@ void svt_picture_average_kernel1_line_sse2_intrin(EbByte src0, EbByte src1, EbBy
         } else if (area_width == 4) {
             //for (y = 0; y < area_height; y += 2)
             {
-                xmm_avg1 = _mm_avg_epu8(_mm_cvtsi32_si128(*(uint32_t *)src0),
-                                        _mm_cvtsi32_si128(*(uint32_t *)src1));
+                xmm_avg1 = _mm_avg_epu8(_mm_cvtsi32_si128(*(uint32_t *)src0), _mm_cvtsi32_si128(*(uint32_t *)src1));
                 //xmm_avg2 = _mm_avg_epu8(_mm_cvtsi32_si128(*(uint32_t *)(src0 + src0_stride)), _mm_cvtsi32_si128(*(uint32_t *)(src1 + src1_stride)));
 
                 *(uint32_t *)dst = _mm_cvtsi128_si32(xmm_avg1);
@@ -163,8 +154,7 @@ void svt_picture_average_kernel1_line_sse2_intrin(EbByte src0, EbByte src1, EbBy
         } else if (area_width == 8) {
             //for (y = 0; y < area_height; y += 2)
             {
-                xmm_avg1 = _mm_avg_epu8(_mm_loadl_epi64((__m128i *)src0),
-                                        _mm_loadl_epi64((__m128i *)src1));
+                xmm_avg1 = _mm_avg_epu8(_mm_loadl_epi64((__m128i *)src0), _mm_loadl_epi64((__m128i *)src1));
                 //xmm_avg2 = _mm_avg_epu8(_mm_loadl_epi64((__m128i*)(src0 + src0_stride)), _mm_loadl_epi64((__m128i*)(src1 + src1_stride)));
 
                 _mm_storel_epi64((__m128i *)dst, xmm_avg1);
@@ -177,8 +167,7 @@ void svt_picture_average_kernel1_line_sse2_intrin(EbByte src0, EbByte src1, EbBy
         } else {
             //for (y = 0; y < area_height; y += 2)
             {
-                xmm_avg1 = _mm_avg_epu8(_mm_loadl_epi64((__m128i *)src0),
-                                        _mm_loadl_epi64((__m128i *)src1));
+                xmm_avg1 = _mm_avg_epu8(_mm_loadl_epi64((__m128i *)src0), _mm_loadl_epi64((__m128i *)src1));
                 xmm_avg2 = _mm_avg_epu8(_mm_cvtsi32_si128(*(uint32_t *)(src0 + 8)),
                                         _mm_cvtsi32_si128(*(uint32_t *)(src1 + 8)));
 
