@@ -12,9 +12,8 @@
 //#include "EbUtility.h"
 #include "EbDefinitions.h"
 
-void svt_aom_highbd_blend_a64_vmask_16bit_c(uint16_t *dst, uint32_t dst_stride,
-                                            const uint16_t *src0, uint32_t src0_stride,
-                                            const uint16_t *src1, uint32_t src1_stride,
+void svt_aom_highbd_blend_a64_vmask_16bit_c(uint16_t *dst, uint32_t dst_stride, const uint16_t *src0,
+                                            uint32_t src0_stride, const uint16_t *src1, uint32_t src1_stride,
                                             const uint8_t *mask, int w, int h, int bd) {
     (void)bd;
     int i, j;
@@ -32,8 +31,7 @@ void svt_aom_highbd_blend_a64_vmask_16bit_c(uint16_t *dst, uint32_t dst_stride,
     for (i = 0; i < h; ++i) {
         const int m = mask[i];
         for (j = 0; j < w; ++j) {
-            dst[i * dst_stride + j] = AOM_BLEND_A64(
-                m, src0[i * src0_stride + j], src1[i * src1_stride + j]);
+            dst[i * dst_stride + j] = AOM_BLEND_A64(m, src0[i * src0_stride + j], src1[i * src1_stride + j]);
         }
     }
 }
