@@ -10,7 +10,7 @@
 */
 #include "EbLog.h"
 //for getenv and fopen on windows
-#ifndef _CRT_SECURE_NO_WARNINGS
+#if defined(_WIN32) && !defined(_CRT_SECURE_NO_WARNINGS)
 #define _CRT_SECURE_NO_WARNINGS
 #endif
 #include <stdio.h>
