@@ -43,12 +43,9 @@
 
 // by setting LS_STEP = 8, the least 2 bits of every elements in A, bx, by are
 // 0. So, we can reduce LS_MAT_RANGE_BITS(2) bits here.
-#define LS_SQUARE(a) \
-    (((a) * (a)*4 + (a)*4 * LS_STEP + LS_STEP * LS_STEP * 2) >> (2 + LS_MAT_DOWN_BITS))
-#define LS_PRODUCT1(a, b) \
-    (((a) * (b)*4 + ((a) + (b)) * 2 * LS_STEP + LS_STEP * LS_STEP) >> (2 + LS_MAT_DOWN_BITS))
-#define LS_PRODUCT2(a, b) \
-    (((a) * (b)*4 + ((a) + (b)) * 2 * LS_STEP + LS_STEP * LS_STEP * 2) >> (2 + LS_MAT_DOWN_BITS))
+#define LS_SQUARE(a) (((a) * (a)*4 + (a)*4 * LS_STEP + LS_STEP * LS_STEP * 2) >> (2 + LS_MAT_DOWN_BITS))
+#define LS_PRODUCT1(a, b) (((a) * (b)*4 + ((a) + (b)) * 2 * LS_STEP + LS_STEP * LS_STEP) >> (2 + LS_MAT_DOWN_BITS))
+#define LS_PRODUCT2(a, b) (((a) * (b)*4 + ((a) + (b)) * 2 * LS_STEP + LS_STEP * LS_STEP * 2) >> (2 + LS_MAT_DOWN_BITS))
 
 // For warping, we really use a 6-tap filter, but we do blocks of 8 pixels
 // at a time. The zoom/rotation/shear in the model are applied to the
@@ -299,34 +296,30 @@ static int32_t get_mult_shift_diag(int64_t p_x, int16_t i_det, int shift) {
 #define DIV_LUT_NUM (1 << DIV_LUT_BITS)
 
 static const uint16_t div_lut[DIV_LUT_NUM + 1] = {
-    16384, 16320, 16257, 16194, 16132, 16070, 16009, 15948, 15888, 15828, 15768, 15709, 15650,
-    15592, 15534, 15477, 15420, 15364, 15308, 15252, 15197, 15142, 15087, 15033, 14980, 14926,
-    14873, 14821, 14769, 14717, 14665, 14614, 14564, 14513, 14463, 14413, 14364, 14315, 14266,
-    14218, 14170, 14122, 14075, 14028, 13981, 13935, 13888, 13843, 13797, 13752, 13707, 13662,
-    13618, 13574, 13530, 13487, 13443, 13400, 13358, 13315, 13273, 13231, 13190, 13148, 13107,
-    13066, 13026, 12985, 12945, 12906, 12866, 12827, 12788, 12749, 12710, 12672, 12633, 12596,
-    12558, 12520, 12483, 12446, 12409, 12373, 12336, 12300, 12264, 12228, 12193, 12157, 12122,
-    12087, 12053, 12018, 11984, 11950, 11916, 11882, 11848, 11815, 11782, 11749, 11716, 11683,
-    11651, 11619, 11586, 11555, 11523, 11491, 11460, 11429, 11398, 11367, 11336, 11305, 11275,
-    11245, 11215, 11185, 11155, 11125, 11096, 11067, 11038, 11009, 10980, 10951, 10923, 10894,
-    10866, 10838, 10810, 10782, 10755, 10727, 10700, 10673, 10645, 10618, 10592, 10565, 10538,
-    10512, 10486, 10460, 10434, 10408, 10382, 10356, 10331, 10305, 10280, 10255, 10230, 10205,
-    10180, 10156, 10131, 10107, 10082, 10058, 10034, 10010, 9986,  9963,  9939,  9916,  9892,
-    9869,  9846,  9823,  9800,  9777,  9754,  9732,  9709,  9687,  9664,  9642,  9620,  9598,
-    9576,  9554,  9533,  9511,  9489,  9468,  9447,  9425,  9404,  9383,  9362,  9341,  9321,
-    9300,  9279,  9259,  9239,  9218,  9198,  9178,  9158,  9138,  9118,  9098,  9079,  9059,
-    9039,  9020,  9001,  8981,  8962,  8943,  8924,  8905,  8886,  8867,  8849,  8830,  8812,
-    8793,  8775,  8756,  8738,  8720,  8702,  8684,  8666,  8648,  8630,  8613,  8595,  8577,
-    8560,  8542,  8525,  8508,  8490,  8473,  8456,  8439,  8422,  8405,  8389,  8372,  8355,
-    8339,  8322,  8306,  8289,  8273,  8257,  8240,  8224,  8208,  8192,
+    16384, 16320, 16257, 16194, 16132, 16070, 16009, 15948, 15888, 15828, 15768, 15709, 15650, 15592, 15534, 15477,
+    15420, 15364, 15308, 15252, 15197, 15142, 15087, 15033, 14980, 14926, 14873, 14821, 14769, 14717, 14665, 14614,
+    14564, 14513, 14463, 14413, 14364, 14315, 14266, 14218, 14170, 14122, 14075, 14028, 13981, 13935, 13888, 13843,
+    13797, 13752, 13707, 13662, 13618, 13574, 13530, 13487, 13443, 13400, 13358, 13315, 13273, 13231, 13190, 13148,
+    13107, 13066, 13026, 12985, 12945, 12906, 12866, 12827, 12788, 12749, 12710, 12672, 12633, 12596, 12558, 12520,
+    12483, 12446, 12409, 12373, 12336, 12300, 12264, 12228, 12193, 12157, 12122, 12087, 12053, 12018, 11984, 11950,
+    11916, 11882, 11848, 11815, 11782, 11749, 11716, 11683, 11651, 11619, 11586, 11555, 11523, 11491, 11460, 11429,
+    11398, 11367, 11336, 11305, 11275, 11245, 11215, 11185, 11155, 11125, 11096, 11067, 11038, 11009, 10980, 10951,
+    10923, 10894, 10866, 10838, 10810, 10782, 10755, 10727, 10700, 10673, 10645, 10618, 10592, 10565, 10538, 10512,
+    10486, 10460, 10434, 10408, 10382, 10356, 10331, 10305, 10280, 10255, 10230, 10205, 10180, 10156, 10131, 10107,
+    10082, 10058, 10034, 10010, 9986,  9963,  9939,  9916,  9892,  9869,  9846,  9823,  9800,  9777,  9754,  9732,
+    9709,  9687,  9664,  9642,  9620,  9598,  9576,  9554,  9533,  9511,  9489,  9468,  9447,  9425,  9404,  9383,
+    9362,  9341,  9321,  9300,  9279,  9259,  9239,  9218,  9198,  9178,  9158,  9138,  9118,  9098,  9079,  9059,
+    9039,  9020,  9001,  8981,  8962,  8943,  8924,  8905,  8886,  8867,  8849,  8830,  8812,  8793,  8775,  8756,
+    8738,  8720,  8702,  8684,  8666,  8648,  8630,  8613,  8595,  8577,  8560,  8542,  8525,  8508,  8490,  8473,
+    8456,  8439,  8422,  8405,  8389,  8372,  8355,  8339,  8322,  8306,  8289,  8273,  8257,  8240,  8224,  8208,
+    8192,
 };
 
 // Decomposes a divisor D such that 1/D = y/2^shift, where y is returned
 // at precision of DIV_LUT_PREC_BITS along with the shift.
 static int16_t resolve_divisor_64(uint64_t D, int16_t *shift) {
     int64_t f;
-    *shift = (int16_t)((D >> 32) ? get_msb((unsigned int)(D >> 32)) + 32
-                                 : get_msb((unsigned int)D));
+    *shift = (int16_t)((D >> 32) ? get_msb((unsigned int)(D >> 32)) + 32 : get_msb((unsigned int)D));
     // e is obtained from D after resetting the most significant 1 bit.
     const int64_t e = D - ((uint64_t)1 << *shift);
     // Get the most significant DIV_LUT_BITS (8) bits of e into f
@@ -369,8 +362,8 @@ static int is_affine_shear_allowed(int16_t alpha, int16_t beta, int16_t gamma, i
         return 1;
 }
 
-static int find_affine_int(int np, const int *pts1, const int *pts2, BlockSize bsize, int mvy,
-                           int mvx, EbWarpedMotionParams *wm, int mi_row, int mi_col) {
+static int find_affine_int(int np, const int *pts1, const int *pts2, BlockSize bsize, int mvy, int mvx,
+                           EbWarpedMotionParams *wm, int mi_row, int mi_col) {
     int32_t A[2][2] = {{0, 0}, {0, 0}};
     int32_t bx[2]   = {0, 0};
     int32_t by[2]   = {0, 0};
@@ -527,7 +520,7 @@ Bool svt_find_projection(int np, int *pts1, int *pts2, BlockSize bsize, int mvy,
 */
 /* A note on hardware implementation:
     The warp filter is intended to be implementable using the same hardware as
-    the high-precision convolve filters from the loop-restoration and
+    the high-precision svt_aom_convolve filters from the loop-restoration and
     convolve-round experiments.
 
     For a single filter stage, considering all of the coefficient sets for the
@@ -574,16 +567,14 @@ Bool svt_find_projection(int np, int *pts1, int *pts2, BlockSize bsize, int mvy,
     leads to a maximum value of about 282 * 2^k after applying the offset.
     So in that case we still need to clamp.
 */
-void svt_av1_warp_affine_c(const int32_t *mat, const uint8_t *ref, int width, int height,
-                           int stride, uint8_t *pred, int p_col, int p_row, int p_width,
-                           int p_height, int p_stride, int subsampling_x, int subsampling_y,
-                           ConvolveParams *conv_params, int16_t alpha, int16_t beta, int16_t gamma,
+void svt_av1_warp_affine_c(const int32_t *mat, const uint8_t *ref, int width, int height, int stride, uint8_t *pred,
+                           int p_col, int p_row, int p_width, int p_height, int p_stride, int subsampling_x,
+                           int subsampling_y, ConvolveParams *conv_params, int16_t alpha, int16_t beta, int16_t gamma,
                            int16_t delta) {
     int32_t   tmp[15 * 8];
     const int bd                = 8;
     const int reduce_bits_horiz = conv_params->round_0;
-    const int reduce_bits_vert  = conv_params->is_compound ? conv_params->round_1
-                                                           : 2 * FILTER_BITS - reduce_bits_horiz;
+    const int reduce_bits_vert  = conv_params->is_compound ? conv_params->round_1 : 2 * FILTER_BITS - reduce_bits_horiz;
     const int max_bits_horiz    = bd + FILTER_BITS + 1 - reduce_bits_horiz;
     const int offset_bits_horiz = bd + FILTER_BITS - 1;
     const int offset_bits_vert  = bd + 2 * FILTER_BITS - reduce_bits_horiz;
@@ -627,8 +618,7 @@ void svt_av1_warp_affine_c(const int32_t *mat, const uint8_t *ref, int width, in
                 for (int l = -4; l < 4; ++l) {
                     int ix = ix4 + l - 3;
                     // At this point, sx = sx4 + alpha * l + beta * k
-                    const int offs = ROUND_POWER_OF_TWO(sx, WARPEDDIFF_PREC_BITS) +
-                        WARPEDPIXEL_PREC_SHIFTS;
+                    const int offs = ROUND_POWER_OF_TWO(sx, WARPEDDIFF_PREC_BITS) + WARPEDPIXEL_PREC_SHIFTS;
                     assert(offs >= 0 && offs <= WARPEDPIXEL_PREC_SHIFTS * 3);
                     const int16_t *coeffs = eb_warped_filter[offs];
 
@@ -651,8 +641,7 @@ void svt_av1_warp_affine_c(const int32_t *mat, const uint8_t *ref, int width, in
                 int sy = sy4 + delta * (k + 4);
                 for (int l = -4; l < AOMMIN(4, p_col + p_width - j - 4); ++l) {
                     // At this point, sy = sy4 + gamma * l + delta * k
-                    const int offs = ROUND_POWER_OF_TWO(sy, WARPEDDIFF_PREC_BITS) +
-                        WARPEDPIXEL_PREC_SHIFTS;
+                    const int offs = ROUND_POWER_OF_TWO(sy, WARPEDDIFF_PREC_BITS) + WARPEDPIXEL_PREC_SHIFTS;
                     assert(offs >= 0 && offs <= WARPEDPIXEL_PREC_SHIFTS * 3);
                     const int16_t *coeffs = eb_warped_filter[offs];
 
@@ -660,16 +649,13 @@ void svt_av1_warp_affine_c(const int32_t *mat, const uint8_t *ref, int width, in
                     for (int m = 0; m < 8; ++m) sum += tmp[(k + m + 4) * 8 + (l + 4)] * coeffs[m];
                     if (conv_params->is_compound) {
                         ConvBufType *p =
-                            &conv_params->dst[(i - p_row + k + 4) * conv_params->dst_stride +
-                                              (j - p_col + l + 4)];
+                            &conv_params->dst[(i - p_row + k + 4) * conv_params->dst_stride + (j - p_col + l + 4)];
                         sum = ROUND_POWER_OF_TWO(sum, reduce_bits_vert);
                         if (conv_params->do_average) {
-                            uint8_t *dst8 =
-                                &pred[(i - p_row + k + 4) * p_stride + (j - p_col + l + 4)];
-                            int32_t tmp32 = *p;
+                            uint8_t *dst8  = &pred[(i - p_row + k + 4) * p_stride + (j - p_col + l + 4)];
+                            int32_t  tmp32 = *p;
                             if (conv_params->use_jnt_comp_avg) {
-                                tmp32 = tmp32 * conv_params->fwd_offset +
-                                    sum * conv_params->bck_offset;
+                                tmp32 = tmp32 * conv_params->fwd_offset + sum * conv_params->bck_offset;
                                 tmp32 = tmp32 >> DIST_PRECISION_BITS;
                             } else {
                                 tmp32 += sum;
@@ -693,10 +679,9 @@ void svt_av1_warp_affine_c(const int32_t *mat, const uint8_t *ref, int width, in
     }
 }
 
-void svt_warp_plane(EbWarpedMotionParams *wm, const uint8_t *const ref, int width, int height,
-                    int stride, uint8_t *pred, int p_col, int p_row, int p_width, int p_height,
-                    int p_stride, int subsampling_x, int subsampling_y,
-                    ConvolveParams *conv_params) {
+void svt_warp_plane(EbWarpedMotionParams *wm, const uint8_t *const ref, int width, int height, int stride,
+                    uint8_t *pred, int p_col, int p_row, int p_width, int p_height, int p_stride, int subsampling_x,
+                    int subsampling_y, ConvolveParams *conv_params) {
     assert(wm->wmtype <= AFFINE);
     if (wm->wmtype == ROTZOOM) {
         wm->wmmat[5] = wm->wmmat[2];
@@ -730,16 +715,14 @@ void svt_warp_plane(EbWarpedMotionParams *wm, const uint8_t *const ref, int widt
 /* Note: For an explanation of the warp algorithm, and some notes on bit widths
     for hardware implementations, see the comments above svt_av1_warp_affine_c
 */
-void dec_svt_av1_highbd_warp_affine_c(const int32_t *mat, const uint16_t *ref, int width,
-                                      int height, int stride, uint16_t *pred, int p_col, int p_row,
-                                      int p_width, int p_height, int p_stride, int subsampling_x,
-                                      int subsampling_y, int bd, ConvolveParams *conv_params,
-                                      int16_t alpha, int16_t beta, int16_t gamma, int16_t delta) {
+void svt_aom_dec_svt_av1_highbd_warp_affine_c(const int32_t *mat, const uint16_t *ref, int width, int height,
+                                              int stride, uint16_t *pred, int p_col, int p_row, int p_width,
+                                              int p_height, int p_stride, int subsampling_x, int subsampling_y, int bd,
+                                              ConvolveParams *conv_params, int16_t alpha, int16_t beta, int16_t gamma,
+                                              int16_t delta) {
     int32_t   tmp[15 * 8];
-    const int reduce_bits_horiz = conv_params->round_0 +
-        AOMMAX(bd + FILTER_BITS - conv_params->round_0 - 14, 0);
-    const int reduce_bits_vert  = conv_params->is_compound ? conv_params->round_1
-                                                           : 2 * FILTER_BITS - reduce_bits_horiz;
+    const int reduce_bits_horiz = conv_params->round_0 + AOMMAX(bd + FILTER_BITS - conv_params->round_0 - 14, 0);
+    const int reduce_bits_vert  = conv_params->is_compound ? conv_params->round_1 : 2 * FILTER_BITS - reduce_bits_horiz;
     const int max_bits_horiz    = bd + FILTER_BITS + 1 - reduce_bits_horiz;
     const int offset_bits_horiz = bd + FILTER_BITS - 1;
     const int offset_bits_vert  = bd + 2 * FILTER_BITS - reduce_bits_horiz;
@@ -779,8 +762,7 @@ void dec_svt_av1_highbd_warp_affine_c(const int32_t *mat, const uint16_t *ref, i
                 int sx = sx4 + beta * (k + 4);
                 for (int l = -4; l < 4; ++l) {
                     int       ix   = ix4 + l - 3;
-                    const int offs = ROUND_POWER_OF_TWO(sx, WARPEDDIFF_PREC_BITS) +
-                        WARPEDPIXEL_PREC_SHIFTS;
+                    const int offs = ROUND_POWER_OF_TWO(sx, WARPEDDIFF_PREC_BITS) + WARPEDPIXEL_PREC_SHIFTS;
                     assert(offs >= 0 && offs <= WARPEDPIXEL_PREC_SHIFTS * 3);
                     const int16_t *coeffs = eb_warped_filter[offs];
 
@@ -800,8 +782,7 @@ void dec_svt_av1_highbd_warp_affine_c(const int32_t *mat, const uint16_t *ref, i
             for (int k = -4; k < AOMMIN(4, p_row + p_height - i - 4); ++k) {
                 int sy = sy4 + delta * (k + 4);
                 for (int l = -4; l < AOMMIN(4, p_col + p_width - j - 4); ++l) {
-                    const int offs = ROUND_POWER_OF_TWO(sy, WARPEDDIFF_PREC_BITS) +
-                        WARPEDPIXEL_PREC_SHIFTS;
+                    const int offs = ROUND_POWER_OF_TWO(sy, WARPEDDIFF_PREC_BITS) + WARPEDPIXEL_PREC_SHIFTS;
                     assert(offs >= 0 && offs <= WARPEDPIXEL_PREC_SHIFTS * 3);
                     const int16_t *coeffs = eb_warped_filter[offs];
 
@@ -809,16 +790,13 @@ void dec_svt_av1_highbd_warp_affine_c(const int32_t *mat, const uint16_t *ref, i
                     for (int m = 0; m < 8; ++m) sum += tmp[(k + m + 4) * 8 + (l + 4)] * coeffs[m];
                     if (conv_params->is_compound) {
                         ConvBufType *p =
-                            &conv_params->dst[(i - p_row + k + 4) * conv_params->dst_stride +
-                                              (j - p_col + l + 4)];
+                            &conv_params->dst[(i - p_row + k + 4) * conv_params->dst_stride + (j - p_col + l + 4)];
                         sum = ROUND_POWER_OF_TWO(sum, reduce_bits_vert);
                         if (conv_params->do_average) {
-                            uint16_t *dst16 =
-                                &pred[(i - p_row + k + 4) * p_stride + (j - p_col + l + 4)];
-                            int32_t tmp32 = *p;
+                            uint16_t *dst16 = &pred[(i - p_row + k + 4) * p_stride + (j - p_col + l + 4)];
+                            int32_t   tmp32 = *p;
                             if (conv_params->use_jnt_comp_avg) {
-                                tmp32 = tmp32 * conv_params->fwd_offset +
-                                    sum * conv_params->bck_offset;
+                                tmp32 = tmp32 * conv_params->fwd_offset + sum * conv_params->bck_offset;
                                 tmp32 = tmp32 >> DIST_PRECISION_BITS;
                             } else {
                                 tmp32 += sum;
@@ -841,17 +819,14 @@ void dec_svt_av1_highbd_warp_affine_c(const int32_t *mat, const uint16_t *ref, i
         }
     }
 }
-void svt_av1_highbd_warp_affine_c(const int32_t *mat, const uint8_t *ref8b, const uint8_t *ref2b,
-                                  int width, int height, int stride8b, int stride2b, uint16_t *pred,
-                                  int p_col, int p_row, int p_width, int p_height, int p_stride,
-                                  int subsampling_x, int subsampling_y, int bd,
-                                  ConvolveParams *conv_params, int16_t alpha, int16_t beta,
-                                  int16_t gamma, int16_t delta) {
+void svt_av1_highbd_warp_affine_c(const int32_t *mat, const uint8_t *ref8b, const uint8_t *ref2b, int width, int height,
+                                  int stride8b, int stride2b, uint16_t *pred, int p_col, int p_row, int p_width,
+                                  int p_height, int p_stride, int subsampling_x, int subsampling_y, int bd,
+                                  ConvolveParams *conv_params, int16_t alpha, int16_t beta, int16_t gamma,
+                                  int16_t delta) {
     int32_t   tmp[15 * 8];
-    const int reduce_bits_horiz = conv_params->round_0 +
-        AOMMAX(bd + FILTER_BITS - conv_params->round_0 - 14, 0);
-    const int reduce_bits_vert  = conv_params->is_compound ? conv_params->round_1
-                                                           : 2 * FILTER_BITS - reduce_bits_horiz;
+    const int reduce_bits_horiz = conv_params->round_0 + AOMMAX(bd + FILTER_BITS - conv_params->round_0 - 14, 0);
+    const int reduce_bits_vert  = conv_params->is_compound ? conv_params->round_1 : 2 * FILTER_BITS - reduce_bits_horiz;
     const int max_bits_horiz    = bd + FILTER_BITS + 1 - reduce_bits_horiz;
     const int offset_bits_horiz = bd + FILTER_BITS - 1;
     const int offset_bits_vert  = bd + 2 * FILTER_BITS - reduce_bits_horiz;
@@ -891,8 +866,7 @@ void svt_av1_highbd_warp_affine_c(const int32_t *mat, const uint8_t *ref8b, cons
                 int sx = sx4 + beta * (k + 4);
                 for (int l = -4; l < 4; ++l) {
                     int       ix   = ix4 + l - 3;
-                    const int offs = ROUND_POWER_OF_TWO(sx, WARPEDDIFF_PREC_BITS) +
-                        WARPEDPIXEL_PREC_SHIFTS;
+                    const int offs = ROUND_POWER_OF_TWO(sx, WARPEDDIFF_PREC_BITS) + WARPEDPIXEL_PREC_SHIFTS;
                     assert(offs >= 0 && offs <= WARPEDPIXEL_PREC_SHIFTS * 3);
                     const int16_t *coeffs = eb_warped_filter[offs];
 
@@ -914,8 +888,7 @@ void svt_av1_highbd_warp_affine_c(const int32_t *mat, const uint8_t *ref8b, cons
             for (int k = -4; k < AOMMIN(4, p_row + p_height - i - 4); ++k) {
                 int sy = sy4 + delta * (k + 4);
                 for (int l = -4; l < AOMMIN(4, p_col + p_width - j - 4); ++l) {
-                    const int offs = ROUND_POWER_OF_TWO(sy, WARPEDDIFF_PREC_BITS) +
-                        WARPEDPIXEL_PREC_SHIFTS;
+                    const int offs = ROUND_POWER_OF_TWO(sy, WARPEDDIFF_PREC_BITS) + WARPEDPIXEL_PREC_SHIFTS;
                     assert(offs >= 0 && offs <= WARPEDPIXEL_PREC_SHIFTS * 3);
                     const int16_t *coeffs = eb_warped_filter[offs];
 
@@ -923,16 +896,13 @@ void svt_av1_highbd_warp_affine_c(const int32_t *mat, const uint8_t *ref8b, cons
                     for (int m = 0; m < 8; ++m) sum += tmp[(k + m + 4) * 8 + (l + 4)] * coeffs[m];
                     if (conv_params->is_compound) {
                         ConvBufType *p =
-                            &conv_params->dst[(i - p_row + k + 4) * conv_params->dst_stride +
-                                              (j - p_col + l + 4)];
+                            &conv_params->dst[(i - p_row + k + 4) * conv_params->dst_stride + (j - p_col + l + 4)];
                         sum = ROUND_POWER_OF_TWO(sum, reduce_bits_vert);
                         if (conv_params->do_average) {
-                            uint16_t *dst16 =
-                                &pred[(i - p_row + k + 4) * p_stride + (j - p_col + l + 4)];
-                            int32_t tmp32 = *p;
+                            uint16_t *dst16 = &pred[(i - p_row + k + 4) * p_stride + (j - p_col + l + 4)];
+                            int32_t   tmp32 = *p;
                             if (conv_params->use_jnt_comp_avg) {
-                                tmp32 = tmp32 * conv_params->fwd_offset +
-                                    sum * conv_params->bck_offset;
+                                tmp32 = tmp32 * conv_params->fwd_offset + sum * conv_params->bck_offset;
                                 tmp32 = tmp32 >> DIST_PRECISION_BITS;
                             } else {
                                 tmp32 += sum;
@@ -956,10 +926,9 @@ void svt_av1_highbd_warp_affine_c(const int32_t *mat, const uint8_t *ref8b, cons
     }
 }
 
-void dec_svt_highbd_warp_plane(EbWarpedMotionParams *wm, const uint8_t *const ref8, int width,
-                               int height, int stride, const uint8_t *const pred8, int p_col,
-                               int p_row, int p_width, int p_height, int p_stride,
-                               int subsampling_x, int subsampling_y, int bd,
+void dec_svt_highbd_warp_plane(EbWarpedMotionParams *wm, const uint8_t *const ref8, int width, int height, int stride,
+                               const uint8_t *const pred8, int p_col, int p_row, int p_width, int p_height,
+                               int p_stride, int subsampling_x, int subsampling_y, int bd,
                                ConvolveParams *conv_params) {
     assert(wm->wmtype <= AFFINE);
     if (wm->wmtype == ROTZOOM) {
@@ -996,9 +965,8 @@ void dec_svt_highbd_warp_plane(EbWarpedMotionParams *wm, const uint8_t *const re
                                    gamma,
                                    delta);
 }
-void svt_highbd_warp_plane(EbWarpedMotionParams *wm, const uint8_t *const ref8,
-                           const uint8_t *const ref_2b, int width, int height, int stride,
-                           const uint8_t *const pred8, int p_col, int p_row, int p_width,
+void svt_highbd_warp_plane(EbWarpedMotionParams *wm, const uint8_t *const ref8, const uint8_t *const ref_2b, int width,
+                           int height, int stride, const uint8_t *const pred8, int p_col, int p_row, int p_width,
                            int p_height, int p_stride, int subsampling_x, int subsampling_y, int bd,
                            ConvolveParams *conv_params) {
     assert(wm->wmtype <= AFFINE);
@@ -1036,11 +1004,11 @@ void svt_highbd_warp_plane(EbWarpedMotionParams *wm, const uint8_t *const ref8,
                                delta);
 }
 
-void dec_svt_av1_warp_plane(EbWarpedMotionParams *wm, int use_hbd, int bd, const uint8_t *ref,
+void svt_aom_dec_svt_av1_warp_plane(EbWarpedMotionParams *wm, int use_hbd, int bd, const uint8_t *ref,
 
-                            int width, int height, int stride, uint8_t *pred, int p_col, int p_row,
-                            int p_width, int p_height, int p_stride, int subsampling_x,
-                            int subsampling_y, ConvolveParams *conv_params) {
+                                    int width, int height, int stride, uint8_t *pred, int p_col, int p_row, int p_width,
+                                    int p_height, int p_stride, int subsampling_x, int subsampling_y,
+                                    ConvolveParams *conv_params) {
     if (use_hbd)
         dec_svt_highbd_warp_plane(wm,
                                   ref,
@@ -1073,10 +1041,9 @@ void dec_svt_av1_warp_plane(EbWarpedMotionParams *wm, int use_hbd, int bd, const
                        subsampling_y,
                        conv_params);
 }
-void svt_av1_warp_plane(EbWarpedMotionParams *wm, int use_hbd, int bd, const uint8_t *ref,
-                        const uint8_t *ref_2b, int width, int height, int stride, uint8_t *pred,
-                        int p_col, int p_row, int p_width, int p_height, int p_stride,
-                        int subsampling_x, int subsampling_y, ConvolveParams *conv_params) {
+void svt_av1_warp_plane(EbWarpedMotionParams *wm, int use_hbd, int bd, const uint8_t *ref, const uint8_t *ref_2b,
+                        int width, int height, int stride, uint8_t *pred, int p_col, int p_row, int p_width,
+                        int p_height, int p_stride, int subsampling_x, int subsampling_y, ConvolveParams *conv_params) {
     if (use_hbd)
         svt_highbd_warp_plane(wm,
                               ref,
@@ -1124,18 +1091,12 @@ int svt_get_shear_params(EbWarpedMotionParams *wm) {
     wm->gamma = clamp((int)ROUND_POWER_OF_TWO_SIGNED_64(v, shift), INT16_MIN, INT16_MAX);
     v         = ((int64_t)mat[3] * mat[4]) * y;
     wm->delta = clamp(
-        mat[5] - (int)ROUND_POWER_OF_TWO_SIGNED_64(v, shift) - (1 << WARPEDMODEL_PREC_BITS),
-        INT16_MIN,
-        INT16_MAX);
+        mat[5] - (int)ROUND_POWER_OF_TWO_SIGNED_64(v, shift) - (1 << WARPEDMODEL_PREC_BITS), INT16_MIN, INT16_MAX);
 
-    wm->alpha = ROUND_POWER_OF_TWO_SIGNED(wm->alpha, WARP_PARAM_REDUCE_BITS) *
-        (1 << WARP_PARAM_REDUCE_BITS);
-    wm->beta = ROUND_POWER_OF_TWO_SIGNED(wm->beta, WARP_PARAM_REDUCE_BITS) *
-        (1 << WARP_PARAM_REDUCE_BITS);
-    wm->gamma = ROUND_POWER_OF_TWO_SIGNED(wm->gamma, WARP_PARAM_REDUCE_BITS) *
-        (1 << WARP_PARAM_REDUCE_BITS);
-    wm->delta = ROUND_POWER_OF_TWO_SIGNED(wm->delta, WARP_PARAM_REDUCE_BITS) *
-        (1 << WARP_PARAM_REDUCE_BITS);
+    wm->alpha = ROUND_POWER_OF_TWO_SIGNED(wm->alpha, WARP_PARAM_REDUCE_BITS) * (1 << WARP_PARAM_REDUCE_BITS);
+    wm->beta  = ROUND_POWER_OF_TWO_SIGNED(wm->beta, WARP_PARAM_REDUCE_BITS) * (1 << WARP_PARAM_REDUCE_BITS);
+    wm->gamma = ROUND_POWER_OF_TWO_SIGNED(wm->gamma, WARP_PARAM_REDUCE_BITS) * (1 << WARP_PARAM_REDUCE_BITS);
+    wm->delta = ROUND_POWER_OF_TWO_SIGNED(wm->delta, WARP_PARAM_REDUCE_BITS) * (1 << WARP_PARAM_REDUCE_BITS);
 
     if (!is_affine_shear_allowed(wm->alpha, wm->beta, wm->gamma, wm->delta))
         return 0;
@@ -1144,7 +1105,7 @@ int svt_get_shear_params(EbWarpedMotionParams *wm) {
 }
 
 // Select samples according to the motion vector difference.
-int select_samples(MV *mv, int *pts, int *pts_inref, int len, BlockSize bsize) {
+int svt_aom_select_samples(MV *mv, int *pts, int *pts_inref, int len, BlockSize bsize) {
     const uint8_t bw                          = block_size_wide[bsize];
     const uint8_t bh                          = block_size_high[bsize];
     const int     thresh                      = clamp(AOMMAX(bw, bh), 16, 112);
