@@ -31,7 +31,7 @@ static INLINE int16_t get_ac_quant(int32_t qindex, int32_t delta, EbBitDepth bit
 }
 
 // Called in read_frame_header_obu() -> av1_decode_frame_headers_and_setup() -> read_uncompressed_header()
-void setup_segmentation_dequant(DecModCtxt *dec_mod_ctxt) {
+void svt_aom_setup_segmentation_dequant(DecModCtxt *dec_mod_ctxt) {
     SeqHeader   *seq_header = dec_mod_ctxt->seq_header;
     FrameHeader *frame_info = dec_mod_ctxt->frame_header;
     int          bit_depth  = seq_header->color_config.bit_depth;
@@ -39,22 +39,20 @@ void setup_segmentation_dequant(DecModCtxt *dec_mod_ctxt) {
         MAX_SEGMENTS : 1;*/
     int32_t dc_delta_q, ac_delta_q;
     for (int i = 0; i < MAX_SEGMENTS; i++) {
-        const int qindex = get_qindex(
+        const int qindex = svt_aom_get_qindex(
             &frame_info->segmentation_params, i, frame_info->quantization_params.base_q_idx);
 
         for (int plane = 0; plane < MAX_MB_PLANE; plane++) {
             dc_delta_q = frame_info->quantization_params.delta_q_dc[plane];
             ac_delta_q = frame_info->quantization_params.delta_q_ac[plane];
 
-            dec_mod_ctxt->dequants.dequant_qtx[i][plane][0] = get_dc_quant(
-                qindex, dc_delta_q, bit_depth);
-            dec_mod_ctxt->dequants.dequant_qtx[i][plane][1] = get_ac_quant(
-                qindex, ac_delta_q, bit_depth);
+            dec_mod_ctxt->dequants.dequant_qtx[i][plane][0] = get_dc_quant(qindex, dc_delta_q, bit_depth);
+            dec_mod_ctxt->dequants.dequant_qtx[i][plane][1] = get_ac_quant(qindex, ac_delta_q, bit_depth);
         }
     }
 }
 
-void av1_inverse_qm_init(DecModCtxt *dec_mod_ctxt, SeqHeader *seq_header) {
+void svt_aom_inverse_qm_init(DecModCtxt *dec_mod_ctxt, SeqHeader *seq_header) {
     const int num_planes = av1_num_planes(&seq_header->color_config);
     int       q, c;
     uint8_t   t;
@@ -90,7 +88,7 @@ void av1_init_sb(FrameHeader *frame)
 
 // Called in parse_decode_block()
 // Update de-quantization parameter based on delta qp param
-void update_dequant(DecModCtxt *dec_mod_ctxt, SBInfo *sb_info) {
+void svt_aom_update_dequant(DecModCtxt *dec_mod_ctxt, SBInfo *sb_info) {
     SeqHeader   *seq_header = dec_mod_ctxt->seq_header;
     FrameHeader *frame      = dec_mod_ctxt->frame_header;
 
@@ -98,8 +96,7 @@ void update_dequant(DecModCtxt *dec_mod_ctxt, SBInfo *sb_info) {
     dec_mod_ctxt->dequants_delta_q = &dec_mod_ctxt->dequants;
     if (frame->delta_q_params.delta_q_present) {
         for (int i = 0; i < MAX_SEGMENTS; i++) {
-            const int current_qindex = get_qindex(
-                &frame->segmentation_params, i, sb_info->sb_delta_q[0]);
+            const int current_qindex = svt_aom_get_qindex(&frame->segmentation_params, i, sb_info->sb_delta_q[0]);
 
             for (int plane = 0; plane < MAX_MB_PLANE; plane++) {
                 const int dc_delta_q = frame->quantization_params.delta_q_dc[plane];
@@ -121,27 +118,24 @@ static INLINE int get_dqv(const int16_t dequant, int coeff_idx, const QmVal *iqm
     return dqv;
 }
 
-int32_t inverse_quantize(DecModCtxt *dec_mod_ctxt, PartitionInfo *part, BlockModeInfo *mode,
-                         int32_t *level, int32_t *qcoeffs, TxType tx_type, TxSize tx_size,
-                         int plane) {
+int32_t svt_aom_inverse_quantize(DecModCtxt *dec_mod_ctxt, PartitionInfo *part, BlockModeInfo *mode, int32_t *level,
+                                 int32_t *qcoeffs, TxType tx_type, TxSize tx_size, int plane) {
     (void)part;
-    SeqHeader             *seq   = dec_mod_ctxt->seq_header;
-    FrameHeader           *frame = dec_mod_ctxt->frame_header;
-    const ScanOrder *const scan_order =
-        &av1_scan_orders[tx_size][tx_type]; //get_scan(tx_size, tx_type);
-    const int16_t *scan      = scan_order->scan;
-    const int32_t  max_value = (1 << (7 + seq->color_config.bit_depth)) - 1;
-    const int32_t  min_value = -(1 << (7 + seq->color_config.bit_depth));
-    int            n_coeffs, i, pos, qmlevel;
-    int16_t       *dequant;
-    const QmVal   *iqmatrix;
-    const TxSize   qm_tx_size = av1_get_adjusted_tx_size(tx_size);
+    SeqHeader             *seq        = dec_mod_ctxt->seq_header;
+    FrameHeader           *frame      = dec_mod_ctxt->frame_header;
+    const ScanOrder *const scan_order = &av1_scan_orders[tx_size][tx_type]; //get_scan(tx_size, tx_type);
+    const int16_t         *scan       = scan_order->scan;
+    const int32_t          max_value  = (1 << (7 + seq->color_config.bit_depth)) - 1;
+    const int32_t          min_value  = -(1 << (7 + seq->color_config.bit_depth));
+    int                    n_coeffs, i, pos, qmlevel;
+    int16_t               *dequant;
+    const QmVal           *iqmatrix;
+    const TxSize           qm_tx_size = av1_get_adjusted_tx_size(tx_size);
 
     int using_qm    = frame->quantization_params.using_qmatrix;
     int lossless    = frame->lossless_array[mode->segment_id];
     dequant         = dec_mod_ctxt->dequants_delta_q->dequant_qtx[mode->segment_id][plane];
-    qmlevel         = (lossless || using_qm == 0) ? NUM_QM_LEVELS - 1
-                                                  : frame->quantization_params.qm[plane];
+    qmlevel         = (lossless || using_qm == 0) ? NUM_QM_LEVELS - 1 : frame->quantization_params.qm[plane];
     iqmatrix        = IS_2D_TRANSFORM(tx_type) ? dec_mod_ctxt->giqmatrix[qmlevel][plane][qm_tx_size]
                                                : dec_mod_ctxt->giqmatrix[NUM_QM_LEVELS - 1][0][qm_tx_size];
     const int shift = av1_get_tx_scale(tx_size);
