@@ -30,12 +30,12 @@ Contains the Decoder Loop Filtering related functions*/
 /*4-> 0   6-> 1   8-> 2   14->3 */
 static int8_t filter_map[15] = {-1, -1, -1, -1, 0, -1, 1, -1, 2, -1, -1, -1, -1, -1, 3};
 
-SvtLbdFilterTapFn lbd_vert_filter_tap[FILTER_LEN];
-SvtHbdFilterTapFn hbd_vert_filter_tap[FILTER_LEN];
-SvtLbdFilterTapFn lbd_horz_filter_tap[FILTER_LEN];
-SvtHbdFilterTapFn hbd_horz_filter_tap[FILTER_LEN];
+static SvtLbdFilterTapFn lbd_vert_filter_tap[FILTER_LEN];
+static SvtHbdFilterTapFn hbd_vert_filter_tap[FILTER_LEN];
+static SvtLbdFilterTapFn lbd_horz_filter_tap[FILTER_LEN];
+static SvtHbdFilterTapFn hbd_horz_filter_tap[FILTER_LEN];
 
-void set_lbd_lf_filter_tap_functions(void) {
+void svt_aom_set_lbd_lf_filter_tap_functions(void) {
     lbd_horz_filter_tap[0] = svt_aom_lpf_horizontal_4;
     lbd_horz_filter_tap[1] = svt_aom_lpf_horizontal_6;
     lbd_horz_filter_tap[2] = svt_aom_lpf_horizontal_8;
@@ -47,7 +47,7 @@ void set_lbd_lf_filter_tap_functions(void) {
     lbd_vert_filter_tap[3] = svt_aom_lpf_vertical_14;
 }
 
-void set_hbd_lf_filter_tap_functions(void) {
+void svt_aom_set_hbd_lf_filter_tap_functions(void) {
     hbd_horz_filter_tap[0] = svt_aom_highbd_lpf_horizontal_4;
     hbd_horz_filter_tap[1] = svt_aom_highbd_lpf_horizontal_6;
     hbd_horz_filter_tap[2] = svt_aom_highbd_lpf_horizontal_8;
@@ -60,8 +60,8 @@ void set_hbd_lf_filter_tap_functions(void) {
 }
 
 /*Population of neighbour block lf params for each 4x4 block*/
-void fill_4x4_lf_param(LfCtxt *lf_ctxt, int32_t tu_x, int32_t tu_y, int32_t stride, TxSize tx_size,
-                       int32_t sub_x, int32_t sub_y, int plane) {
+void svt_aom_fill_4x4_lf_param(LfCtxt *lf_ctxt, int32_t tu_x, int32_t tu_y, int32_t stride, TxSize tx_size,
+                               int32_t sub_x, int32_t sub_y, int plane) {
     /*Population of chroma info is done at 4x4
     to be sync with all other luma population*/
     const int txw       = tx_size_wide_unit[tx_size] << sub_x;
@@ -101,11 +101,12 @@ static INLINE TxSize dec_get_transform_size(const EdgeDir edge_dir, TxSize tx_si
 
 /*Return TxSize from get_transform_size(), so it is plane and direction
  awared*/
-static AOM_FORCE_INLINE TxSize dec_set_lpf_parameters(
-    Av1DeblockingParameters *const params, FrameHeader *frm_hdr, EbColorConfig *color_config,
-    BlockModeInfo *mi_cur, BlockModeInfo *mi_near, LfCtxt *lf_ctxt, const EdgeDir edge_dir,
-    const uint32_t x, const uint32_t y, const int32_t plane, int32_t *sb_delta_lf,
-    int32_t *sb_delta_lf_prev, int32_t *min_tx_dim) {
+static AOM_FORCE_INLINE TxSize dec_set_lpf_parameters(Av1DeblockingParameters *const params, FrameHeader *frm_hdr,
+                                                      EbColorConfig *color_config, BlockModeInfo *mi_cur,
+                                                      BlockModeInfo *mi_near, LfCtxt *lf_ctxt, const EdgeDir edge_dir,
+                                                      const uint32_t x, const uint32_t y, const int32_t plane,
+                                                      int32_t *sb_delta_lf, int32_t *sb_delta_lf_prev,
+                                                      int32_t *min_tx_dim) {
     LoopFilterInfoN *lf_info = &lf_ctxt->lf_info;
 
     /*reset to initial values*/
@@ -148,8 +149,7 @@ static AOM_FORCE_INLINE TxSize dec_set_lpf_parameters(
 
     {
         const uint32_t coord           = (VERT_EDGE == edge_dir) ? (x >> sub_x) : (y >> sub_y);
-        const uint32_t transform_masks = edge_dir == VERT_EDGE ? tx_size_wide[ts] - 1
-                                                               : tx_size_high[ts] - 1;
+        const uint32_t transform_masks = edge_dir == VERT_EDGE ? tx_size_wide[ts] - 1 : tx_size_high[ts] - 1;
         const int32_t  txb_edge        = (coord & transform_masks) ? (0) : (1);
 
         if (!txb_edge)
@@ -157,32 +157,23 @@ static AOM_FORCE_INLINE TxSize dec_set_lpf_parameters(
         /*prepare outer edge parameters. deblock the edge if it's an edge of a TU*/
         {
             uint32_t       curr_level; // Added to address 4x4 problem
-            PredictionMode mode = (mi_cur->mode == INTRA_MODE_4x4) ? DC_PRED : mi_cur->mode;
+            PredictionMode mode = mi_cur->mode;
             if (frm_hdr->delta_lf_params.delta_lf_present)
-                curr_level = get_filter_level_delta_lf(frm_hdr,
-                                                       edge_dir,
-                                                       plane,
-                                                       sb_delta_lf,
-                                                       mi_cur->segment_id,
-                                                       mode,
-                                                       mi_cur->ref_frame[0]);
+                curr_level = svt_aom_get_filter_level_delta_lf(
+                    frm_hdr, edge_dir, plane, sb_delta_lf, mi_cur->segment_id, mode, mi_cur->ref_frame[0]);
             else
-                curr_level = lf_info->lvl[plane][mi_cur->segment_id][edge_dir][mi_cur->ref_frame[0]]
-                                         [mode_lf_lut[mode]];
+                curr_level = lf_info->lvl[plane][mi_cur->segment_id][edge_dir][mi_cur->ref_frame[0]][mode_lf_lut[mode]];
 
-            const int32_t curr_skipped = mi_cur->skip &&
-                is_inter_block_no_intrabc(mi_cur->ref_frame[0]);
+            const int32_t curr_skipped = mi_cur->skip && is_inter_block_no_intrabc(mi_cur->ref_frame[0]);
 
             uint32_t level = curr_level;
             if (coord) {
                 /* Since block are alligned at 8x8 boundary , so prev block
                     will be cur - 1<<sub_x */
-                TxSize *lf_tx_l_prev  = (VERT_EDGE == edge_dir)
-                     ? lf_tx_l_cur - (uint64_t)(1 << sub_x)
-                     : lf_tx_l_cur - (lf_stride << sub_y);
-                TxSize *lf_tx_uv_prev = (VERT_EDGE == edge_dir)
-                    ? lf_tx_uv_cur - (uint64_t)(1 << sub_x)
-                    : lf_tx_uv_cur - (lf_stride << sub_y);
+                TxSize *lf_tx_l_prev  = (VERT_EDGE == edge_dir) ? lf_tx_l_cur - (uint64_t)(1 << sub_x)
+                                                                : lf_tx_l_cur - (lf_stride << sub_y);
+                TxSize *lf_tx_uv_prev = (VERT_EDGE == edge_dir) ? lf_tx_uv_cur - (uint64_t)(1 << sub_x)
+                                                                : lf_tx_uv_cur - (lf_stride << sub_y);
 
                 if (lf_tx_l_prev == NULL)
                     return TX_INVALID;
@@ -199,22 +190,16 @@ static AOM_FORCE_INLINE TxSize dec_set_lpf_parameters(
                 *min_tx_dim         = AOMMIN(*min_tx_dim, prev_ts_dim);
 
                 uint32_t pv_lvl;
-                mode = (mi_near->mode == INTRA_MODE_4x4) ? DC_PRED : mi_near->mode;
+                mode = mi_near->mode;
                 if (frm_hdr->delta_lf_params.delta_lf_present)
-                    pv_lvl = get_filter_level_delta_lf(frm_hdr,
-                                                       edge_dir,
-                                                       plane,
-                                                       sb_delta_lf_prev,
-                                                       mi_near->segment_id,
-                                                       mode,
-                                                       mi_near->ref_frame[0]);
+                    pv_lvl = svt_aom_get_filter_level_delta_lf(
+                        frm_hdr, edge_dir, plane, sb_delta_lf_prev, mi_near->segment_id, mode, mi_near->ref_frame[0]);
                 else
-                    pv_lvl = lf_info->lvl[plane][mi_near->segment_id][edge_dir]
-                                         [mi_near->ref_frame[0]][mode_lf_lut[mode]];
+                    pv_lvl =
+                        lf_info->lvl[plane][mi_near->segment_id][edge_dir][mi_near->ref_frame[0]][mode_lf_lut[mode]];
 
-                const int32_t pv_skip = mi_near->skip &&
-                    is_inter_block_no_intrabc(mi_near->ref_frame[0]);
-                const BlockSize bsize = get_plane_block_size(mi_near->sb_type, sub_x, sub_y);
+                const int32_t   pv_skip = mi_near->skip && is_inter_block_no_intrabc(mi_near->ref_frame[0]);
+                const BlockSize bsize   = get_plane_block_size(mi_near->bsize, sub_x, sub_y);
                 assert(bsize < BlockSizeS_ALL);
                 const int32_t prediction_masks = edge_dir == VERT_EDGE ? block_size_wide[bsize] - 1
                                                                        : block_size_high[bsize] - 1;
@@ -255,14 +240,13 @@ static AOM_FORCE_INLINE TxSize dec_set_lpf_parameters(
 }
 
 /*It applies Vertical Loop Filtering in a superblock*/
-void dec_av1_filter_block_plane_vert(EbDecHandle *dec_handle, SBInfo *sb_info,
-                                     EbPictureBufferDesc *recon_picture_buf, LfCtxt *lf_ctxt,
-                                     const int32_t num_planes, const int32_t sb_mi_row,
-                                     const int32_t sb_mi_col, int32_t *sb_delta_lf) {
-    FrameHeader *  frm_hdr      = &dec_handle->frame_header;
+static void dec_av1_filter_block_plane_vert(EbDecHandle *dec_handle, SBInfo *sb_info,
+                                            EbPictureBufferDesc *recon_picture_buf, LfCtxt *lf_ctxt,
+                                            const int32_t num_planes, const int32_t sb_mi_row, const int32_t sb_mi_col,
+                                            int32_t *sb_delta_lf) {
+    FrameHeader   *frm_hdr      = &dec_handle->frame_header;
     EbColorConfig *color_config = &dec_handle->seq_header.color_config;
-    EbBitDepthEnum is16bit      = (recon_picture_buf->bit_depth > EB_8BIT ||
-                              dec_handle->is_16bit_pipeline);
+    EbBitDepth     is16bit      = (recon_picture_buf->bit_depth > EB_EIGHT_BIT || dec_handle->is_16bit_pipeline);
     int32_t        sub_x        = color_config->subsampling_x;
     int32_t        sub_y        = color_config->subsampling_y;
     uint8_t        no_lf_luma   = !(frm_hdr->loop_filter_params.filter_level[0]) &&
@@ -270,7 +254,7 @@ void dec_av1_filter_block_plane_vert(EbDecHandle *dec_handle, SBInfo *sb_info,
     uint8_t no_lf_u = !(frm_hdr->loop_filter_params.filter_level_u);
     uint8_t no_lf_v = !(frm_hdr->loop_filter_params.filter_level_v);
 
-    void *   blk_recon_buf;
+    void    *blk_recon_buf;
     int32_t  recon_stride;
     int32_t *sb_delta_lf_left;
 
@@ -280,13 +264,13 @@ void dec_av1_filter_block_plane_vert(EbDecHandle *dec_handle, SBInfo *sb_info,
     uint32_t mi_cols = (&dec_handle->frame_header)->mi_cols;
     uint32_t mi_rows = (&dec_handle->frame_header)->mi_rows;
 
-    BlockModeInfo *mode_info = get_cur_mode_info(dec_handle, sb_mi_row, sb_mi_col, sb_info);
+    BlockModeInfo *mode_info = svt_aom_get_cur_mode_info(dec_handle, sb_mi_row, sb_mi_col, sb_info);
 
     int n_blocks = sb_info->num_block;
     for (int sub_blck = 0; sub_blck < n_blocks; sub_blck++) {
         int32_t   blk_mi_row = sb_mi_row + mode_info->mi_row_in_sb;
         int32_t   blk_mi_col = sb_mi_col + mode_info->mi_col_in_sb;
-        BlockSize bsize      = mode_info->sb_type;
+        BlockSize bsize      = mode_info->bsize;
 
         int32_t bw4               = mi_size_wide[bsize];
         int32_t bh4               = mi_size_high[bsize];
@@ -320,8 +304,7 @@ void dec_av1_filter_block_plane_vert(EbDecHandle *dec_handle, SBInfo *sb_info,
             sub_y = (plane > 0) ? color_config->subsampling_y : 0;
 
             trans_info = (plane == 2)
-                ? (sb_info->sb_trans_info[plane - 1] + mode_info->first_txb_offset[plane - 1] +
-                   num_chroma_tus)
+                ? (sb_info->sb_trans_info[plane - 1] + mode_info->first_txb_offset[plane - 1] + num_chroma_tus)
                 : (sb_info->sb_trans_info[plane] + mode_info->first_txb_offset[plane]);
 
             if (lossless_block) {
@@ -331,14 +314,14 @@ void dec_av1_filter_block_plane_vert(EbDecHandle *dec_handle, SBInfo *sb_info,
             } else
                 num_tu = mode_info->num_tus[!!plane];
 
-            derive_blk_pointers(recon_picture_buf,
-                                plane,
-                                ((blk_mi_col >> sub_x) * MI_SIZE),
-                                ((blk_mi_row >> sub_y) * MI_SIZE),
-                                &blk_recon_buf,
-                                &recon_stride,
-                                sub_x,
-                                sub_y);
+            svt_aom_derive_blk_pointers(recon_picture_buf,
+                                        plane,
+                                        ((blk_mi_col >> sub_x) * MI_SIZE),
+                                        ((blk_mi_row >> sub_y) * MI_SIZE),
+                                        &blk_recon_buf,
+                                        &recon_stride,
+                                        sub_x,
+                                        sub_y);
 
             BlockModeInfo *mi_left = mode_info;
 
@@ -346,7 +329,7 @@ void dec_av1_filter_block_plane_vert(EbDecHandle *dec_handle, SBInfo *sb_info,
             memset(&params, 0, sizeof(params));
 
             for (uint32_t tu = 0; tu < num_tu; tu++) {
-                void *  tu_recon_buf;
+                void   *tu_recon_buf;
                 int32_t tu_offset;
                 TxSize  cur_tx_size;
                 int32_t cur_txh, min_txh;
@@ -354,8 +337,7 @@ void dec_av1_filter_block_plane_vert(EbDecHandle *dec_handle, SBInfo *sb_info,
                 cur_tx_size = trans_info->tx_size;
                 cur_txh     = tx_size_high_unit[cur_tx_size];
 
-                tu_offset = (trans_info->txb_y_offset * recon_stride + trans_info->txb_x_offset)
-                    << MI_SIZE_LOG2;
+                tu_offset    = (trans_info->txb_y_offset * recon_stride + trans_info->txb_x_offset) << MI_SIZE_LOG2;
                 tu_recon_buf = (void *)((uint8_t *)blk_recon_buf + (tu_offset << is16bit));
 
                 uint8_t *p = (uint8_t *)tu_recon_buf;
@@ -376,8 +358,7 @@ void dec_av1_filter_block_plane_vert(EbDecHandle *dec_handle, SBInfo *sb_info,
                 int32_t left_mi_col = (blk_mi_col & (~sub_x)) + (trans_info->txb_x_offset << sub_x);
 
                 /* For VERT_EDGE edge and x_range is for SB scan */
-                sb_delta_lf_left = (left_mi_col == sb_mi_col) ? sb_delta_lf - FRAME_LF_COUNT
-                                                              : sb_delta_lf;
+                sb_delta_lf_left = (left_mi_col == sb_mi_col) ? sb_delta_lf - FRAME_LF_COUNT : sb_delta_lf;
 
                 min_txh = cur_txh;
                 for (int32_t temp_txh = 0; temp_txh < cur_txh; temp_txh += min_txh) {
@@ -385,7 +366,7 @@ void dec_av1_filter_block_plane_vert(EbDecHandle *dec_handle, SBInfo *sb_info,
                         memset(&params, 0, sizeof(params));
 
                     if (left_mi_col > 0) {
-                        mi_left = get_left_mode_info(dec_handle, left_mi_row, left_mi_col, sb_info);
+                        mi_left = svt_aom_get_left_mode_info(dec_handle, left_mi_row, left_mi_col, sb_info);
                     }
 
                     cur_tx_size = dec_set_lpf_parameters(&params,
@@ -418,13 +399,12 @@ void dec_av1_filter_block_plane_vert(EbDecHandle *dec_handle, SBInfo *sb_info,
                         int8_t filter_idx = filter_map[params.filter_length];
                         if (filter_idx != -1) {
                             if (is16bit)
-                                hbd_vert_filter_tap[filter_idx](
-                                    (uint16_t *)(p), //CONVERT_TO_SHORTPTR(p),
-                                    recon_stride,
-                                    params.mblim,
-                                    params.lim,
-                                    params.hev_thr,
-                                    recon_picture_buf->bit_depth);
+                                hbd_vert_filter_tap[filter_idx]((uint16_t *)(p), //CONVERT_TO_SHORTPTR(p),
+                                                                recon_stride,
+                                                                params.mblim,
+                                                                params.lim,
+                                                                params.hev_thr,
+                                                                recon_picture_buf->bit_depth);
                             else
                                 lbd_vert_filter_tap[filter_idx](
                                     p, recon_stride, params.mblim, params.lim, params.hev_thr);
@@ -441,14 +421,14 @@ void dec_av1_filter_block_plane_vert(EbDecHandle *dec_handle, SBInfo *sb_info,
     }
 }
 
-void dec_av1_filter_block_plane_horz(EbDecHandle *dec_handle, SBInfo *sb_info,
-                                     EbPictureBufferDesc *recon_picture_buf, LfCtxt *lf_ctxt,
-                                     const int32_t num_planes, const int32_t sb_mi_row,
-                                     const uint32_t sb_mi_col, int32_t *sb_delta_lf) {
-    FrameHeader *  frm_hdr      = &dec_handle->frame_header;
+static void dec_av1_filter_block_plane_horz(EbDecHandle *dec_handle, SBInfo *sb_info,
+                                            EbPictureBufferDesc *recon_picture_buf, LfCtxt *lf_ctxt,
+                                            const int32_t num_planes, const int32_t sb_mi_row, const uint32_t sb_mi_col,
+                                            int32_t *sb_delta_lf) {
+    FrameHeader   *frm_hdr      = &dec_handle->frame_header;
     EbColorConfig *color_config = &dec_handle->seq_header.color_config;
 
-    EbBool is16bit = (recon_picture_buf->bit_depth > EB_8BIT || dec_handle->is_16bit_pipeline);
+    Bool is16bit = (recon_picture_buf->bit_depth > EB_EIGHT_BIT || dec_handle->is_16bit_pipeline);
 
     int32_t sub_x = color_config->subsampling_x;
     int32_t sub_y = color_config->subsampling_y;
@@ -458,7 +438,7 @@ void dec_av1_filter_block_plane_horz(EbDecHandle *dec_handle, SBInfo *sb_info,
     uint8_t no_lf_u = !(frm_hdr->loop_filter_params.filter_level_u);
     uint8_t no_lf_v = !(frm_hdr->loop_filter_params.filter_level_v);
 
-    void *   blk_recon_buf;
+    void    *blk_recon_buf;
     int32_t  recon_stride;
     int32_t *sb_delta_lf_above;
 
@@ -468,12 +448,12 @@ void dec_av1_filter_block_plane_horz(EbDecHandle *dec_handle, SBInfo *sb_info,
     uint32_t mi_cols = (&dec_handle->frame_header)->mi_cols;
     uint32_t mi_rows = (&dec_handle->frame_header)->mi_rows;
 
-    BlockModeInfo *mode_info = get_cur_mode_info(dec_handle, sb_mi_row, sb_mi_col, sb_info);
+    BlockModeInfo *mode_info = svt_aom_get_cur_mode_info(dec_handle, sb_mi_row, sb_mi_col, sb_info);
     int            n_blocks  = sb_info->num_block;
     for (int sub_blck = 0; sub_blck < n_blocks; sub_blck++) {
         int32_t   blk_mi_row = sb_mi_row + mode_info->mi_row_in_sb;
         int32_t   blk_mi_col = sb_mi_col + mode_info->mi_col_in_sb;
-        BlockSize bsize      = mode_info->sb_type;
+        BlockSize bsize      = mode_info->bsize;
 
         int32_t bw4               = mi_size_wide[bsize];
         int32_t bh4               = mi_size_high[bsize];
@@ -492,9 +472,9 @@ void dec_av1_filter_block_plane_horz(EbDecHandle *dec_handle, SBInfo *sb_info,
         max_blocks_wide = max_blocks_wide >> tx_size_wide_log2[0];
         max_blocks_high = max_blocks_high >> tx_size_high_log2[0];
 
-        int num_chroma_tus = lossless_block ? (max_blocks_wide * max_blocks_high) >>
-                (color_config->subsampling_x + color_config->subsampling_y)
-                                            : mode_info->num_tus[AOM_PLANE_U];
+        int num_chroma_tus = lossless_block
+            ? (max_blocks_wide * max_blocks_high) >> (color_config->subsampling_x + color_config->subsampling_y)
+            : mode_info->num_tus[AOM_PLANE_U];
 
         for (int plane = 0; plane < num_planes; ++plane) {
             if ((plane == 0) && no_lf_luma)
@@ -508,8 +488,7 @@ void dec_av1_filter_block_plane_horz(EbDecHandle *dec_handle, SBInfo *sb_info,
             sub_y = (plane > 0) ? color_config->subsampling_y : 0;
 
             trans_info = (plane == 2)
-                ? (sb_info->sb_trans_info[plane - 1] + mode_info->first_txb_offset[plane - 1] +
-                   num_chroma_tus)
+                ? (sb_info->sb_trans_info[plane - 1] + mode_info->first_txb_offset[plane - 1] + num_chroma_tus)
                 : (sb_info->sb_trans_info[plane] + mode_info->first_txb_offset[plane]);
 
             if (lossless_block) {
@@ -518,14 +497,14 @@ void dec_av1_filter_block_plane_horz(EbDecHandle *dec_handle, SBInfo *sb_info,
             } else
                 num_tu = mode_info->num_tus[!!plane];
 
-            derive_blk_pointers(recon_picture_buf,
-                                plane,
-                                ((blk_mi_col >> sub_x) * MI_SIZE),
-                                ((blk_mi_row >> sub_y) * MI_SIZE),
-                                &blk_recon_buf,
-                                &recon_stride,
-                                sub_x,
-                                sub_y);
+            svt_aom_derive_blk_pointers(recon_picture_buf,
+                                        plane,
+                                        ((blk_mi_col >> sub_x) * MI_SIZE),
+                                        ((blk_mi_row >> sub_y) * MI_SIZE),
+                                        &blk_recon_buf,
+                                        &recon_stride,
+                                        sub_x,
+                                        sub_y);
 
             BlockModeInfo *mi_top = mode_info;
 
@@ -533,7 +512,7 @@ void dec_av1_filter_block_plane_horz(EbDecHandle *dec_handle, SBInfo *sb_info,
             memset(&params, 0, sizeof(params));
 
             for (uint32_t tu = 0; tu < num_tu; tu++) {
-                void *  tu_recon_buf;
+                void   *tu_recon_buf;
                 int32_t tu_offset;
                 TxSize  cur_tx_size;
                 int     cur_txw, min_txw;
@@ -541,8 +520,7 @@ void dec_av1_filter_block_plane_horz(EbDecHandle *dec_handle, SBInfo *sb_info,
                 cur_tx_size = trans_info->tx_size;
                 cur_txw     = tx_size_wide_unit[cur_tx_size];
 
-                tu_offset = (trans_info->txb_y_offset * recon_stride + trans_info->txb_x_offset)
-                    << MI_SIZE_LOG2;
+                tu_offset    = (trans_info->txb_y_offset * recon_stride + trans_info->txb_x_offset) << MI_SIZE_LOG2;
                 tu_recon_buf = (void *)((uint8_t *)blk_recon_buf + (tu_offset << is16bit));
 
                 uint8_t *p = (uint8_t *)tu_recon_buf;
@@ -562,9 +540,7 @@ void dec_av1_filter_block_plane_horz(EbDecHandle *dec_handle, SBInfo *sb_info,
                 int32_t left_mi_col = (blk_mi_col | sub_x) + (trans_info->txb_x_offset << sub_x);
 
                 /* For VERT_EDGE edge and x_range is for SB scan */
-                sb_delta_lf_above = (left_mi_row == sb_mi_row)
-                    ? sb_delta_lf - lf_ctxt->delta_lf_stride
-                    : sb_delta_lf;
+                sb_delta_lf_above = (left_mi_row == sb_mi_row) ? sb_delta_lf - lf_ctxt->delta_lf_stride : sb_delta_lf;
 
                 min_txw = cur_txw;
                 for (int temp_txw = 0; temp_txw < cur_txw; temp_txw += min_txw) {
@@ -572,7 +548,7 @@ void dec_av1_filter_block_plane_horz(EbDecHandle *dec_handle, SBInfo *sb_info,
                         memset(&params, 0, sizeof(params));
 
                     if (left_mi_row > 0)
-                        mi_top = get_top_mode_info(dec_handle, left_mi_row, left_mi_col, sb_info);
+                        mi_top = svt_aom_get_top_mode_info(dec_handle, left_mi_row, left_mi_col, sb_info);
 
                     cur_tx_size = dec_set_lpf_parameters(&params,
                                                          frm_hdr,
@@ -605,13 +581,12 @@ void dec_av1_filter_block_plane_horz(EbDecHandle *dec_handle, SBInfo *sb_info,
 
                         if (filter_idx != -1) {
                             if (is16bit)
-                                hbd_horz_filter_tap[filter_idx](
-                                    (uint16_t *)(p), //CONVERT_TO_SHORTPTR(p),
-                                    recon_stride,
-                                    params.mblim,
-                                    params.lim,
-                                    params.hev_thr,
-                                    recon_picture_buf->bit_depth);
+                                hbd_horz_filter_tap[filter_idx]((uint16_t *)(p), //CONVERT_TO_SHORTPTR(p),
+                                                                recon_stride,
+                                                                params.mblim,
+                                                                params.lim,
+                                                                params.hev_thr,
+                                                                recon_picture_buf->bit_depth);
                             else
                                 lbd_horz_filter_tap[filter_idx](
                                     p, recon_stride, params.mblim, params.lim, params.hev_thr);
@@ -629,23 +604,16 @@ void dec_av1_filter_block_plane_horz(EbDecHandle *dec_handle, SBInfo *sb_info,
 }
 
 /*LF function to filter each SB*/
-void dec_loop_filter_sb(EbDecHandle *dec_handle, SBInfo *sb_info, FrameHeader *frm_hdr,
-                        SeqHeader *seq_header, EbPictureBufferDesc *recon_picture_buf,
-                        LfCtxt *lf_ctxt, const int32_t mi_row, const int32_t mi_col,
-                        int32_t plane_start, int32_t plane_end, uint8_t last_col,
-                        int32_t *sb_delta_lf) {
+static void dec_loop_filter_sb(EbDecHandle *dec_handle, SBInfo *sb_info, FrameHeader *frm_hdr, SeqHeader *seq_header,
+                               EbPictureBufferDesc *recon_picture_buf, LfCtxt *lf_ctxt, const int32_t mi_row,
+                               const int32_t mi_col, int32_t plane_start, int32_t plane_end, uint8_t last_col,
+                               int32_t *sb_delta_lf) {
     int num_planes = plane_end - plane_start;
     if (frm_hdr->loop_filter_params.combine_vert_horz_lf) {
         /*filter all vertical and horizontal edges in every 64x64 super block
          filter vertical edges*/
-        dec_av1_filter_block_plane_vert(dec_handle,
-                                        sb_info,
-                                        recon_picture_buf,
-                                        lf_ctxt,
-                                        num_planes,
-                                        mi_row,
-                                        mi_col,
-                                        sb_delta_lf);
+        dec_av1_filter_block_plane_vert(
+            dec_handle, sb_info, recon_picture_buf, lf_ctxt, num_planes, mi_row, mi_col, sb_delta_lf);
 
         /*filter horizontal edges*/
         int32_t max_mib_size = seq_header->sb_size == BLOCK_128X128 ? MAX_MIB_SIZE : SB64_MIB_SIZE;
@@ -663,66 +631,44 @@ void dec_loop_filter_sb(EbDecHandle *dec_handle, SBInfo *sb_info, FrameHeader *f
 
         /*Filter the horizontal edges of the last sb in each row*/
         if (last_col) {
-            dec_av1_filter_block_plane_horz(dec_handle,
-                                            sb_info,
-                                            recon_picture_buf,
-                                            lf_ctxt,
-                                            num_planes,
-                                            mi_row,
-                                            mi_col,
-                                            sb_delta_lf);
+            dec_av1_filter_block_plane_horz(
+                dec_handle, sb_info, recon_picture_buf, lf_ctxt, num_planes, mi_row, mi_col, sb_delta_lf);
         }
     } else {
         /*filter all vertical edges in every 64x64 super block*/
-        dec_av1_filter_block_plane_vert(dec_handle,
-                                        sb_info,
-                                        recon_picture_buf,
-                                        lf_ctxt,
-                                        num_planes,
-                                        mi_row,
-                                        mi_col,
-                                        sb_delta_lf);
+        dec_av1_filter_block_plane_vert(
+            dec_handle, sb_info, recon_picture_buf, lf_ctxt, num_planes, mi_row, mi_col, sb_delta_lf);
 
         /*filter all horizontal edges in every 64x64 super block*/
-        dec_av1_filter_block_plane_horz(dec_handle,
-                                        sb_info,
-                                        recon_picture_buf,
-                                        lf_ctxt,
-                                        num_planes,
-                                        mi_row,
-                                        mi_col,
-                                        sb_delta_lf);
+        dec_av1_filter_block_plane_horz(
+            dec_handle, sb_info, recon_picture_buf, lf_ctxt, num_planes, mi_row, mi_col, sb_delta_lf);
     }
 }
 
 /* Row level function to trigger loop filter for each superblock*/
-void dec_loop_filter_row(EbDecHandle *dec_handle_ptr, EbPictureBufferDesc *recon_picture_buf,
-                         LfCtxt *lf_ctxt, uint32_t y_sb_index, int32_t plane_start,
-                         int32_t plane_end) {
+void svt_aom_dec_loop_filter_row(EbDecHandle *dec_handle_ptr, EbPictureBufferDesc *recon_picture_buf, LfCtxt *lf_ctxt,
+                                 uint32_t y_sb_index, int32_t plane_start, int32_t plane_end) {
     MainFrameBuf *main_frame_buf  = &dec_handle_ptr->main_frame_buf;
-    CurFrameBuf * frame_buf       = &main_frame_buf->cur_frame_bufs[0];
-    FrameHeader * frm_hdr         = &dec_handle_ptr->frame_header;
-    SeqHeader *   seq_header      = &dec_handle_ptr->seq_header;
+    CurFrameBuf  *frame_buf       = &main_frame_buf->cur_frame_bufs[0];
+    FrameHeader  *frm_hdr         = &dec_handle_ptr->frame_header;
+    SeqHeader    *seq_header      = &dec_handle_ptr->seq_header;
     uint8_t       sb_size_log2    = seq_header->sb_size_log2;
     int32_t       sb_size_w       = block_size_wide[seq_header->sb_size];
     int32_t       pic_width_in_sb = (frm_hdr->frame_size.frame_width + sb_size_w - 1) / sb_size_w;
     uint32_t      sb_origin_y     = y_sb_index << sb_size_log2;
 
     volatile int32_t *sb_lf_completed_in_prev_row = NULL;
-    DecMtlfFrameInfo *lf_frame_info =
-        &dec_handle_ptr->main_frame_buf.cur_frame_bufs[0].dec_mt_frame_data.lf_frame_info;
+    DecMtlfFrameInfo *lf_frame_info = &dec_handle_ptr->main_frame_buf.cur_frame_bufs[0].dec_mt_frame_data.lf_frame_info;
     if (y_sb_index) {
-        sb_lf_completed_in_prev_row =
-            (volatile int32_t *)&lf_frame_info->sb_lf_completed_in_row[y_sb_index - 1];
+        sb_lf_completed_in_prev_row = (volatile int32_t *)&lf_frame_info->sb_lf_completed_in_row[y_sb_index - 1];
     }
     int32_t *sb_lf_completed_in_row = &lf_frame_info->sb_lf_completed_in_row[y_sb_index];
 
     for (int32_t x_sb_index = 0; x_sb_index < pic_width_in_sb; ++x_sb_index) {
         int32_t sb_origin_x     = x_sb_index << sb_size_log2;
-        int32_t end_of_row_flag = (x_sb_index == pic_width_in_sb - 1) ? EB_TRUE : EB_FALSE;
+        int32_t end_of_row_flag = (x_sb_index == pic_width_in_sb - 1) ? TRUE : FALSE;
 
-        SBInfo *sb_info = frame_buf->sb_info +
-            (((y_sb_index * main_frame_buf->sb_cols) + x_sb_index));
+        SBInfo *sb_info = frame_buf->sb_info + (((y_sb_index * main_frame_buf->sb_cols) + x_sb_index));
 
         /* Top-Right Sync*/
         if (y_sb_index) {
@@ -748,14 +694,14 @@ void dec_loop_filter_row(EbDecHandle *dec_handle_ptr, EbPictureBufferDesc *recon
 }
 
 /*Frame level function to trigger loop filter for each superblock*/
-void dec_av1_loop_filter_frame(EbDecHandle *dec_handle_ptr, EbPictureBufferDesc *recon_picture_buf,
-                               LfCtxt *lf_ctxt, int32_t plane_start, int32_t plane_end,
-                               int32_t is_mt, int enable_flag) {
+void svt_aom_dec_av1_loop_filter_frame(EbDecHandle *dec_handle_ptr, EbPictureBufferDesc *recon_picture_buf,
+                                       LfCtxt *lf_ctxt, int32_t plane_start, int32_t plane_end, int32_t is_mt,
+                                       int enable_flag) {
     if (!enable_flag)
         return;
 
     FrameHeader *frm_hdr      = &dec_handle_ptr->frame_header;
-    SeqHeader *  seq_header   = &dec_handle_ptr->seq_header;
+    SeqHeader   *seq_header   = &dec_handle_ptr->seq_header;
     uint8_t      sb_size_log2 = seq_header->sb_size_log2;
 
     LoopFilterInfoN *lf_info = &lf_ctxt->lf_info;
@@ -768,18 +714,16 @@ void dec_av1_loop_filter_frame(EbDecHandle *dec_handle_ptr, EbPictureBufferDesc
 
     frm_hdr->loop_filter_params.combine_vert_horz_lf = 1;
     /*init hev threshold const vectors*/
-    for (int lvl = 0; lvl <= MAX_LOOP_FILTER; lvl++)
-        memset(lf_info->lfthr[lvl].hev_thr, (lvl >> 4), SIMD_WIDTH);
+    for (int lvl = 0; lvl <= MAX_LOOP_FILTER; lvl++) memset(lf_info->lfthr[lvl].hev_thr, (lvl >> 4), SIMD_WIDTH);
 
     svt_av1_loop_filter_frame_init(frm_hdr, lf_info, plane_start, plane_end);
 
-    set_lbd_lf_filter_tap_functions();
-    set_hbd_lf_filter_tap_functions();
+    svt_aom_set_lbd_lf_filter_tap_functions();
+    svt_aom_set_hbd_lf_filter_tap_functions();
 
     if (is_mt) {
         for (uint32_t y_sb_index = 0; y_sb_index < picture_height_in_sb; ++y_sb_index) {
-            dec_loop_filter_row(
-                dec_handle_ptr, recon_picture_buf, lf_ctxt, y_sb_index, plane_start, plane_end);
+            svt_aom_dec_loop_filter_row(dec_handle_ptr, recon_picture_buf, lf_ctxt, y_sb_index, plane_start, plane_end);
         }
     } else {
         /*Loop over a frame : tregger dec_loop_filter_sb for each SB*/
@@ -787,13 +731,12 @@ void dec_av1_loop_filter_frame(EbDecHandle *dec_handle_ptr, EbPictureBufferDesc
             for (uint32_t x_sb_index = 0; x_sb_index < pic_width_in_sb; ++x_sb_index) {
                 uint32_t sb_origin_x     = x_sb_index << sb_size_log2;
                 uint32_t sb_origin_y     = y_sb_index << sb_size_log2;
-                EbBool   end_of_row_flag = x_sb_index == pic_width_in_sb - 1;
+                Bool     end_of_row_flag = x_sb_index == pic_width_in_sb - 1;
 
                 MainFrameBuf *main_frame_buf = &dec_handle_ptr->main_frame_buf;
-                CurFrameBuf * frame_buf      = &main_frame_buf->cur_frame_bufs[0];
+                CurFrameBuf  *frame_buf      = &main_frame_buf->cur_frame_bufs[0];
 
-                SBInfo *sb_info = frame_buf->sb_info +
-                    (((y_sb_index * main_frame_buf->sb_cols) + x_sb_index));
+                SBInfo *sb_info = frame_buf->sb_info + (((y_sb_index * main_frame_buf->sb_cols) + x_sb_index));
 
                 /*sb_info->sb_delta_lf = frame_buf->delta_lf + (FRAME_LF_COUNT *
                     ((y_sb_index * main_frame_buf->sb_cols) + x_sb_index));*/
