@@ -22,10 +22,9 @@
 #include "EbDecBlock.h"
 #include "EbDecMemInit.h"
 
-EbErrorType check_add_tplmv_buf(EbDecHandle *dec_handle_ptr) {
+EbErrorType svt_aom_check_add_tplmv_buf(EbDecHandle *dec_handle_ptr) {
     FrameHeader  *ps_frm_hdr = &dec_handle_ptr->frame_header;
-    const int32_t tpl_size   = ((ps_frm_hdr->mi_rows + MAX_MIB_SIZE) >> 1) *
-        (ps_frm_hdr->mi_stride >> 1);
+    const int32_t tpl_size   = ((ps_frm_hdr->mi_rows + MAX_MIB_SIZE) >> 1) * (ps_frm_hdr->mi_stride >> 1);
 
     int32_t realloc = (dec_handle_ptr->main_frame_buf.tpl_mvs == NULL) ||
         (dec_handle_ptr->main_frame_buf.tpl_mvs_size < tpl_size);
@@ -40,29 +39,26 @@ EbErrorType check_add_tplmv_buf(EbDecHandle *dec_handle_ptr) {
     return EB_ErrorNone;
 }
 
-void derive_blk_pointers(EbPictureBufferDesc *recon_picture_buf, int32_t plane, int32_t blk_col_px,
-                         int32_t blk_row_px, void **pp_blk_recon_buf, int32_t *recon_stride,
-                         int32_t sub_x, int32_t sub_y) {
+void svt_aom_derive_blk_pointers(EbPictureBufferDesc *recon_picture_buf, int32_t plane, int32_t blk_col_px,
+                                 int32_t blk_row_px, void **pp_blk_recon_buf, int32_t *recon_stride, int32_t sub_x,
+                                 int32_t sub_y) {
     int32_t block_offset;
 
     if (plane == 0) {
-        block_offset = (recon_picture_buf->origin_y + blk_row_px) * recon_picture_buf->stride_y +
-            (recon_picture_buf->origin_x + blk_col_px);
+        block_offset = (recon_picture_buf->org_y + blk_row_px) * recon_picture_buf->stride_y +
+            (recon_picture_buf->org_x + blk_col_px);
         *recon_stride = recon_picture_buf->stride_y;
     } else if (plane == 1) {
-        block_offset = ((recon_picture_buf->origin_y >> sub_y) + blk_row_px) *
-                recon_picture_buf->stride_cb +
-            ((recon_picture_buf->origin_x >> sub_x) + blk_col_px);
+        block_offset = ((recon_picture_buf->org_y >> sub_y) + blk_row_px) * recon_picture_buf->stride_cb +
+            ((recon_picture_buf->org_x >> sub_x) + blk_col_px);
         *recon_stride = recon_picture_buf->stride_cb;
     } else {
-        block_offset = ((recon_picture_buf->origin_y >> sub_y) + blk_row_px) *
-                recon_picture_buf->stride_cr +
-            ((recon_picture_buf->origin_x >> sub_x) + blk_col_px);
+        block_offset = ((recon_picture_buf->org_y >> sub_y) + blk_row_px) * recon_picture_buf->stride_cr +
+            ((recon_picture_buf->org_x >> sub_x) + blk_col_px);
         *recon_stride = recon_picture_buf->stride_cr;
     }
 
-    if (recon_picture_buf->bit_depth != EB_EIGHT_BIT ||
-        recon_picture_buf->is_16bit_pipeline) { //16bit
+    if (recon_picture_buf->bit_depth != EB_EIGHT_BIT || recon_picture_buf->is_16bit_pipeline) { //16bit
         if (plane == 0)
             *pp_blk_recon_buf = (void *)((uint16_t *)recon_picture_buf->buffer_y + block_offset);
         else if (plane == 1)
@@ -79,9 +75,9 @@ void derive_blk_pointers(EbPictureBufferDesc *recon_picture_buf, int32_t plane,
     }
 }
 
-void pad_row(EbPictureBufferDesc *recon_picture_buf, EbByte buf_y, EbByte buf_cb, EbByte buf_cr,
-             uint32_t row_width, uint32_t row_height, uint32_t pad_width, uint32_t pad_height,
-             uint32_t sx, uint32_t sy, PadDir flags) {
+void svt_aom_pad_row(EbPictureBufferDesc *recon_picture_buf, EbByte buf_y, EbByte buf_cb, EbByte buf_cr,
+                     uint32_t row_width, uint32_t row_height, uint32_t pad_width, uint32_t pad_height, uint32_t sx,
+                     uint32_t sy, PadDir flags) {
     uint16_t stride_y  = recon_picture_buf->stride_y;
     uint16_t stride_cb = recon_picture_buf->stride_cb;
     uint16_t stride_cr = recon_picture_buf->stride_cr;
@@ -99,16 +95,8 @@ void pad_row(EbPictureBufferDesc *recon_picture_buf, EbByte buf_y, EbByte buf_cb
         if (flags & RIGHT) {
             generate_padding_r(buf_y, stride_y, row_width, row_height, pad_width);
             if (recon_picture_buf->color_format != EB_YUV400) {
-                generate_padding_r(buf_cb,
-                                   stride_cb,
-                                   (row_width + sx) >> sx,
-                                   (row_height + sy) >> sy,
-                                   pad_width >> sx);
-                generate_padding_r(buf_cr,
-                                   stride_cr,
-                                   (row_width + sx) >> sx,
-                                   (row_height + sy) >> sy,
-                                   pad_width >> sx);
+                generate_padding_r(buf_cb, stride_cb, (row_width + sx) >> sx, (row_height + sy) >> sy, pad_width >> sx);
+                generate_padding_r(buf_cr, stride_cr, (row_width + sx) >> sx, (row_height + sy) >> sy, pad_width >> sx);
             }
         }
     } else {
@@ -119,15 +107,12 @@ void pad_row(EbPictureBufferDesc *recon_picture_buf, EbByte buf_y, EbByte buf_cb
         if (flags & LEFT) {
             generate_padding_l_hbd(buf_y, stride_y, row_height, pad_width << shift);
             if (recon_picture_buf->color_format != EB_YUV400) {
-                generate_padding_l_hbd(
-                    buf_cb, stride_cb, (row_height + sy) >> sy, pad_width >> sx << shift);
-                generate_padding_l_hbd(
-                    buf_cr, stride_cr, (row_height + sy) >> sy, pad_width >> sx << shift);
+                generate_padding_l_hbd(buf_cb, stride_cb, (row_height + sy) >> sy, pad_width >> sx << shift);
+                generate_padding_l_hbd(buf_cr, stride_cr, (row_height + sy) >> sy, pad_width >> sx << shift);
             }
         }
         if (flags & RIGHT) {
-            generate_padding_r_hbd(
-                buf_y, stride_y, row_width << shift, row_height, pad_width << shift);
+            generate_padding_r_hbd(buf_y, stride_y, row_width << shift, row_height, pad_width << shift);
             if (recon_picture_buf->color_format != EB_YUV400) {
                 generate_padding_r_hbd(buf_cb,
                                        stride_cb,
@@ -145,39 +130,27 @@ void pad_row(EbPictureBufferDesc *recon_picture_buf, EbByte buf_y, EbByte buf_cb
     if (flags & TOP) {
         generate_padding_t(buf_y, stride_y, row_width << shift, pad_height);
         if (recon_picture_buf->color_format != EB_YUV400) {
-            generate_padding_t(
-                buf_cb, stride_cb, (row_width + sx) >> sx << shift, pad_height >> sy);
-            generate_padding_t(
-                buf_cr, stride_cr, (row_width + sx) >> sx << shift, pad_height >> sy);
+            generate_padding_t(buf_cb, stride_cb, (row_width + sx) >> sx << shift, pad_height >> sy);
+            generate_padding_t(buf_cr, stride_cr, (row_width + sx) >> sx << shift, pad_height >> sy);
         }
 
         if (flags & TOP_LEFT) {
-            generate_padding_t(
-                buf_y - (pad_width << shift), stride_y, pad_width << shift, pad_height);
+            generate_padding_t(buf_y - (pad_width << shift), stride_y, pad_width << shift, pad_height);
             if (recon_picture_buf->color_format != EB_YUV400) {
-                generate_padding_t(buf_cb - (pad_width >> sx << shift),
-                                   stride_cb,
-                                   (pad_width + sx) >> sx << shift,
-                                   pad_height >> sy);
-                generate_padding_t(buf_cr - (pad_width >> sx << shift),
-                                   stride_cr,
-                                   (pad_width + sx) >> sx << shift,
-                                   pad_height >> sy);
+                generate_padding_t(
+                    buf_cb - (pad_width >> sx << shift), stride_cb, (pad_width + sx) >> sx << shift, pad_height >> sy);
+                generate_padding_t(
+                    buf_cr - (pad_width >> sx << shift), stride_cr, (pad_width + sx) >> sx << shift, pad_height >> sy);
             }
         }
 
         if (flags & TOP_RIGHT) {
-            generate_padding_t(
-                buf_y + (row_width << shift), stride_y, pad_width << shift, pad_height);
+            generate_padding_t(buf_y + (row_width << shift), stride_y, pad_width << shift, pad_height);
             if (recon_picture_buf->color_format != EB_YUV400) {
-                generate_padding_t(buf_cb + (row_width >> sx << shift),
-                                   stride_cb,
-                                   (pad_width + sx) >> sx << shift,
-                                   pad_height >> sy);
-                generate_padding_t(buf_cr + (row_width >> sx << shift),
-                                   stride_cr,
-                                   (pad_width + sx) >> sx << shift,
-                                   pad_height >> sy);
+                generate_padding_t(
+                    buf_cb + (row_width >> sx << shift), stride_cb, (pad_width + sx) >> sx << shift, pad_height >> sy);
+                generate_padding_t(
+                    buf_cr + (row_width >> sx << shift), stride_cr, (pad_width + sx) >> sx << shift, pad_height >> sy);
             }
         }
     }
@@ -185,21 +158,14 @@ void pad_row(EbPictureBufferDesc *recon_picture_buf, EbByte buf_y, EbByte buf_cb
     if (flags & BOTTOM) {
         generate_padding_b(buf_y, stride_y, row_width << shift, row_height, pad_height);
         if (recon_picture_buf->color_format != EB_YUV400) {
-            generate_padding_b(buf_cb,
-                               stride_cb,
-                               (row_width + sx) >> sx << shift,
-                               (row_height + sy) >> sy,
-                               pad_height >> sy);
-            generate_padding_b(buf_cr,
-                               stride_cr,
-                               (row_width + sx) >> sx << shift,
-                               (row_height + sy) >> sy,
-                               pad_height >> sy);
+            generate_padding_b(
+                buf_cb, stride_cb, (row_width + sx) >> sx << shift, (row_height + sy) >> sy, pad_height >> sy);
+            generate_padding_b(
+                buf_cr, stride_cr, (row_width + sx) >> sx << shift, (row_height + sy) >> sy, pad_height >> sy);
         }
 
         if (flags & BOTTOM_LEFT) {
-            generate_padding_b(
-                buf_y - (pad_width << shift), stride_y, pad_width << shift, row_height, pad_height);
+            generate_padding_b(buf_y - (pad_width << shift), stride_y, pad_width << shift, row_height, pad_height);
             if (recon_picture_buf->color_format != EB_YUV400) {
                 generate_padding_b(buf_cb - (pad_width >> sx << shift),
                                    stride_cb,
@@ -215,8 +181,7 @@ void pad_row(EbPictureBufferDesc *recon_picture_buf, EbByte buf_y, EbByte buf_cb
         }
 
         if (flags & BOTTOM_RIGHT) {
-            generate_padding_b(
-                buf_y + (row_width << shift), stride_y, pad_width << shift, row_height, pad_height);
+            generate_padding_b(buf_y + (row_width << shift), stride_y, pad_width << shift, row_height, pad_height);
             if (recon_picture_buf->color_format != EB_YUV400) {
                 generate_padding_b(buf_cb + (row_width >> sx << shift),
                                    stride_cb,
@@ -233,7 +198,7 @@ void pad_row(EbPictureBufferDesc *recon_picture_buf, EbByte buf_y, EbByte buf_cb
     }
 }
 
-PadDir get_neighbour_flags(int32_t row, int32_t col, int32_t num_rows, int32_t num_cols) {
+PadDir svt_aom_get_neighbour_flags(int32_t row, int32_t col, int32_t num_rows, int32_t num_cols) {
     PadDir flags = 0;
     if (col == 0)
         flags |= LEFT;
@@ -256,10 +221,10 @@ PadDir get_neighbour_flags(int32_t row, int32_t col, int32_t num_rows, int32_t n
     return flags;
 }
 
-void pad_pic(EbDecHandle *dec_handle_ptr) {
+void svt_aom_pad_pic(EbDecHandle *dec_handle_ptr) {
     EbPictureBufferDesc *recon_picture_buf = dec_handle_ptr->cur_pic_buf[0]->ps_pic_buf;
-    uint32_t frame_width  = dec_handle_ptr->frame_header.frame_size.superres_upscaled_width;
-    uint32_t frame_height = dec_handle_ptr->frame_header.frame_size.frame_height;
+    uint32_t             frame_width       = dec_handle_ptr->frame_header.frame_size.superres_upscaled_width;
+    uint32_t             frame_height      = dec_handle_ptr->frame_header.frame_size.frame_height;
 
     int sx = dec_handle_ptr->seq_header.color_config.subsampling_x;
     int sy = dec_handle_ptr->seq_header.color_config.subsampling_y;
@@ -277,38 +242,28 @@ void pad_pic(EbDecHandle *dec_handle_ptr) {
     uint16_t stride_cb = recon_picture_buf->stride_cb << shift;
     uint16_t stride_cr = recon_picture_buf->stride_cr << shift;
 
-    uint32_t pad_width  = recon_picture_buf->origin_x;
-    uint32_t pad_height = recon_picture_buf->origin_y;
+    uint32_t pad_width  = recon_picture_buf->org_x;
+    uint32_t pad_height = recon_picture_buf->org_y;
 
     /* To be adjusted according to the granularity of operation.
        Assuming a superblock row here. */
     int32_t row_id = 0;
     for (uint32_t row = 0; row < frame_height; row += sb_size, row_id++) {
-        EbByte src_y = recon_picture_buf->buffer_y + (pad_width << shift) +
-            (pad_height + row) * stride_y;
+        EbByte src_y  = recon_picture_buf->buffer_y + (pad_width << shift) + (pad_height + row) * stride_y;
         EbByte src_cb = recon_picture_buf->buffer_cb + (pad_width >> sx << shift) +
             ((pad_height + row) >> sy) * stride_cb;
         EbByte src_cr = recon_picture_buf->buffer_cr + (pad_width >> sx << shift) +
             ((pad_height + row) >> sy) * stride_cr;
 
         int32_t row_height = AOMMIN(sb_size, (int32_t)(frame_height - row));
-        PadDir  flags      = get_neighbour_flags(row_id, 0, sb_aligned_height >> sb_size_log2, 1);
+        PadDir  flags      = svt_aom_get_neighbour_flags(row_id, 0, sb_aligned_height >> sb_size_log2, 1);
 
-        pad_row(recon_picture_buf,
-                src_y,
-                src_cb,
-                src_cr,
-                frame_width,
-                row_height,
-                pad_width,
-                pad_height,
-                sx,
-                sy,
-                flags);
+        svt_aom_pad_row(
+            recon_picture_buf, src_y, src_cb, src_cr, frame_width, row_height, pad_width, pad_height, sx, sy, flags);
     }
 }
 
-int inverse_recenter(int r, int v) {
+int svt_aom_inverse_recenter(int r, int v) {
     if (v > 2 * r)
         return v;
     else if (v & 1)
