@@ -244,7 +244,7 @@ static void svt_av1_apply_temporal_filter_planewise_medium_partial_avx2(
     unsigned int i, j, k, subblock_idx;
 
     int32_t  idx_32x32               = me_ctx->tf_block_col + me_ctx->tf_block_row * 2;
-    uint32_t distance_threshold_fp16 = AOMMAX((me_ctx->min_frame_size << 16) / 10, 1 << 16);
+    uint32_t distance_threshold_fp16 = AOMMAX((me_ctx->tf_mv_dist_th << 16) / 10, 1 << 16);
 
     //Calculation for every quarter
     uint32_t  d_factor_fp8[4];
@@ -507,9 +507,7 @@ static void svt_av1_apply_temporal_filter_planewise_medium_hbd_partial_avx2(
 
     int32_t  idx_32x32               = me_ctx->tf_block_col + me_ctx->tf_block_row * 2;
     int      shift_factor            = ((encoder_bit_depth - 8) * 2);
-    uint32_t distance_threshold_fp16 = AOMMAX((me_ctx->min_frame_size << 16) / 10,
-                                              1 << 16); //TODO Change to FP8
-
+    uint32_t distance_threshold_fp16 = AOMMAX((me_ctx->tf_mv_dist_th << 16) / 10, 1 << 16); //TODO Change to FP8
     //Calculation for every quarter
     uint32_t  d_factor_fp8[4];
     uint32_t  block_error_fp8[4];
