@@ -32,8 +32,8 @@ static INLINE __m256i txb_init_levels_avx2(const TranLow *const coeff) {
     return _mm256_permutevar8x32_epi32(res, idx);
 }
 
-void svt_av1_txb_init_levels_avx2(const TranLow *const coeff, const int32_t width,
-                                  const int32_t height, uint8_t *const levels) {
+void svt_av1_txb_init_levels_avx2(const TranLow *const coeff, const int32_t width, const int32_t height,
+                                  uint8_t *const levels) {
     const TranLow *cf      = coeff;
     const __m128i  x_zeros = _mm_setzero_si128();
     const __m256i  y_zeros = _mm256_setzero_si256();
@@ -125,8 +125,7 @@ static INLINE __m256i set_128x2(__m128i val_lo, __m128i val_hi) {
     return _mm256_inserti128_si256(_mm256_castsi128_si256(val_lo), val_hi, 1);
 }
 
-static INLINE __m128i load_8bit_4x4_to_1_reg_sse2(const void *const src,
-                                                  const int32_t     byte_stride) {
+static INLINE __m128i load_8bit_4x4_to_1_reg_sse2(const void *const src, const int32_t byte_stride) {
     return _mm_setr_epi32(*(const int32_t *)((int8_t *)src + 0 * byte_stride),
                           *(const int32_t *)((int8_t *)src + 1 * byte_stride),
                           *(const int32_t *)((int8_t *)src + 2 * byte_stride),
@@ -160,10 +159,8 @@ static INLINE void load_levels_8x4x5_avx2(const uint8_t *const src, const int32_
 
 static INLINE void load_levels_16x2x5_avx2(const uint8_t *const src, const int32_t stride,
                                            const ptrdiff_t *const offsets, __m256i *const level) {
-    level[0] = set_128x2(_mm_loadu_si128((__m128i *)(src + 1)),
-                         _mm_loadu_si128((__m128i *)(src + stride + 1)));
-    level[1] = set_128x2(_mm_loadu_si128((__m128i *)(src + stride)),
-                         _mm_loadu_si128((__m128i *)(src + stride * 2)));
+    level[0] = set_128x2(_mm_loadu_si128((__m128i *)(src + 1)), _mm_loadu_si128((__m128i *)(src + stride + 1)));
+    level[1] = set_128x2(_mm_loadu_si128((__m128i *)(src + stride)), _mm_loadu_si128((__m128i *)(src + stride * 2)));
     level[2] = set_128x2(_mm_loadu_si128((__m128i *)(src + offsets[0])),
                          _mm_loadu_si128((__m128i *)(src + offsets[0] + stride)));
     level[3] = set_128x2(_mm_loadu_si128((__m128i *)(src + offsets[1])),
@@ -238,13 +235,11 @@ DECLARE_ALIGNED(32, static const uint8_t, pos_to_offsets[256]) = {
     21, 21, 21, 21, 21, 21, 21, 21, 21, 21, 21, 21, 21, 21, 21, 21};
 
 static INLINE void get_4_nz_map_contexts_2d_sse2(const uint8_t *levels, const int32_t height,
-                                                 const ptrdiff_t *const offsets,
-                                                 int8_t *const          coeff_contexts) {
+                                                 const ptrdiff_t *const offsets, int8_t *const coeff_contexts) {
     const int32_t stride              = 4 + TX_PAD_HOR;
     const __m128i pos_to_offset_large = _mm_set1_epi8(21);
-    __m128i       pos_to_offset       = (height == 4)
-                    ? _mm_setr_epi8(0, 1, 6, 6, 1, 6, 6, 21, 6, 6, 21, 21, 6, 21, 21, 21)
-                    : _mm_setr_epi8(0, 11, 11, 11, 11, 11, 11, 11, 6, 6, 21, 21, 6, 21, 21, 21);
+    __m128i       pos_to_offset = (height == 4) ? _mm_setr_epi8(0, 1, 6, 6, 1, 6, 6, 21, 6, 6, 21, 21, 6, 21, 21, 21)
+                                                : _mm_setr_epi8(0, 11, 11, 11, 11, 11, 11, 11, 6, 6, 21, 21, 6, 21, 21, 21);
     __m128i       count;
     __m128i       level[5];
     int8_t       *cc  = coeff_contexts;
@@ -267,8 +262,7 @@ static INLINE void get_4_nz_map_contexts_2d_sse2(const uint8_t *levels, const in
 }
 
 static INLINE void get_8_coeff_contexts_2d_avx2(const uint8_t *levels, const int32_t height,
-                                                const ptrdiff_t *const offsets,
-                                                int8_t                *coeff_contexts) {
+                                                const ptrdiff_t *const offsets, int8_t *coeff_contexts) {
     const int32_t stride = 8 + TX_PAD_HOR;
     int8_t       *cc     = coeff_contexts;
     int32_t       row    = height;
@@ -279,18 +273,16 @@ static INLINE void get_8_coeff_contexts_2d_avx2(const uint8_t *levels, const int
     assert(!(height % 4));
 
     if (height == 8) {
-        __m128i tmp_a = _mm_setr_epi8(0, 1, 6, 6, 21, 21, 21, 21, 1, 6, 6, 21, 21, 21, 21, 21);
-        __m128i tmp_b = _mm_setr_epi8(6, 6, 21, 21, 21, 21, 21, 21, 6, 21, 21, 21, 21, 21, 21, 21);
+        __m128i tmp_a    = _mm_setr_epi8(0, 1, 6, 6, 21, 21, 21, 21, 1, 6, 6, 21, 21, 21, 21, 21);
+        __m128i tmp_b    = _mm_setr_epi8(6, 6, 21, 21, 21, 21, 21, 21, 6, 21, 21, 21, 21, 21, 21, 21);
         pos_to_offset[0] = set_128x2(tmp_a, tmp_b);
     } else if (height < 8) {
-        __m128i tmp_a = _mm_setr_epi8(0, 16, 6, 6, 21, 21, 21, 21, 16, 16, 6, 21, 21, 21, 21, 21);
-        __m128i tmp_b = _mm_setr_epi8(
-            16, 16, 21, 21, 21, 21, 21, 21, 16, 16, 21, 21, 21, 21, 21, 21);
+        __m128i tmp_a    = _mm_setr_epi8(0, 16, 6, 6, 21, 21, 21, 21, 16, 16, 6, 21, 21, 21, 21, 21);
+        __m128i tmp_b    = _mm_setr_epi8(16, 16, 21, 21, 21, 21, 21, 21, 16, 16, 21, 21, 21, 21, 21, 21);
         pos_to_offset[0] = set_128x2(tmp_a, tmp_b);
     } else {
-        __m128i tmp_a = _mm_setr_epi8(
-            0, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11);
-        __m128i tmp_b = _mm_setr_epi8(6, 6, 21, 21, 21, 21, 21, 21, 6, 21, 21, 21, 21, 21, 21, 21);
+        __m128i tmp_a    = _mm_setr_epi8(0, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11);
+        __m128i tmp_b    = _mm_setr_epi8(6, 6, 21, 21, 21, 21, 21, 21, 6, 21, 21, 21, 21, 21, 21, 21);
         pos_to_offset[0] = set_128x2(tmp_a, tmp_b);
     }
     pos_to_offset[1] = _mm256_set1_epi8(21);
@@ -310,10 +302,8 @@ static INLINE void get_8_coeff_contexts_2d_avx2(const uint8_t *levels, const int
 }
 
 static INLINE void get_16_coeff_contexts_2d_avx2(const uint8_t *levels, const int32_t real_width,
-                                                 const int32_t real_height, const int32_t width,
-                                                 const int32_t          height,
-                                                 const ptrdiff_t *const offsets,
-                                                 int8_t                *coeff_contexts) {
+                                                 const int32_t real_height, const int32_t width, const int32_t height,
+                                                 const ptrdiff_t *const offsets, int8_t *coeff_contexts) {
     const int32_t stride = width + TX_PAD_HOR;
     int8_t       *cc     = coeff_contexts;
     int32_t       row    = height;
@@ -360,10 +350,8 @@ static INLINE void get_16_coeff_contexts_2d_avx2(const uint8_t *levels, const in
 }
 
 static INLINE void get_32n_coeff_contexts_2d_avx2(const uint8_t *levels, const int32_t real_width,
-                                                  const int32_t real_height, const int32_t width,
-                                                  const int32_t          height,
-                                                  const ptrdiff_t *const offsets,
-                                                  int8_t                *coeff_contexts) {
+                                                  const int32_t real_height, const int32_t width, const int32_t height,
+                                                  const ptrdiff_t *const offsets, int8_t *coeff_contexts) {
     const int32_t stride = width + TX_PAD_HOR;
     int8_t       *cc     = coeff_contexts;
     int32_t       row    = height;
@@ -425,8 +413,7 @@ static INLINE void get_32n_coeff_contexts_2d_avx2(const uint8_t *levels, const i
 }
 
 static INLINE void get_4_nz_map_contexts_hor_sse2(const uint8_t *levels, const int32_t height,
-                                                  const ptrdiff_t *const offsets,
-                                                  int8_t                *coeff_contexts) {
+                                                  const ptrdiff_t *const offsets, int8_t *coeff_contexts) {
     const int32_t stride        = 4 + TX_PAD_HOR;
     const __m128i pos_to_offset = _mm_setr_epi8(SIG_COEF_CONTEXTS_2D + 0,
                                                 SIG_COEF_CONTEXTS_2D + 5,
@@ -462,8 +449,7 @@ static INLINE void get_4_nz_map_contexts_hor_sse2(const uint8_t *levels, const i
 }
 
 static INLINE void get_8_coeff_contexts_hor_avx2(const uint8_t *levels, const int32_t height,
-                                                 const ptrdiff_t *const offsets,
-                                                 int8_t                *coeff_contexts) {
+                                                 const ptrdiff_t *const offsets, int8_t *coeff_contexts) {
     const int32_t stride              = 8 + TX_PAD_HOR;
     const __m128i pos_to_offset_small = _mm_setr_epi8(SIG_COEF_CONTEXTS_2D + 0,
                                                       SIG_COEF_CONTEXTS_2D + 5,
@@ -501,10 +487,8 @@ static INLINE void get_8_coeff_contexts_hor_avx2(const uint8_t *levels, const in
     } while (row);
 }
 
-static INLINE void get_16_coeff_contexts_hor_avx2(const uint8_t *levels, const int32_t width,
-                                                  const int32_t          height,
-                                                  const ptrdiff_t *const offsets,
-                                                  int8_t                *coeff_contexts) {
+static INLINE void get_16_coeff_contexts_hor_avx2(const uint8_t *levels, const int32_t width, const int32_t height,
+                                                  const ptrdiff_t *const offsets, int8_t *coeff_contexts) {
     const int32_t stride = width + TX_PAD_HOR;
     __m256i       count;
     __m256i       level[5];
@@ -543,10 +527,8 @@ static INLINE void get_16_coeff_contexts_hor_avx2(const uint8_t *levels, const i
     } while (row);
 }
 
-static INLINE void get_32n_coeff_contexts_hor_avx2(const uint8_t *levels, const int32_t width,
-                                                   const int32_t          height,
-                                                   const ptrdiff_t *const offsets,
-                                                   int8_t                *coeff_contexts) {
+static INLINE void get_32n_coeff_contexts_hor_avx2(const uint8_t *levels, const int32_t width, const int32_t height,
+                                                   const ptrdiff_t *const offsets, int8_t *coeff_contexts) {
     const int32_t stride              = width + TX_PAD_HOR;
     const __m256i pos_to_offset_large = _mm256_set1_epi8(SIG_COEF_CONTEXTS_2D + 10);
     __m256i       count;
@@ -607,8 +589,7 @@ static INLINE void get_32n_coeff_contexts_hor_avx2(const uint8_t *levels, const
 }
 
 static INLINE void get_4_nz_map_contexts_ver_sse2(const uint8_t *levels, const int32_t height,
-                                                  const ptrdiff_t *const offsets,
-                                                  int8_t                *coeff_contexts) {
+                                                  const ptrdiff_t *const offsets, int8_t *coeff_contexts) {
     const int32_t stride              = 4 + TX_PAD_HOR;
     const __m128i pos_to_offset_large = _mm_set1_epi8(SIG_COEF_CONTEXTS_2D + 10);
     __m128i       pos_to_offset       = _mm_setr_epi8(SIG_COEF_CONTEXTS_2D + 0,
@@ -646,8 +627,7 @@ static INLINE void get_4_nz_map_contexts_ver_sse2(const uint8_t *levels, const i
 }
 
 static INLINE void get_8_coeff_contexts_ver_avx2(const uint8_t *levels, const int32_t height,
-                                                 const ptrdiff_t *const offsets,
-                                                 int8_t                *coeff_contexts) {
+                                                 const ptrdiff_t *const offsets, int8_t *coeff_contexts) {
     const int32_t stride         = 8 + TX_PAD_HOR;
     __m128i       pos_to_off_128 = _mm_setr_epi8(SIG_COEF_CONTEXTS_2D + 0,
                                            SIG_COEF_CONTEXTS_2D + 0,
@@ -666,7 +646,7 @@ static INLINE void get_8_coeff_contexts_ver_avx2(const uint8_t *levels, const in
                                            SIG_COEF_CONTEXTS_2D + 5,
                                            SIG_COEF_CONTEXTS_2D + 5);
 
-    __m256i pos_to_offset = set_128x2(pos_to_off_128, _mm_set1_epi8(SIG_COEF_CONTEXTS_2D + 10));
+    __m256i pos_to_offset       = set_128x2(pos_to_off_128, _mm_set1_epi8(SIG_COEF_CONTEXTS_2D + 10));
     __m256i pos_to_offset_large = _mm256_set1_epi8(SIG_COEF_CONTEXTS_2D + 10);
 
     int32_t row = height;
@@ -687,10 +667,8 @@ static INLINE void get_8_coeff_contexts_ver_avx2(const uint8_t *levels, const in
     } while (row);
 }
 
-static INLINE void get_16_coeff_contexts_ver_avx2(const uint8_t *levels, const int32_t width,
-                                                  const int32_t          height,
-                                                  const ptrdiff_t *const offsets,
-                                                  int8_t                *coeff_contexts) {
+static INLINE void get_16_coeff_contexts_ver_avx2(const uint8_t *levels, const int32_t width, const int32_t height,
+                                                  const ptrdiff_t *const offsets, int8_t *coeff_contexts) {
     const int32_t stride = width + TX_PAD_HOR;
     __m256i       pos_to_offset[2];
     __m256i       count;
@@ -700,8 +678,7 @@ static INLINE void get_16_coeff_contexts_ver_avx2(const uint8_t *levels, const i
     assert(!(width % 16));
     assert(!(height % 2));
 
-    pos_to_offset[0] = set_128x2(_mm_set1_epi8(SIG_COEF_CONTEXTS_2D + 0),
-                                 _mm_set1_epi8(SIG_COEF_CONTEXTS_2D + 5));
+    pos_to_offset[0] = set_128x2(_mm_set1_epi8(SIG_COEF_CONTEXTS_2D + 0), _mm_set1_epi8(SIG_COEF_CONTEXTS_2D + 5));
     pos_to_offset[1] = _mm256_set1_epi8(SIG_COEF_CONTEXTS_2D + 10);
 
     do {
@@ -717,10 +694,8 @@ static INLINE void get_16_coeff_contexts_ver_avx2(const uint8_t *levels, const i
     } while (row);
 }
 
-static INLINE void get_32n_coeff_contexts_ver_avx2(const uint8_t *levels, const int32_t width,
-                                                   const int32_t          height,
-                                                   const ptrdiff_t *const offsets,
-                                                   int8_t                *coeff_contexts) {
+static INLINE void get_32n_coeff_contexts_ver_avx2(const uint8_t *levels, const int32_t width, const int32_t height,
+                                                   const ptrdiff_t *const offsets, int8_t *coeff_contexts) {
     const int32_t stride = width + TX_PAD_HOR;
     __m256i       pos_to_offset[3];
     __m256i       count;
@@ -752,9 +727,8 @@ static INLINE void get_32n_coeff_contexts_ver_avx2(const uint8_t *levels, const
     } while (--row);
 }
 
-void svt_av1_get_nz_map_contexts_avx2(const uint8_t *const levels, const int16_t *const scan,
-                                      const uint16_t eob, TxSize tx_size, const TxClass tx_class,
-                                      int8_t *const coeff_contexts) {
+void svt_av1_get_nz_map_contexts_avx2(const uint8_t *const levels, const int16_t *const scan, const uint16_t eob,
+                                      TxSize tx_size, const TxClass tx_class, int8_t *const coeff_contexts) {
     const int32_t last_idx = eob - 1;
     if (!last_idx) {
         coeff_contexts[0] = 0;
@@ -783,11 +757,9 @@ void svt_av1_get_nz_map_contexts_avx2(const uint8_t *const levels, const int16_t
         else if (width == 8)
             get_8_coeff_contexts_2d_avx2(levels, height, offsets, coeff_contexts);
         else if (width == 16)
-            get_16_coeff_contexts_2d_avx2(
-                levels, real_width, real_height, width, height, offsets, coeff_contexts);
+            get_16_coeff_contexts_2d_avx2(levels, real_width, real_height, width, height, offsets, coeff_contexts);
         else
-            get_32n_coeff_contexts_2d_avx2(
-                levels, real_width, real_height, width, height, offsets, coeff_contexts);
+            get_32n_coeff_contexts_2d_avx2(levels, real_width, real_height, width, height, offsets, coeff_contexts);
     } else if (tx_class == TX_CLASS_HORIZ) {
         offsets[0] = 2;
         offsets[1] = 3;
@@ -824,8 +796,7 @@ void svt_av1_get_nz_map_contexts_avx2(const uint8_t *const levels, const int16_t
         coeff_contexts[pos] = 3;
 }
 
-void svt_copy_mi_map_grid_avx2(ModeInfo **mi_grid_ptr, uint32_t mi_stride, uint8_t num_rows,
-                               uint8_t num_cols) {
+void svt_copy_mi_map_grid_avx2(ModeInfo **mi_grid_ptr, uint32_t mi_stride, uint8_t num_rows, uint8_t num_cols) {
     ModeInfo *target = mi_grid_ptr[0];
     if (num_cols == 1) {
         for (uint8_t mi_y = 0; mi_y < num_rows; mi_y++) {
