@@ -18,9 +18,8 @@
 /**************************************
  * Extern Function Declarations
  **************************************/
-extern EbErrorType cdef_context_ctor(EbThreadContext   *thread_context_ptr,
-                                     const EbEncHandle *enc_handle_ptr, int index);
+extern EbErrorType svt_aom_cdef_context_ctor(EbThreadContext *thread_ctx, const EbEncHandle *enc_handle_ptr, int index);
 
-extern void *cdef_kernel(void *input_ptr);
+extern void *svt_aom_cdef_kernel(void *input_ptr);
 
 #endif
