@@ -82,6 +82,10 @@ typedef struct EncodeContext {
 
     EbHandle total_number_of_recon_frame_mutex;
     uint64_t total_number_of_recon_frames;
+#if OPT_LD_LATENCY2
+    EbHandle total_number_of_shown_frames_mutex;
+    uint64_t total_number_of_shown_frames;
+#endif
 
     // Overlay input picture fifo
     EbFifo *overlay_input_picture_pool_fifo_ptr;
@@ -111,14 +115,24 @@ typedef struct EncodeContext {
 
     // Picture Decision decoded picture buffer - used to track PA refs
     PaReferenceEntry **pd_dpb;
+#if OPT_LD_LATENCY2
+    // Picture decision and Packetization process both access pd_dpb.
+    // Mutex added for protection
+    EbHandle pd_dpb_mutex;
+#endif
 
     // Picture Manager Circular Queues
     InputQueueEntry **input_picture_queue;
     uint32_t          input_picture_queue_head_index;
     uint32_t          input_picture_queue_tail_index;
     // Picture Manager List
-    ReferenceQueueEntry **reference_picture_list;
-    uint32_t              reference_picture_list_length;
+    ReferenceQueueEntry **ref_pic_list;
+    uint32_t              ref_pic_list_length;
+#if OPT_LD_LATENCY2
+    // Picture manager and Packetization process both access ref_pic_list.
+    // Mutex added for protection
+    EbHandle ref_pic_list_mutex;
+#endif
 
     // Initial Rate Control Reorder Queue
     InitialRateControlReorderEntry **initial_rate_control_reorder_queue;
@@ -152,8 +166,9 @@ typedef struct EncodeContext {
 
     // Dynamic GOP
     uint32_t         previous_mini_gop_hierarchical_levels;
+    uint64_t         mini_gop_cnt_per_gop;
     EbObjectWrapper *previous_picture_control_set_wrapper_ptr;
-    uint64_t picture_number_alt; // The picture number overlay includes all the overlay frames
+    uint64_t         picture_number_alt; // The picture number overlay includes all the overlay frames
 
     EbHandle stat_file_mutex;
 
@@ -183,6 +198,9 @@ typedef struct EncodeContext {
     EbHandle                          rc_param_queue_mutex;
     // reference scaling random access event
     EbRefFrameScale resize_evt;
+    //Superblock end index for cycling refresh through the frame.
+    uint32_t         cr_sb_end;
+    SvtAv1RoiMapEvt *roi_map_evt;
 } EncodeContext;
 
 typedef struct EncodeContextInitData {
@@ -192,6 +210,5 @@ typedef struct EncodeContextInitData {
 /**************************************
  * Extern Function Declarations
  **************************************/
-extern EbErrorType encode_context_ctor(EncodeContext *encode_context_ptr,
-                                       EbPtr          object_init_data_ptr);
+extern EbErrorType svt_aom_encode_context_ctor(EncodeContext *enc_ctx, EbPtr object_init_data_ptr);
 #endif // EbEncodeContext_h
