@@ -12,10 +12,10 @@
 #include <stdlib.h>
 #include "EbInitialRateControlReorderQueue.h"
 
-EbErrorType initial_rate_control_reorder_entry_ctor(InitialRateControlReorderEntry *entry_ptr,
-                                                    uint32_t picture_number) {
-    entry_ptr->picture_number         = picture_number;
-    entry_ptr->parent_pcs_wrapper_ptr = (EbObjectWrapper *)NULL;
+EbErrorType svt_aom_initial_rate_control_reorder_entry_ctor(InitialRateControlReorderEntry *entry_ptr,
+                                                            uint32_t                        picture_number) {
+    entry_ptr->picture_number = picture_number;
+    entry_ptr->ppcs_wrapper   = (EbObjectWrapper *)NULL;
 
     return EB_ErrorNone;
 }
