@@ -13,16 +13,15 @@
 
 #include "EbInitialRateControlResults.h"
 
-EbErrorType initial_rate_control_results_ctor(InitialRateControlResults *object_ptr,
-                                              EbPtr                      object_init_data_ptr) {
+static EbErrorType initial_rate_control_results_ctor(InitialRateControlResults *object_ptr,
+                                                     EbPtr                      object_init_data_ptr) {
     (void)object_ptr;
     (void)object_init_data_ptr;
 
     return EB_ErrorNone;
 }
 
-EbErrorType initial_rate_control_results_creator(EbPtr *object_dbl_ptr,
-                                                 EbPtr  object_init_data_ptr) {
+EbErrorType svt_aom_initial_rate_control_results_creator(EbPtr *object_dbl_ptr, EbPtr object_init_data_ptr) {
     InitialRateControlResults *obj;
 
     *object_dbl_ptr = NULL;
