@@ -66,7 +66,7 @@ static void mode_decision_context_dctor(EbPtr p) {
         EB_FREE_ARRAY(obj->md_blk_arr_nsq[0].av1xd);
     }
     EB_FREE_ARRAY(obj->avail_blk_flag);
-    EB_FREE_ARRAY(obj->tested_blk_flag);
+    EB_FREE_ARRAY(obj->cost_avail);
     EB_FREE_ARRAY(obj->md_local_blk_unit);
     EB_FREE_ARRAY(obj->md_blk_arr_nsq);
     if (obj->rate_est_table)
@@ -101,6 +101,7 @@ static void mode_decision_context_dctor(EbPtr p) {
     EB_DELETE(obj->scratch_prediction_ptr);
     EB_DELETE(obj->temp_residual);
     EB_DELETE(obj->temp_recon_ptr);
+    EB_FREE_ARRAY(obj->full_cost_ssim_array);
 }
 
 void svt_aom_set_nics(NicScalingCtrls *scaling_ctrls, uint32_t mds1_count[CAND_CLASS_TOTAL],
@@ -217,7 +218,7 @@ EbErrorType svt_aom_mode_decision_context_ctor(ModeDecisionContext *ctx, EbColor
             for (EbInputResolution input_resolution = 0; input_resolution < INPUT_SIZE_COUNT; input_resolution++) {
                 if (obmc_allowed)
                     break;
-                obmc_allowed |= svt_aom_get_obmc_level(enc_mode, is_ref, fast_decode, input_resolution);
+                obmc_allowed |= svt_aom_get_obmc_level(enc_mode, fast_decode, input_resolution);
             }
         }
     }
@@ -256,6 +257,7 @@ EbErrorType svt_aom_mode_decision_context_ctor(ModeDecisionContext *ctx, EbColor
     // Cost Arrays
     EB_MALLOC_ARRAY(ctx->fast_cost_array, ctx->max_nics_uv);
     EB_MALLOC_ARRAY(ctx->full_cost_array, ctx->max_nics_uv);
+    EB_MALLOC_ARRAY(ctx->full_cost_ssim_array, ctx->max_nics_uv);
     // Candidate Buffers
     EB_NEW(ctx->cand_bf_tx_depth_1,
            svt_aom_mode_decision_scratch_cand_bf_ctor,
@@ -327,7 +329,7 @@ EbErrorType svt_aom_mode_decision_context_ctor(ModeDecisionContext *ctx, EbColor
     ctx->md_blk_arr_nsq[0].av1xd = NULL;
     EB_MALLOC_ARRAY(ctx->md_blk_arr_nsq[0].av1xd, block_max_count_sb);
     EB_MALLOC_ARRAY(ctx->avail_blk_flag, block_max_count_sb);
-    EB_MALLOC_ARRAY(ctx->tested_blk_flag, block_max_count_sb);
+    EB_MALLOC_ARRAY(ctx->cost_avail, block_max_count_sb);
     EB_MALLOC_ARRAY(ctx->mdc_sb_array, 1);
     for (coded_leaf_index = 0; coded_leaf_index < block_max_count_sb; ++coded_leaf_index) {
         ctx->md_blk_arr_nsq[coded_leaf_index].av1xd      = ctx->md_blk_arr_nsq[0].av1xd + coded_leaf_index;
@@ -441,7 +443,8 @@ EbErrorType svt_aom_mode_decision_context_ctor(ModeDecisionContext *ctx, EbColor
                ctx->temp_residual,
                ctx->temp_recon_ptr,
                &(ctx->fast_cost_array[buffer_index]),
-               &(ctx->full_cost_array[buffer_index]));
+               &(ctx->full_cost_array[buffer_index]),
+               &(ctx->full_cost_ssim_array[buffer_index]));
     }
 
     for (buffer_index = max_nics; buffer_index < ctx->max_nics_uv; ++buffer_index) {
@@ -453,8 +456,10 @@ EbErrorType svt_aom_mode_decision_context_ctor(ModeDecisionContext *ctx, EbColor
                ctx->temp_residual,
                ctx->temp_recon_ptr,
                &(ctx->fast_cost_array[buffer_index]),
-               &(ctx->full_cost_array[buffer_index]));
+               &(ctx->full_cost_array[buffer_index]),
+               &(ctx->full_cost_ssim_array[buffer_index]));
     }
+
     return EB_ErrorNone;
 }
 
@@ -489,7 +494,9 @@ void svt_aom_reset_mode_decision_neighbor_arrays(PictureControlSet *pcs, uint16_
 
     return;
 }
-
+// If the ref intra percentage is below the TH, applying modulation to the MD lambda
+#define LAMBDA_MOD_INTRA_TH 65
+#define LAMBDA_MOD_SCALING_FACTOR 138
 // Set the lambda for each sb.
 // When lambda tuning is on (blk_lambda_tuning), lambda of each block is set separately (full_lambda_md/fast_lambda_md)
 // later in svt_aom_set_tuned_blk_lambda
@@ -500,6 +507,17 @@ static void av1_lambda_assign_md(PictureControlSet *pcs, ModeDecisionContext *ct
     ctx->full_lambda_md[1] = (uint32_t)svt_aom_compute_rd_mult(pcs, ctx->qp_index, ctx->me_q_index, 10);
     ctx->fast_lambda_md[1] = av1lambda_mode_decision10_bit_sad[ctx->qp_index];
 
+    if (pcs->scs->stats_based_sb_lambda_modulation) {
+        if (pcs->temporal_layer_index > 0) {
+            if (pcs->ref_intra_percentage < LAMBDA_MOD_INTRA_TH) {
+                ctx->full_lambda_md[0] = (ctx->full_lambda_md[0] * LAMBDA_MOD_SCALING_FACTOR) >> 7;
+                ctx->fast_lambda_md[0] = (ctx->fast_lambda_md[0] * LAMBDA_MOD_SCALING_FACTOR) >> 7;
+                ctx->full_lambda_md[1] = (ctx->full_lambda_md[1] * LAMBDA_MOD_SCALING_FACTOR) >> 7;
+                ctx->fast_lambda_md[1] = (ctx->fast_lambda_md[1] * LAMBDA_MOD_SCALING_FACTOR) >> 7;
+            }
+        }
+    }
+
     ctx->full_lambda_md[1] *= 16;
     ctx->fast_lambda_md[1] *= 4;
 
