@@ -20,35 +20,39 @@
 /***************************************
  * Extern Function Declaration
  ***************************************/
-EbErrorType  picture_decision_context_ctor(EbThreadContext   *thread_context_ptr,
-                                           const EbEncHandle *enc_handle_ptr,
-                                           uint8_t            scene_change_detection);
-extern void *picture_decision_kernel(void *input_ptr);
+EbErrorType  svt_aom_picture_decision_context_ctor(EbThreadContext *thread_ctx, const EbEncHandle *enc_handle_ptr,
+                                                   uint8_t calc_hist);
+extern void *svt_aom_picture_decision_kernel(void *input_ptr);
 
-void downsample_decimation_input_picture(PictureParentControlSet *pcs_ptr,
-                                         EbPictureBufferDesc     *inputPaddedPicturePtr,
-                                         EbPictureBufferDesc     *quarterDecimatedPicturePtr,
-                                         EbPictureBufferDesc     *sixteenthDecimatedPicturePtr);
+void svt_aom_downsample_decimation_input_picture(PictureParentControlSet *pcs,
+                                                 EbPictureBufferDesc     *inputPaddedPicturePtr,
+                                                 EbPictureBufferDesc     *quarterDecimatedPicturePtr,
+                                                 EbPictureBufferDesc     *sixteenthDecimatedPicturePtr);
 
-void pad_picture_to_multiple_of_min_blk_size_dimensions(SequenceControlSet  *scs_ptr,
-                                                        EbPictureBufferDesc *input_picture_ptr);
-void pad_picture_to_multiple_of_min_blk_size_dimensions_16bit(
-    SequenceControlSet *scs_ptr, EbPictureBufferDesc *input_picture_ptr);
-void picture_pre_processing_operations(PictureParentControlSet *pcs_ptr,
-                                       SequenceControlSet      *scs_ptr);
-void pad_picture_to_multiple_of_sb_dimensions(EbPictureBufferDesc *input_padded_picture_ptr);
-void gathering_picture_statistics(SequenceControlSet *scs_ptr, PictureParentControlSet *pcs_ptr,
-                                  EbPictureBufferDesc *input_padded_picture_ptr,
-                                  EbPictureBufferDesc *sixteenth_decimated_picture_ptr);
+void svt_aom_pad_picture_to_multiple_of_min_blk_size_dimensions(SequenceControlSet  *scs,
+                                                                EbPictureBufferDesc *input_pic);
+void svt_aom_pad_picture_to_multiple_of_min_blk_size_dimensions_16bit(SequenceControlSet  *scs,
+                                                                      EbPictureBufferDesc *input_pic);
+void svt_aom_picture_pre_processing_operations(PictureParentControlSet *pcs, SequenceControlSet *scs);
+void svt_aom_pad_picture_to_multiple_of_sb_dimensions(EbPictureBufferDesc *input_padded_pic);
+void svt_aom_gathering_picture_statistics(SequenceControlSet *scs, PictureParentControlSet *pcs,
+                                          EbPictureBufferDesc *input_padded_pic,
+                                          EbPictureBufferDesc *sixteenth_decimated_picture_ptr);
 
-void down_sample_chroma(EbPictureBufferDesc *input_picture_ptr,
-                        EbPictureBufferDesc *outputPicturePtr);
+void svt_aom_down_sample_chroma(EbPictureBufferDesc *input_pic, EbPictureBufferDesc *outputPicturePtr);
 
-Bool is_delayed_intra(PictureParentControlSet *pcs);
-
-void svt_aom_set_dlf_controls(PictureParentControlSet *pcs_ptr, uint8_t dlf_level,
-                              uint8_t bit_depth);
+Bool svt_aom_is_delayed_intra(PictureParentControlSet *pcs);
 
+uint8_t     svt_aom_tf_max_ref_per_struct(uint32_t hierarchical_levels, uint8_t type /*I_SLICE, BASE, L1*/,
+                                          bool direction /*Past, Future*/);
+EbErrorType svt_aom_prediction_structure_group_ctor(PredictionStructureGroup *pred_struct_group_ptr);
+bool        svt_aom_is_pic_used_as_ref(unsigned hierarchical_levels, unsigned temporal_layer, unsigned picture_index,
+                                       unsigned referencing_scheme, bool is_overlay);
+typedef struct DpbEntry {
+    uint64_t picture_number;
+    uint64_t decode_order;
+    uint8_t  temporal_layer_index;
+} DpbEntry;
 /**************************************
  * Context
  **************************************/
@@ -61,13 +65,12 @@ typedef struct PictureDecisionContext {
     Bool        reset_running_avg;
     int8_t      tf_motion_direction; // -1: invalid   0: horz  1: vert
     uint32_t ***prev_picture_histogram;
-    uint64_t    prev_average_intensity_per_region[MAX_NUMBER_OF_REGIONS_IN_WIDTH]
-                                              [MAX_NUMBER_OF_REGIONS_IN_HEIGHT];
-    uint32_t **ahd_running_avg_cb;
-    uint32_t **ahd_running_avg_cr;
-    uint32_t **ahd_running_avg;
-    Bool       is_scene_change_detected;
-    int8_t     transition_detected; // -1: not computed
+    uint64_t    prev_average_intensity_per_region[MAX_NUMBER_OF_REGIONS_IN_WIDTH][MAX_NUMBER_OF_REGIONS_IN_HEIGHT];
+    uint32_t  **ahd_running_avg_cb;
+    uint32_t  **ahd_running_avg_cr;
+    uint32_t  **ahd_running_avg;
+    Bool        is_scene_change_detected;
+    int8_t      transition_detected; // -1: not computed
         // The signal transition_detected is set for only the RA case, and used to derive transition_present flag
         // If the scene change happens during a complete mini-GOP, then transition_present is set to 1
         // for only the next BASE. However, if the scene change happens during an incomplete mini-GOP
@@ -76,9 +79,6 @@ typedef struct PictureDecisionContext {
         // When transition_present is set to 1, different action(s) will be taken to mimic an I_SLICE (decrease the QP, better INTRA search level,
         // shut depth-removal, ..). The QP action is not applied if a P.
     // Dynamic GOP
-    uint32_t ttl_region_activity_cost[MAX_NUMBER_OF_REGIONS_IN_WIDTH]
-                                     [MAX_NUMBER_OF_REGIONS_IN_HEIGHT];
-
     uint32_t total_number_of_mini_gops;
 
     uint32_t mini_gop_start_index[MINI_GOP_WINDOW_MAX_COUNT];
@@ -91,14 +91,17 @@ typedef struct PictureDecisionContext {
     uint32_t mini_gop_region_activity_cost_array[MINI_GOP_MAX_COUNT][MAX_NUMBER_OF_REGIONS_IN_WIDTH]
                                                 [MAX_NUMBER_OF_REGIONS_IN_HEIGHT];
 
-    uint32_t mini_gop_group_faded_in_pictures_count[MINI_GOP_MAX_COUNT];
-    uint32_t mini_gop_group_faded_out_pictures_count[MINI_GOP_MAX_COUNT];
-    uint8_t  lay0_toggle; //3 way toggle 0->1->2
-    uint8_t  lay1_toggle; //2 way toggle 0->1
-    Bool mini_gop_toggle; //mini GOP toggling since last Key Frame  K-0-1-0-1-0-K-0-1-0-1-K-0-1.....
+    uint32_t                 mini_gop_group_faded_in_pictures_count[MINI_GOP_MAX_COUNT];
+    uint32_t                 mini_gop_group_faded_out_pictures_count[MINI_GOP_MAX_COUNT];
+    uint8_t                  lay0_toggle; //3 way toggle 0->1->2
+    uint8_t                  lay1_toggle; //2 way toggle 0->1
+    uint8_t                  cut_short_ra_mg;
+    DpbEntry                 dpb[REF_FRAMES];
+    Bool                     mini_gop_toggle; //mini GOP toggling since last Key Frame  K-0-1-0-1-0-K-0-1-0-1-K-0-1.....
     uint8_t                  last_i_picture_sc_class0;
     uint8_t                  last_i_picture_sc_class1;
     uint8_t                  last_i_picture_sc_class2;
+    uint64_t                 last_long_base_pic;
     uint64_t                 key_poc;
     uint8_t                  tf_level;
     uint32_t                 tf_pic_arr_cnt;
@@ -107,8 +110,9 @@ typedef struct PictureDecisionContext {
     PictureParentControlSet *prev_delayed_intra; //Key frame or I of LDP short MG
     uint32_t                 mg_size; //number of active pictures in above array
     PictureParentControlSet *mg_pictures_array_disp_order[1 << MAX_TEMPORAL_LAYERS];
-
-    int64_t mg_progress_id;
+    int64_t                  base_counter;
+    bool                     gm_pp_last_detected;
+    int64_t                  mg_progress_id;
 
     int32_t last_i_noise_levels_log1p_fp16[MAX_MB_PLANE];
     double  last_i_noise_levels[MAX_MB_PLANE];
@@ -117,6 +121,15 @@ typedef struct PictureDecisionContext {
     uint32_t ref_order_hint[REF_FRAMES]; // spec 6.8.2
     uint64_t sframe_poc;
     int32_t  sframe_due; // The flag indicates whether the next ARF will be made an s-frame
+    uint8_t *sixteenth_b64_buffer;
+    uint32_t sixteenth_b64_buffer_stride;
+    uint64_t norm_dist;
+    uint8_t  perc_cplx;
+    uint8_t  perc_active;
+    int16_t  mv_in_out_count;
+    bool     enable_startup_mg;
+    uint32_t filt_to_unfilt_diff;
+    bool     list0_only;
 } PictureDecisionContext;
 
 #endif // EbPictureDecision_h
