@@ -11,8 +11,8 @@
 
 #include "EbPictureDecisionReorderQueue.h"
 
-EbErrorType picture_decision_reorder_entry_ctor(PictureDecisionReorderEntry *entry_ptr,
-                                                uint32_t                     picture_number) {
+EbErrorType svt_aom_picture_decision_reorder_entry_ctor(PictureDecisionReorderEntry *entry_ptr,
+                                                        uint32_t                     picture_number) {
     entry_ptr->picture_number = picture_number;
     return EB_ErrorNone;
 }
