@@ -12,7 +12,7 @@
 #include <stdlib.h>
 #include "EbPictureDemuxResults.h"
 
-EbErrorType picture_results_ctor(PictureDemuxResults *object_ptr, EbPtr object_init_data_ptr) {
+static EbErrorType picture_results_ctor(PictureDemuxResults *object_ptr, EbPtr object_init_data_ptr) {
     object_ptr->picture_type = EB_PIC_INVALID;
 
     (void)object_init_data_ptr;
@@ -20,7 +20,7 @@ EbErrorType picture_results_ctor(PictureDemuxResults *object_ptr, EbPtr object_i
     return EB_ErrorNone;
 }
 
-EbErrorType picture_results_creator(EbPtr *object_dbl_ptr, EbPtr object_init_data_ptr) {
+EbErrorType svt_aom_picture_results_creator(EbPtr *object_dbl_ptr, EbPtr object_init_data_ptr) {
     PictureDemuxResults *obj;
 
     *object_dbl_ptr = NULL;
