@@ -23,7 +23,7 @@ extern "C" {
  **************************************/
 typedef struct RateControlResults {
     EbDctor          dctor;
-    EbObjectWrapper *pcs_wrapper_ptr;
+    EbObjectWrapper *pcs_wrapper;
     Bool             superres_recode;
 } RateControlResults;
 
@@ -34,7 +34,7 @@ typedef struct RateControlResultsInitData {
 /**************************************
  * Extern Function Declarations
  **************************************/
-extern EbErrorType rate_control_results_creator(EbPtr *object_dbl_ptr, EbPtr object_init_data_ptr);
+extern EbErrorType svt_aom_rate_control_results_creator(EbPtr *object_dbl_ptr, EbPtr object_init_data_ptr);
 
 #ifdef __cplusplus
 }
