@@ -17,15 +17,11 @@
 extern "C" {
 #endif
 /***************************************
-     * Extern Function Declaration
-     ***************************************/
-EbErrorType resource_coordination_context_ctor(EbThreadContext* thread_context_ptr,
-                                               EbEncHandle*     enc_handle_ptr);
+ * Extern Function Declaration
+ ***************************************/
+EbErrorType svt_aom_resource_coordination_context_ctor(EbThreadContext* thread_ctx, EbEncHandle* enc_handle_ptr);
 
-uint8_t get_enable_restoration(EncMode enc_mode, int8_t config_enable_restoration,
-                               uint8_t input_resolution, Bool fast_decode);
-
-extern void* resource_coordination_kernel(void* input_ptr);
+extern void* svt_aom_resource_coordination_kernel(void* input_ptr);
 #ifdef __cplusplus
 }
 #endif
