@@ -94,8 +94,8 @@ class PictureOperatorTest : public ::testing::Test,
         : pu_width_(std::get<0>(TEST_GET_PARAM(0))),
           pu_height_(std::get<1>(TEST_GET_PARAM(0))),
           test_pattern_(TEST_GET_PARAM(1)) {
-        tst_size = 2 * MAX_PU_SIZE * MAX_PU_SIZE;
-        tst_stride_ = 2 * MAX_PU_SIZE;
+        tst_size = 2 * 64 * 64;
+        tst_stride_ = 2 * 64;
         tst1_aligned_ = (uint8_t *)svt_aom_memalign(8, tst_size);
         tst2_aligned_ = (uint8_t *)svt_aom_memalign(8, tst_size);
         dst1_aligned_ = (uint8_t *)svt_aom_memalign(8, tst_size);
