@@ -1,13 +1,14 @@
 /*
-* Copyright(c) 2019 Intel Corporation
-*
-* This source code is subject to the terms of the BSD 2 Clause License and
-* the Alliance for Open Media Patent License 1.0. If the BSD 2 Clause License
-* was not distributed with this source code in the LICENSE file, you can
-* obtain it at https://www.aomedia.org/license/software-license. If the Alliance for Open
-* Media Patent License 1.0 was not distributed with this source code in the
-* PATENTS file, you can obtain it at https://www.aomedia.org/license/patent-license.
-*/
+ * Copyright(c) 2019 Intel Corporation
+ *
+ * This source code is subject to the terms of the BSD 2 Clause License and
+ * the Alliance for Open Media Patent License 1.0. If the BSD 2 Clause License
+ * was not distributed with this source code in the LICENSE file, you can
+ * obtain it at https://www.aomedia.org/license/software-license. If the
+ * Alliance for Open Media Patent License 1.0 was not distributed with this
+ * source code in the PATENTS file, you can obtain it at
+ * https://www.aomedia.org/license/patent-license.
+ */
 
 #include "gtest/gtest.h"
 #include "aom_dsp_rtcd.h"
@@ -32,7 +33,7 @@ typedef void (*av1_compute_stats_highbd_func)(
     int32_t wiener_win, const uint8_t *dgd8, const uint8_t *src8,
     int32_t h_start, int32_t h_end, int32_t v_start, int32_t v_end,
     int32_t dgd_stride, int32_t src_stride, int64_t *M, int64_t *H,
-    AomBitDepth bit_depth);
+    EbBitDepth bit_depth);
 
 typedef ::testing::tuple<BlockSize, av1_compute_stats_func, int, int>
     av1_compute_stats_params;
@@ -44,26 +45,45 @@ class av1_compute_stats_test
     int64_t M_org[WIENER_WIN2], M_opt[WIENER_WIN2];
     int64_t H_org[WIENER_WIN2 * WIENER_WIN2], H_opt[WIENER_WIN2 * WIENER_WIN2];
 
-
     void init_data(const int idx) {
         if (!idx) {
-            memset(dgd, 0, sizeof(*dgd) * 2 * RESTORATION_UNITSIZE_MAX * dgd_stride);
-            memset(src, 0, sizeof(*src) * 2 * RESTORATION_UNITSIZE_MAX * src_stride);
+            memset(
+                dgd,
+                0,
+                sizeof(*dgd) * 2 * RESTORATION_UNITPELS_HORZ_MAX * dgd_stride);
+            memset(
+                src,
+                0,
+                sizeof(*src) * 2 * RESTORATION_UNITPELS_HORZ_MAX * src_stride);
         } else if (1 == idx) {
-            svt_buf_random_u8_to_255(dgd, 2 * RESTORATION_UNITSIZE_MAX * dgd_stride);
-            svt_buf_random_u8_to_255(src, 2 * RESTORATION_UNITSIZE_MAX * src_stride);
+            svt_buf_random_u8_to_255(
+                dgd, 2 * RESTORATION_UNITPELS_HORZ_MAX * dgd_stride);
+            svt_buf_random_u8_to_255(
+                src, 2 * RESTORATION_UNITPELS_HORZ_MAX * src_stride);
         } else if (2 == idx) {
-            svt_buf_random_u8_to_255(dgd, 2 * RESTORATION_UNITSIZE_MAX * dgd_stride);
-            memset(src, 0, sizeof(*src) * 2 * RESTORATION_UNITSIZE_MAX * src_stride);
+            svt_buf_random_u8_to_255(
+                dgd, 2 * RESTORATION_UNITPELS_HORZ_MAX * dgd_stride);
+            memset(
+                src,
+                0,
+                sizeof(*src) * 2 * RESTORATION_UNITPELS_HORZ_MAX * src_stride);
         } else if (3 == idx) {
-            memset(dgd, 0, sizeof(*dgd) * 2 * RESTORATION_UNITSIZE_MAX * dgd_stride);
-            svt_buf_random_u8_to_255(src, 2 * RESTORATION_UNITSIZE_MAX * src_stride);
+            memset(
+                dgd,
+                0,
+                sizeof(*dgd) * 2 * RESTORATION_UNITPELS_HORZ_MAX * dgd_stride);
+            svt_buf_random_u8_to_255(
+                src, 2 * RESTORATION_UNITPELS_HORZ_MAX * src_stride);
         } else if (4 == idx) {
-            svt_buf_random_u8_to_0_or_255(dgd, 2 * RESTORATION_UNITSIZE_MAX * dgd_stride);
-            svt_buf_random_u8_to_0_or_255(src, 2 * RESTORATION_UNITSIZE_MAX * src_stride);
+            svt_buf_random_u8_to_0_or_255(
+                dgd, 2 * RESTORATION_UNITPELS_HORZ_MAX * dgd_stride);
+            svt_buf_random_u8_to_0_or_255(
+                src, 2 * RESTORATION_UNITPELS_HORZ_MAX * src_stride);
         } else {
-            svt_buf_random_u8(dgd, 2 * RESTORATION_UNITSIZE_MAX * dgd_stride);
-            svt_buf_random_u8(src, 2 * RESTORATION_UNITSIZE_MAX * src_stride);
+            svt_buf_random_u8(dgd,
+                              2 * RESTORATION_UNITPELS_HORZ_MAX * dgd_stride);
+            svt_buf_random_u8(src,
+                              2 * RESTORATION_UNITPELS_HORZ_MAX * src_stride);
         }
     }
 
@@ -77,8 +97,20 @@ class av1_compute_stats_test
   public:
     void match_test() {
         const int block_size = TEST_GET_PARAM(0);
-        int width = block_size_wide[block_size];
-        int height = block_size_high[block_size];
+        int width;
+        int height;
+        if (block_size < BlockSizeS_ALL) {
+            width = block_size_wide[block_size];
+            height = block_size_high[block_size];
+        } else {
+            if (block_size == BlockSizeS_ALL) {
+                width = 308;
+                height = 308;
+            } else {
+                width = 304;
+                height = 304;
+            }
+        }
         av1_compute_stats_func func = TEST_GET_PARAM(1);
         int test_idx = TEST_GET_PARAM(2);
         int wiener_win = TEST_GET_PARAM(3);
@@ -88,10 +120,10 @@ class av1_compute_stats_test
             svt_create_random_aligned_stride(2 * RESTORATION_UNITSIZE_MAX, 64);
         src_stride =
             svt_create_random_aligned_stride(2 * RESTORATION_UNITSIZE_MAX, 64);
-        dgd = (uint8_t *)malloc(sizeof(*dgd) * 2 * RESTORATION_UNITSIZE_MAX *
-                                dgd_stride);
-        src = (uint8_t *)malloc(sizeof(*src) * 2 * RESTORATION_UNITSIZE_MAX *
-                                src_stride);
+        dgd = (uint8_t *)malloc(sizeof(*dgd) * 2 *
+                                RESTORATION_UNITPELS_HORZ_MAX * dgd_stride);
+        src = (uint8_t *)malloc(sizeof(*src) * 2 *
+                                RESTORATION_UNITPELS_HORZ_MAX * src_stride);
 
         int test_times = test_idx == 0 ? 1 : 10;
         for (int i = 0; i < test_times; i++) {
@@ -145,17 +177,17 @@ class av1_compute_stats_test
             svt_create_random_aligned_stride(2 * RESTORATION_UNITSIZE_MAX, 64);
         src_stride =
             svt_create_random_aligned_stride(2 * RESTORATION_UNITSIZE_MAX, 64);
-        dgd = (uint8_t *)malloc(sizeof(*dgd) * 2 * RESTORATION_UNITSIZE_MAX *
-                                dgd_stride);
-        src = (uint8_t *)malloc(sizeof(*src) * 2 * RESTORATION_UNITSIZE_MAX *
-                                src_stride);
+        dgd = (uint8_t *)malloc(sizeof(*dgd) * 2 *
+                                RESTORATION_UNITPELS_HORZ_MAX * dgd_stride);
+        src = (uint8_t *)malloc(sizeof(*src) * 2 *
+                                RESTORATION_UNITPELS_HORZ_MAX * src_stride);
         init_data(5);
         uint8_t *const d = dgd + WIENER_WIN * dgd_stride;
         uint8_t *const s = src + WIENER_WIN * src_stride;
         const int32_t h_start = 0;
         const int32_t v_start = 0;
-        const int32_t h_end = RESTORATION_UNITSIZE_MAX;
-        const int32_t v_end = RESTORATION_UNITSIZE_MAX;
+        const int32_t h_end = RESTORATION_UNITPELS_HORZ_MAX;
+        const int32_t v_end = RESTORATION_UNITPELS_HORZ_MAX;
 
         const uint64_t num_loop = 100000 / (wiener_win * wiener_win);
 
@@ -206,8 +238,8 @@ class av1_compute_stats_test
 
         printf("Average Nanoseconds per Function Call\n");
         printf("    svt_av1_compute_stats_c(%d)   : %6.2f\n",
-                wiener_win,
-                1000000 * time_c / num_loop);
+               wiener_win,
+               1000000 * time_c / num_loop);
         printf(
             "    svt_av1_compute_stats_opt(%d) : %6.2f   (Comparison: "
             "%5.2fx)\n",
@@ -215,7 +247,6 @@ class av1_compute_stats_test
             1000000 * time_o / num_loop,
             time_c / time_o);
     }
-
 };
 
 TEST_P(av1_compute_stats_test, match) {
@@ -227,23 +258,24 @@ TEST_P(av1_compute_stats_test, DISABLED_speed) {
 
 INSTANTIATE_TEST_CASE_P(
     AV1_COMPUTE_STATS_AVX2, av1_compute_stats_test,
-    ::testing::Combine(::testing::Range(BLOCK_4X4, BlockSizeS_ALL),
-                       ::testing::Values(svt_av1_compute_stats_avx2),
-                       ::testing::Range(0, 6),
-                       ::testing::Values(WIENER_WIN_CHROMA, WIENER_WIN,
-                                         WIENER_WIN_3TAP)));
+    ::testing::Combine(
+        ::testing::Range(BLOCK_4X4, (BlockSize)(BlockSizeS_ALL + 2)),
+        ::testing::Values(svt_av1_compute_stats_sse4_1,
+                          svt_av1_compute_stats_avx2),
+        ::testing::Range(0, 6),
+        ::testing::Values(WIENER_WIN_CHROMA, WIENER_WIN, WIENER_WIN_3TAP)));
 
 #if EN_AVX512_SUPPORT
 INSTANTIATE_TEST_CASE_P(
     AV1_COMPUTE_STATS_AVX512, av1_compute_stats_test,
-    ::testing::Combine(::testing::Range(BLOCK_4X4, BlockSizeS_ALL),
-                       ::testing::Values(svt_av1_compute_stats_avx512),
-                       ::testing::Range(0, 6),
-                       ::testing::Values(WIENER_WIN_CHROMA, WIENER_WIN,
-                                         WIENER_WIN_3TAP)));
+    ::testing::Combine(
+        ::testing::Range(BLOCK_4X4, (BlockSize)(BlockSizeS_ALL + 2)),
+        ::testing::Values(svt_av1_compute_stats_avx512), ::testing::Range(0, 6),
+        ::testing::Values(WIENER_WIN_CHROMA, WIENER_WIN, WIENER_WIN_3TAP)));
 #endif
 
-typedef ::testing::tuple<BlockSize, av1_compute_stats_highbd_func, int, int, AomBitDepth>
+typedef ::testing::tuple<BlockSize, av1_compute_stats_highbd_func, int, int,
+                         EbBitDepth>
     av1_compute_stats_hbd_params;
 
 class av1_compute_stats_test_hbd
@@ -253,47 +285,66 @@ class av1_compute_stats_test_hbd
     int64_t M_org[WIENER_WIN2], M_opt[WIENER_WIN2];
     int64_t H_org[WIENER_WIN2 * WIENER_WIN2], H_opt[WIENER_WIN2 * WIENER_WIN2];
 
-    void init_data_highbd(AomBitDepth bd, const int idx) {
+    void init_data_highbd(EbBitDepth bd, const int idx) {
         if (!idx) {
-            memset(dgd, 0, sizeof(*dgd) * 2 * RESTORATION_UNITSIZE_MAX * dgd_stride);
-            memset(src, 0, sizeof(*src) * 2 * RESTORATION_UNITSIZE_MAX * src_stride);
+            memset(
+                dgd,
+                0,
+                sizeof(*dgd) * 2 * RESTORATION_UNITPELS_HORZ_MAX * dgd_stride);
+            memset(
+                src,
+                0,
+                sizeof(*src) * 2 * RESTORATION_UNITPELS_HORZ_MAX * src_stride);
         } else if (1 == idx) {
             svt_buf_random_u16_to_bd(
-                dgd, 2 * RESTORATION_UNITSIZE_MAX * dgd_stride, bd);
+                dgd, 2 * RESTORATION_UNITPELS_HORZ_MAX * dgd_stride, bd);
             svt_buf_random_u16_to_bd(
-                src, 2 * RESTORATION_UNITSIZE_MAX * src_stride, bd);
+                src, 2 * RESTORATION_UNITPELS_HORZ_MAX * src_stride, bd);
         } else if (2 == idx) {
             svt_buf_random_u16_to_bd(
-                dgd, 2 * RESTORATION_UNITSIZE_MAX * dgd_stride, bd);
-            memset(src, 0, sizeof(*src) * 2 * RESTORATION_UNITSIZE_MAX * src_stride);
+                dgd, 2 * RESTORATION_UNITPELS_HORZ_MAX * dgd_stride, bd);
+            memset(
+                src,
+                0,
+                sizeof(*src) * 2 * RESTORATION_UNITPELS_HORZ_MAX * src_stride);
         } else if (3 == idx) {
-            memset(dgd, 0, sizeof(*dgd) * 2 * RESTORATION_UNITSIZE_MAX * dgd_stride);
+            memset(
+                dgd,
+                0,
+                sizeof(*dgd) * 2 * RESTORATION_UNITPELS_HORZ_MAX * dgd_stride);
             svt_buf_random_u16_to_bd(
-                src, 2 * RESTORATION_UNITSIZE_MAX * src_stride, bd);
+                src, 2 * RESTORATION_UNITPELS_HORZ_MAX * src_stride, bd);
         } else if (4 == idx) {
             svt_buf_random_u16_to_0_or_bd(
-                dgd, 2 * RESTORATION_UNITSIZE_MAX * dgd_stride, bd);
+                dgd, 2 * RESTORATION_UNITPELS_HORZ_MAX * dgd_stride, bd);
             svt_buf_random_u16_to_0_or_bd(
-                src, 2 * RESTORATION_UNITSIZE_MAX * src_stride, bd);
+                src, 2 * RESTORATION_UNITPELS_HORZ_MAX * src_stride, bd);
         } else if (5 == idx) {
-            // Trigger the 32-bit overflow in Step 3 and 4 for AOM_BITS_12.
+            // Trigger the 32-bit overflow in Step 3 and 4 for EB_TWELVE_BIT.
             svt_buf_random_u16_to_bd(
-                dgd, 2 * RESTORATION_UNITSIZE_MAX * dgd_stride, bd);
-            for (int i = 0; i < 2 * RESTORATION_UNITSIZE_MAX; i++) {
+                dgd, 2 * RESTORATION_UNITPELS_HORZ_MAX * dgd_stride, bd);
+            for (int i = 0; i < 2 * RESTORATION_UNITPELS_HORZ_MAX; i++) {
                 memset(dgd + i * dgd_stride, 0, sizeof(*dgd) * 20);
             }
-            memset(src, 0, sizeof(*src) * 2 * RESTORATION_UNITSIZE_MAX * src_stride);
+            memset(
+                src,
+                0,
+                sizeof(*src) * 2 * RESTORATION_UNITPELS_HORZ_MAX * src_stride);
         } else if (6 == idx) {
-            // Trigger the 32-bit overflow in Step 5 and 6 for AOM_BITS_12.
+            // Trigger the 32-bit overflow in Step 5 and 6 for EB_TWELVE_BIT.
             svt_buf_random_u16_to_bd(
-                dgd, 2 * RESTORATION_UNITSIZE_MAX * dgd_stride, bd);
-            memset(dgd, 0, sizeof(*dgd) * 2 * RESTORATION_UNITSIZE_MAX * 20);
-            memset(src, 0, sizeof(*src) * 2 * RESTORATION_UNITSIZE_MAX * src_stride);
+                dgd, 2 * RESTORATION_UNITPELS_HORZ_MAX * dgd_stride, bd);
+            memset(
+                dgd, 0, sizeof(*dgd) * 2 * RESTORATION_UNITPELS_HORZ_MAX * 20);
+            memset(
+                src,
+                0,
+                sizeof(*src) * 2 * RESTORATION_UNITPELS_HORZ_MAX * src_stride);
         } else {
             svt_buf_random_u16_with_bd(
-                dgd, 2 * RESTORATION_UNITSIZE_MAX * dgd_stride, bd);
+                dgd, 2 * RESTORATION_UNITPELS_HORZ_MAX * dgd_stride, bd);
             svt_buf_random_u16_with_bd(
-                src, 2 * RESTORATION_UNITSIZE_MAX * src_stride, bd);
+                src, 2 * RESTORATION_UNITPELS_HORZ_MAX * src_stride, bd);
         }
     }
 
@@ -307,27 +358,39 @@ class av1_compute_stats_test_hbd
   public:
     void highbd_match_test() {
         const int block_size = TEST_GET_PARAM(0);
-        int width = block_size_wide[block_size];
-        int height = block_size_high[block_size];
+        int width;
+        int height;
+        if (block_size < BlockSizeS_ALL) {
+            width = block_size_wide[block_size];
+            height = block_size_high[block_size];
+        } else {
+            if (block_size == BlockSizeS_ALL) {
+                width = 308;
+                height = 308;
+            } else {
+                width = 304;
+                height = 304;
+            }
+        }
         av1_compute_stats_highbd_func func = TEST_GET_PARAM(1);
         int test_idx = TEST_GET_PARAM(2);
         int wiener_win = TEST_GET_PARAM(3);
-        const AomBitDepth bit_depth = TEST_GET_PARAM(4);
+        const EbBitDepth bit_depth = TEST_GET_PARAM(4);
         init_output();
 
         dgd_stride =
             svt_create_random_aligned_stride(2 * RESTORATION_UNITSIZE_MAX, 64);
         src_stride =
             svt_create_random_aligned_stride(2 * RESTORATION_UNITSIZE_MAX, 64);
-        dgd = (uint16_t *)malloc(sizeof(*dgd) * 2 * RESTORATION_UNITSIZE_MAX *
-                                  dgd_stride);
-        src = (uint16_t *)malloc(sizeof(*src) * 2 * RESTORATION_UNITSIZE_MAX *
-                                  src_stride);
+        dgd = (uint16_t *)malloc(sizeof(*dgd) * 2 *
+                                 RESTORATION_UNITPELS_HORZ_MAX * dgd_stride);
+        src = (uint16_t *)malloc(sizeof(*src) * 2 *
+                                 RESTORATION_UNITPELS_HORZ_MAX * src_stride);
 
         int test_times = test_idx == 0 ? 1 : 10;
         for (int i = 0; i < test_times; i++) {
             width += i % 2 == 0 ? 0 : 1;
-            height +=  i % 2 == 0 ? 1 : 0;
+            height += i % 2 == 0 ? 1 : 0;
             init_data_highbd(bit_depth, test_idx);
 
             const uint16_t *const d =
@@ -363,8 +426,8 @@ class av1_compute_stats_test_hbd
                  H_opt,
                  bit_depth);
 
-                ASSERT_EQ(0, memcmp(M_org, M_opt, sizeof(M_org)));
-                ASSERT_EQ(0, memcmp(H_org, H_opt, sizeof(H_org)));
+            ASSERT_EQ(0, memcmp(M_org, M_opt, sizeof(M_org)));
+            ASSERT_EQ(0, memcmp(H_org, H_opt, sizeof(H_org)));
         }
         free(dgd);
         free(src);
@@ -378,22 +441,22 @@ class av1_compute_stats_test_hbd
 
         av1_compute_stats_highbd_func func = TEST_GET_PARAM(1);
         int wiener_win = TEST_GET_PARAM(3);
-        const AomBitDepth bit_depth = TEST_GET_PARAM(4);
+        const EbBitDepth bit_depth = TEST_GET_PARAM(4);
         init_output();
 
         dgd_stride =
             svt_create_random_aligned_stride(2 * RESTORATION_UNITSIZE_MAX, 64);
         src_stride =
             svt_create_random_aligned_stride(2 * RESTORATION_UNITSIZE_MAX, 64);
-        dgd = (uint16_t *)malloc(sizeof(*dgd) * 2 * RESTORATION_UNITSIZE_MAX *
-                                 dgd_stride);
-        src = (uint16_t *)malloc(sizeof(*src) * 2 * RESTORATION_UNITSIZE_MAX *
-                                 src_stride);
+        dgd = (uint16_t *)malloc(sizeof(*dgd) * 2 *
+                                 RESTORATION_UNITPELS_HORZ_MAX * dgd_stride);
+        src = (uint16_t *)malloc(sizeof(*src) * 2 *
+                                 RESTORATION_UNITPELS_HORZ_MAX * src_stride);
 
         const int32_t h_start = 0;
         const int32_t v_start = 0;
-        const int32_t h_end = RESTORATION_UNITSIZE_MAX;
-        const int32_t v_end = RESTORATION_UNITSIZE_MAX;
+        const int32_t h_end = RESTORATION_UNITPELS_HORZ_MAX;
+        const int32_t v_end = RESTORATION_UNITPELS_HORZ_MAX;
 
         init_data_highbd(bit_depth, 7);
         uint16_t *const d = dgd + WIENER_WIN * dgd_stride;
@@ -424,17 +487,17 @@ class av1_compute_stats_test_hbd
 
         for (uint64_t i = 0; i < num_loop; i++) {
             func(wiener_win,
-                    dgd8,
-                    src8,
-                    h_start,
-                    h_end,
-                    v_start,
-                    v_end,
-                    dgd_stride,
-                    src_stride,
-                    M_opt,
-                    H_opt,
-                    bit_depth);
+                 dgd8,
+                 src8,
+                 h_start,
+                 h_end,
+                 v_start,
+                 v_end,
+                 dgd_stride,
+                 src_stride,
+                 M_opt,
+                 H_opt,
+                 bit_depth);
         }
 
         svt_av1_get_time(&finish_time_seconds, &finish_time_useconds);
@@ -452,8 +515,8 @@ class av1_compute_stats_test_hbd
 
         printf("Average Nanoseconds per Function Call\n");
         printf("    svt_av1_compute_stats_highbd_c(%d)   : %6.2f\n",
-                wiener_win,
-                1000000 * time_c / num_loop);
+               wiener_win,
+               1000000 * time_c / num_loop);
         printf(
             "    av1_compute_stats_highbd_opt(%d) : %6.2f   "
             "(Comparison: "
@@ -462,7 +525,6 @@ class av1_compute_stats_test_hbd
             1000000 * time_o / num_loop,
             time_c / time_o);
     }
-
 };
 
 TEST_P(av1_compute_stats_test_hbd, match) {
@@ -475,19 +537,20 @@ TEST_P(av1_compute_stats_test_hbd, DISABLED_speed) {
 INSTANTIATE_TEST_CASE_P(
     AV1_COMPUTE_STATS_HBD_AVX2, av1_compute_stats_test_hbd,
     ::testing::Combine(
-        ::testing::Range(BLOCK_4X4, BlockSizeS_ALL),
-        ::testing::Values(svt_av1_compute_stats_highbd_avx2),
+        ::testing::Range(BLOCK_4X4, (BlockSize)(BlockSizeS_ALL + 2)),
+        ::testing::Values(svt_av1_compute_stats_highbd_sse4_1,
+                          svt_av1_compute_stats_highbd_avx2),
         ::testing::Range(0, 8),
         ::testing::Values(WIENER_WIN_CHROMA, WIENER_WIN, WIENER_WIN_3TAP),
-        ::testing::Values(AOM_BITS_8, AOM_BITS_10, AOM_BITS_12)));
+        ::testing::Values(EB_EIGHT_BIT, EB_TEN_BIT, EB_TWELVE_BIT)));
 
 #if EN_AVX512_SUPPORT
 INSTANTIATE_TEST_CASE_P(
     AV1_COMPUTE_STATS_HBD_AVX512, av1_compute_stats_test_hbd,
     ::testing::Combine(
-        ::testing::Range(BLOCK_4X4, BlockSizeS_ALL),
+        ::testing::Range(BLOCK_4X4, (BlockSize)(BlockSizeS_ALL + 2)),
         ::testing::Values(svt_av1_compute_stats_highbd_avx512),
         ::testing::Range(0, 8),
         ::testing::Values(WIENER_WIN_CHROMA, WIENER_WIN, WIENER_WIN_3TAP),
-        ::testing::Values(AOM_BITS_8, AOM_BITS_10, AOM_BITS_12)));
+        ::testing::Values(EB_EIGHT_BIT, EB_TEN_BIT, EB_TWELVE_BIT)));
 #endif
