@@ -187,7 +187,8 @@ INSTANTIATE_TEST_CASE_P(
     AVX2, SpatialFullDistortionTest,
     ::testing::Values(svt_spatial_full_distortion_kernel_avx2));
 
-INSTANTIATE_TEST_CASE_P(SSE4_1, SpatialFullDistortionTest,
+INSTANTIATE_TEST_CASE_P(
+    SSE4_1, SpatialFullDistortionTest,
     ::testing::Values(svt_spatial_full_distortion_kernel_sse4_1));
 
 #if EN_AVX512_SUPPORT
@@ -375,7 +376,7 @@ INSTANTIATE_TEST_CASE_P(
         ::testing::Values(svt_spatial_full_distortion_kernel_sse4_1,
                           svt_spatial_full_distortion_kernel_avx2,
                           svt_spatial_full_distortion_kernel_avx512)));
-#endif
+#else
 
 INSTANTIATE_TEST_CASE_P(
     SpatialKernelFunc, SpatialFullDistortionKernelFuncTest,
@@ -384,6 +385,7 @@ INSTANTIATE_TEST_CASE_P(
         ::testing::ValuesIn(TEST_PATTERNS),
         ::testing::Values(svt_spatial_full_distortion_kernel_sse4_1,
                           svt_spatial_full_distortion_kernel_avx2)));
+#endif
 
 class FullDistortionKernel16BitsFuncTest
     : public SpatialFullDistortionFuncTestBase,
@@ -591,8 +593,10 @@ class fullDistortionKernel32Bits
     void RunCheckOutput();
 
     void init_data() {
-        svt_buf_random_u32_with_max((uint32_t *)coeff, MAX_SB_SIZE * coeff_stride_, (1<<15));
-        svt_buf_random_u32_with_max((uint32_t *)recon, MAX_SB_SIZE * recon_stride_, (1<<15));
+        svt_buf_random_u32_with_max(
+            (uint32_t *)coeff, MAX_SB_SIZE * coeff_stride_, (1 << 15));
+        svt_buf_random_u32_with_max(
+            (uint32_t *)recon, MAX_SB_SIZE * recon_stride_, (1 << 15));
     }
 
     uint64_t result_ref[DIST_CALC_TOTAL];
@@ -608,7 +612,8 @@ void fullDistortionKernel32Bits::RunCheckOutput() {
     for (int i = 0; i < 10; i++) {
         init_data();
         for (uint32_t area_width = 4; area_width <= 128; area_width += 4) {
-            for (uint32_t area_height = 4; area_height <= 128; area_height += 4) {
+            for (uint32_t area_height = 4; area_height <= 128;
+                 area_height += 4) {
                 svt_full_distortion_kernel32_bits_c(coeff,
                                                     coeff_stride_,
                                                     recon,
@@ -624,7 +629,8 @@ void fullDistortionKernel32Bits::RunCheckOutput() {
                       area_width,
                       area_height);
 
-                EXPECT_EQ(memcmp(result_ref, result_mod, sizeof(result_ref)), 0);
+                EXPECT_EQ(memcmp(result_ref, result_mod, sizeof(result_ref)),
+                          0);
             }
         }
     }
@@ -686,18 +692,13 @@ void fullDistortionKernelCbfZero32Bits::RunCheckOutput() {
         for (uint32_t area_width = 4; area_width <= 128; area_width += 4) {
             for (uint32_t area_height = 4; area_height <= 128;
                  area_height += 4) {
-                svt_full_distortion_kernel_cbf_zero32_bits_c(coeff,
-                                                    coeff_stride_,
-                                                    result_ref,
-                                                    area_width,
-                                                    area_height);
-                func_(coeff,
-                      coeff_stride_,
-                      result_mod,
-                      area_width,
-                      area_height);
+                svt_full_distortion_kernel_cbf_zero32_bits_c(
+                    coeff, coeff_stride_, result_ref, area_width, area_height);
+                func_(
+                    coeff, coeff_stride_, result_mod, area_width, area_height);
 
-                EXPECT_EQ(memcmp(result_ref, result_mod, sizeof(result_ref)), 0);
+                EXPECT_EQ(memcmp(result_ref, result_mod, sizeof(result_ref)),
+                          0);
             }
         }
     }
