@@ -135,10 +135,11 @@ TEST_P(MseTest, MaxTest) {
     run_max_test();
 };
 
-INSTANTIATE_TEST_CASE_P(Variance, MseTest,
-                        ::testing::Values(TestMseParam(16, 16,
-                                                       &svt_aom_mse16x16_avx2,
-                                                       &svt_aom_mse16x16_c)));
+INSTANTIATE_TEST_CASE_P(
+    Variance, MseTest,
+    ::testing::Values(
+        TestMseParam(16, 16, &svt_aom_mse16x16_sse2, &svt_aom_mse16x16_c),
+        TestMseParam(16, 16, &svt_aom_mse16x16_avx2, &svt_aom_mse16x16_c)));
 
 class MseTestHighbd : public ::testing::TestWithParam<TestMseParamHighbd> {
   public:
@@ -531,7 +532,7 @@ class AvxSubpelVarianceTest : public ::testing::TestWithParam<TestParams> {
         if (use_high_bit_depth) {
             mask = (1u << static_cast<unsigned>(use_high_bit_depth)) - 1;
         } else {
-            mask = (1u << AOM_BITS_8) - 1;
+            mask = (1u << EB_EIGHT_BIT) - 1;
         }
 
         if (!use_high_bit_depth) {
