@@ -26,7 +26,7 @@ YuvVideoSource::YuvVideoSource(const std::string &file_name,
                                const VideoColorFormat format,
                                const uint32_t width, const uint32_t height,
                                const uint8_t bit_depth)
-    : VideoFileSource(file_name, format, width, height, bit_depth, false) {
+    : VideoFileSource(file_name, format, width, height, bit_depth) {
     src_name_ = "YUV Source";
 }
 
